@@ -1421,8 +1421,8 @@ cpl_error_code kmo_image_divide_scalar(cpl_image *img, float divisor)
 */
 cpl_error_code kmo_image_divide(cpl_image *img1, const cpl_image *img2)
 {
-    float           *df1        = NULL,
-                    *df2        = NULL;
+    float           *df1        = NULL;
+    const float     *df2        = NULL;
     int             x1          = 0,
                     y1          = 0,
                     x2          = 0,
@@ -1458,7 +1458,7 @@ cpl_error_code kmo_image_divide(cpl_image *img1, const cpl_image *img2)
                 KMO_TRY_EXIT_IF_NULL(
                     df1 = (float*)cpl_image_get_data(img1));
                 KMO_TRY_EXIT_IF_NULL(
-                    df2 = (float*)cpl_image_get_data_const(img2));
+                    df2 = (const float*)cpl_image_get_data_const(img2));
 
                 for (i = 0; i < x1 * y1; i++) {
                     df1[i] /= df2[i];
