@@ -728,7 +728,7 @@ cpl_error_code kmo_plot_vector(const char *pre, const char *opt,
     Any possibly set error from cpl_plot_vector()
 */
 cpl_error_code kmo_plot_vectors_xy(const char *pre, const char *opt,
-                                   const cpl_vector *x, const cpl_vector *y)
+                                   cpl_vector *x, cpl_vector *y)
 {
     cpl_error_code  ret_error   = CPL_ERROR_NONE;
 
@@ -752,8 +752,7 @@ cpl_error_code kmo_plot_vectors_xy(const char *pre, const char *opt,
             }
 
             KMO_TRY_EXIT_IF_NULL(
-                bi = cpl_bivector_wrap_vectors((cpl_vector*)x,
-                                               (cpl_vector*)y));
+                bi = cpl_bivector_wrap_vectors(x, y));
 
             KMO_TRY_EXIT_IF_ERROR(
                 cpl_plot_bivector(pre_final, opt, NULL, bi));
@@ -788,9 +787,9 @@ cpl_error_code kmo_plot_vectors_xy(const char *pre, const char *opt,
     Any possibly set error from cpl_plot_vector()
 */
 cpl_error_code     kmo_plot_vectors2(const char *pre, const char **opt,
-                                     const cpl_vector *x,
-                                     const cpl_vector *y1,
-                                     const cpl_vector *y2)
+                                     cpl_vector *x,
+                                     cpl_vector *y1,
+                                     cpl_vector *y2)
 {
     cpl_error_code  ret_error   = CPL_ERROR_NONE;
 
@@ -814,18 +813,17 @@ cpl_error_code     kmo_plot_vectors2(const char *pre, const char **opt,
             }
 
             KMO_TRY_EXIT_IF_NULL(
-                plots[0] = cpl_bivector_wrap_vectors((cpl_vector*)x,
-                                                     (cpl_vector*)y1));
+                plots[0] = cpl_bivector_wrap_vectors(x, y1));
             KMO_TRY_EXIT_IF_NULL(
-                plots[1] = cpl_bivector_wrap_vectors((cpl_vector*)x,
-                                                     (cpl_vector*)y2));
+                plots[1] = cpl_bivector_wrap_vectors(x, y2));
 
-            KMO_TRY_EXIT_IF_ERROR(
-                cpl_plot_bivectors(pre_final,
-                               (const char**)opt,
-                               "",
-                               (const cpl_bivector**)plots,
-                               nr_plots));
+            CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
+            cpl_error_code err = cpl_plot_bivectors(pre_final, opt, "",
+            		(const cpl_bivector **)plots,
+                    nr_plots);
+            CPL_DIAG_PRAGMA_POP;
+
+            KMO_TRY_EXIT_IF_ERROR(err);
 
             int k = 0;
             for (k = 0; k < nr_plots; k++) {
@@ -908,8 +906,7 @@ void kmo_debug_unused_ifus(cpl_array *unused) {
 
         KMO_TRY_EXIT_IF_NULL(
             punused = cpl_array_get_data_int(unused));
-        int j = 0;
-        for (j = 0; j < KMOS_IFUS_PER_DETECTOR; j++) {
+        for (int j = 0; j < KMOS_IFUS_PER_DETECTOR; j++) {
             switch (punused[j]) {
             case 0:
                 break;
@@ -947,8 +944,7 @@ void kmo_debug_unused_ifus(cpl_array *unused) {
             sprintf(str, "      ");
             KMO_TRY_EXIT_IF_NULL(
                 punused = cpl_array_get_data_int(unused));
-            int j = 0;
-            for (j = 0; j < KMOS_IFUS_PER_DETECTOR; j++) {
+            for (int j = 0; j < KMOS_IFUS_PER_DETECTOR; j++) {
                 switch (punused[j]) {
                 case 0:
                     strcat(str, "  .");
