@@ -53,6 +53,10 @@
 #define KEY_WAVELMAX_COMMENT         "[nm] Maximum wavelength"
 #define KEY_PROG_ID                  "PROG_ID"
 #define KEY_PROG_ID_COMMENT          "ESO programme identification"
+#define KEY_DATEOBS                  "DATE-OBS"
+#define KEY_DATEOBS_COMMENT          "Observing date"
+#define KEY_MJDOBS                   "MJD-OBS"
+#define KEY_MJDOBS_COMMENT           "[d] Start of observations (days)"
 #define KEY_MJDEND                   "MJD-END"
 #define KEY_MJDEND_COMMENT           "[d] End of observations (days)"
 #define KEY_PRODCATG                 "PRODCATG"
@@ -80,7 +84,7 @@
 #define KEY_CSYER2					"CSYER2"
 #define KEY_CSYER2_COMMENT          "[deg] Systematic error in coordinate"
 #define KEY_CRDER3					"CRDER3"
-#define KEY_CRDER3_COMMENT          ""
+#define KEY_CRDER3_COMMENT          "[um] Random error in spectral coordinate"
 #define KEY_NCOMBINE                "NCOMBINE"
 
 /* ------------------ END IDP RELATED    ------------------------------------ */
@@ -271,6 +275,9 @@
 #define FIT_ERR_SCALE            "ESO PRO FIT ERR SCALE"
 #define FIT_RED_CHISQ            "ESO PRO FIT RED CHISQ"
 
+#define PRO_MJD_OBS             "ESO PRO MJD-OBS"
+#define PRO_DATE_OBS            "ESO PRO DATE-OBS"
+
 /* ----- QC parameters ------------------------------------------------------ */
 // kmo_dark
 #define QC_DARK                  "ESO QC DARK"
@@ -494,13 +501,11 @@ int kmos_idp_prepare_main_keys(
         cpl_imagelist       *   cube_combined_error) ;
 int kmos_idp_prepare_data_keys(
         cpl_propertylist    *   plist,
-        const char          *   error_extname,
-        const char          *   object) ;
+        const char          *   error_extname) ;
 int kmos_idp_prepare_error_keys(
         cpl_propertylist    *   plist,
         const char          *   error_extname,
-        const char          *   data_extname,
-        const char          *   object) ;
+        const char          *   data_extname) ;
 cpl_imagelist * kmos_idp_compute_error(
         cpl_imagelist   *   data_cube) ;
 char * kmos_idp_compute_error_extname(
@@ -509,6 +514,20 @@ double kmos_idp_compute_abmaglim(
         cpl_imagelist           *   datacube,
         double                      sky_res,
         const cpl_propertylist  *   plist) ;
+int kmos_idp_add_files_infos(
+        cpl_propertylist    *   out,
+        cpl_frameset        *   fset,
+        const char          *   raw_tag,
+        int                 *   used_frame_idx,
+        int                     data_cube_counter) ;
+int kmos_idp_compute_mjd(
+        cpl_frameset        *   fset,
+        const char          *   raw_tag,
+        int                 *   used_frame_idx,
+        int                     data_cube_counter,
+        double              *   mjd_start,
+        double              *   mjd_end,
+        char                **  date_obs) ;
 
 /********************************************************************/
 
