@@ -32,15 +32,15 @@
 
 #include "kmclipm_constants.h"
 #include "kmclipm_math.h"
-#include "kmclipm_functions.h"
 
 #include "kmo_dfs.h"
 #include "kmo_error.h"
 #include "kmo_cpl_extensions.h"
-#include "kmo_priv_combine.h"
 #include "kmo_priv_fit_profile.h"
 #include "kmo_priv_shift.h"
 
+#include "kmo_priv_combine.h"
+
 /*-----------------------------------------------------------------------------
                                 Functions prototypes
  -----------------------------------------------------------------------------*/
@@ -137,10 +137,11 @@ cpl_error_code kmos_combine_frames(
     cpl_image           *   cur_img2 ;
     kmclipm_vector      *   data_vec ;
     float               *   pavg_data ;
-    float               *   pavg_noise ;
+    float               *   pavg_noise = NULL;
     float               *   pcur_img2 ;
     int                     nx, ny, nz, ix, iy, iz, rej ;
-    double                  stderr, tol, tmp_dbl ;
+    double                  std_err;
+    double                  tol, tmp_dbl ;
     enum combine_status     status = combine_ok;
 
     /* Check inputs */
@@ -234,18 +235,18 @@ cpl_error_code kmos_combine_frames(
                     kmclipm_vector_set(data_vec, iz, 0.0/0.0);
                 }
             } /* for iz = 0 */
-
+            std_err = 0;
             pavg_data[ix+iy*nx] = (float)kmos_combine_vector(data_vec, 
                     cmethod, cpos_rej, cneg_rej, citer, cmax, cmin,
-                    &stderr, default_val, &status);
+                    &std_err, default_val, &status);
 
             if (status == combine_rejected) {
                 /* this pixel is invalid */
                 cpl_image_reject(*avg_data, ix+1, iy+1);
             }
             if (avg_noise != NULL) {
-                pavg_noise[ix+iy*nx] = (float)stderr;
-                if (status == combine_rejected || ((stderr == -1)&&(nz != 1))) {
+                pavg_noise[ix+iy*nx] = (float)std_err;
+                if (status == combine_rejected || ((std_err == -1)&&(nz != 1))) {
                     /* This noise pixel is invalid */
                     cpl_image_reject(*avg_noise, ix+1, iy+1);
                 }
@@ -255,7 +256,7 @@ cpl_error_code kmos_combine_frames(
     kmclipm_vector_delete(data_vec);
 
     /* if nz is 1, kmclipm_combine_vector()
-       returns default_val for stderr. We replace this by stddev(data)*/
+       returns default_val for std_err. We replace this by stddev(data)*/
     if ((nz == 1) && (avg_noise != NULL)) {
         cpl_imagelist *data_dup = cpl_imagelist_duplicate(data);
         cur_img2 = cpl_imagelist_get(data_dup, 0);
@@ -480,8 +481,7 @@ cpl_error_code kmo_align_subpix(
         if ((fabs(fract_part_x) > tol) || (fabs(fract_part_y) > tol)) {
             KMO_TRY_EXIT_IF_ERROR(
                 kmo_priv_shift(data, noise, header_data, header_noise,
-                    fract_part_x, fract_part_y, flux, -1, method, extrapolate,
-                    FALSE));
+                    fract_part_x, fract_part_y, flux, method, extrapolate));
         } else {
             fract_part_x = 0;
             fract_part_y = 0;
@@ -523,7 +523,7 @@ cpl_error_code kmo_align_subpix(
     {
         KMO_CATCH_MSG();
         ret = cpl_error_get_code();
-        x = 0;
+        *x = 0;
     }
 
     return ret;
@@ -914,21 +914,20 @@ cpl_error_code kmo_priv_combine(
     char            *   clean_suffix; 
     char            *   ext_name ; 
     char            *   fn_shifts ; 
-    int                 nx, ny, nz, nx_new, ny_new, y_min, x_min, y_max,
-                        x_max, tmp_int, nr_identified ;
-    double              cd1_1, cd1_2, ang1, ang2, stdev, tol, stderr ;
+    int                 nx, ny, nz, nx_new, ny_new, tmp_int, nr_identified ;
+    double              cd1_1, cd1_2, ang1, ang2, stdev, tol, std_err ;
     cpl_bivector    *   shifts ; 
     double          *   pxshifts ;
     double          *   pyshifts ;
     double          *   ptmp_data_vec ;
-    double          *   ptmp_noise_vec ;
+    double          *   ptmp_noise_vec = NULL;
     cpl_vector      *   identified ;
     double          *   pidentified ;
     int                 i, ix, iy, iz ;
     cpl_image       *   img_data_tmp ;
     cpl_image       *   img_noise_tmp ;
     cpl_image       **  data_cur_img_list ;
-    cpl_image       **  noise_cur_img_list ;
+    cpl_image       **  noise_cur_img_list = NULL;
     float           *   pimg_data_tmp ;
     float           *   pimg_noise_tmp ;
     float           *   pexp_mask ;
@@ -1126,7 +1125,7 @@ cpl_error_code kmo_priv_combine(
                     pimg_data_tmp[ix+iy*nx_new] =
                         kmclipm_combine_vector(kvd, kvn, cmethod, cpos_rej,
                                 cneg_rej, citer, cmax, cmin, &tmp_int, 
-                                &stdev, &stderr, 0., &combStatus);
+                                &stdev, &std_err, 0., &combStatus);
                     if (exp_mask != NULL) {
                         pexp_mask[ix+iy*nx_new] = nr_identified;
                     }
@@ -1137,7 +1136,7 @@ cpl_error_code kmo_priv_combine(
                 kmclipm_vector_delete(kvd);
                 if (noise_counter > 0) kmclipm_vector_delete(kvn);
                 if (nr_identified > 1) {
-                    pimg_noise_tmp[ix+iy*nx_new] = stderr;
+                    pimg_noise_tmp[ix+iy*nx_new] = std_err;
                 } else {
                     // no noise value here, reject pixel
                     cpl_image_reject(img_noise_tmp, ix+1,iy+1);
@@ -1401,7 +1400,7 @@ static cpl_error_code kmos_reject_deviant(
                        (cmethod == "min_max" only)
   @param cmin          Number of minimum pixel values to reject
                        (cmethod == "min_max" only)
-  @param stderr        (Output) The standard error of @c data_in calculated
+  @param std_err       (Output) The standard error of @c data_in calculated
                        with rejection.
   @param default_val   The default value to return if all values have been
                        rejected.
@@ -1432,7 +1431,7 @@ static double kmos_combine_vector(
         int                         citer,
         int                         cmax,
         int                         cmin,
-        double                  *   stderr,
+        double                  *   std_err,
         double                      default_val,
         enum combine_status     *   status)
 {
@@ -1453,9 +1452,9 @@ static double kmos_combine_vector(
     calc_noise = FALSE;
 
     nz = cpl_vector_get_size(data_in->data);
-    *status = combine_ok;
-    out_val = default_val;
-    *stderr = default_val;
+    *status  = combine_ok;
+    out_val  = default_val;
+    *std_err = default_val;
 
     data = kmclipm_vector_duplicate(data_in);
     size = kmclipm_vector_count_non_rejected(data);
@@ -1523,9 +1522,9 @@ static double kmos_combine_vector(
             }
             if (all_rejected == TRUE) {
                 size = 0;
-                out_val = default_val;
-                *status = combine_rejected;
-                *stderr = default_val;
+                out_val  = default_val;
+                *status  = combine_rejected;
+                *std_err = default_val;
                 calc_noise = FALSE;
             } else {
                 /* compute the average out of the remaining values */
@@ -1534,31 +1533,31 @@ static double kmos_combine_vector(
             }
         }
     } else {
-        out_val = default_val;
-        *status = combine_rejected;
-        *stderr = default_val;
+        out_val  = default_val;
+        *status  = combine_rejected;
+        *std_err = default_val;
     }
 
-    /* Compute stderr */
+    /* Compute std_err */
     if (calc_noise == TRUE) {
         size = kmclipm_vector_count_non_rejected(data);
         if (size > 2) {
             if (!strcmp(cmethod, "median")) {
-                *stderr = kmclipm_vector_get_stdev_median(data) / sqrt(size) ;
+                *std_err = kmclipm_vector_get_stdev_median(data) / sqrt(size) ;
             } else {
-                *stderr = kmclipm_vector_get_stdev(data) / sqrt(size) ;
+                *std_err = kmclipm_vector_get_stdev(data) / sqrt(size) ;
             }
         } else {
             /* error estimation on input data */
             if (size == 1) {
-                *stderr = default_val;
+                *std_err = default_val;
             } else if (size == 2) {
                 i = 0;
                 while (kmclipm_vector_is_rejected(data, i)) i++;
                 j = i+1;
                 while (kmclipm_vector_is_rejected(data, j)) j++;
 
-                *stderr = fabs(kmclipm_vector_get(data, i, NULL) -
+                *std_err = fabs(kmclipm_vector_get(data, i, NULL) -
                               kmclipm_vector_get(data, j, NULL)) / sqrt(2);
             }
         }
