@@ -30,6 +30,13 @@
 #include "kmo_cpl_extensions.h"
 #include "kmo_debug.h"
 
+static int kmos_fit_lorentz_plot(
+        const cpl_vector    *   x,
+        const cpl_vector    *   y,
+        const cpl_vector    *   fit_par,
+        double                  peak_pos,
+        int                     fitted) ;
+
 /*----------------------------------------------------------------------------*/
 /**
     @defgroup kmos_priv_fit_profile Helper functions for recipe kmo_fit_profile
@@ -67,9 +74,9 @@
     @li CPL_ERROR_ILLEGAL_INPUT if the provided @c method is incorrect or if
                                 x1 is too small or x2 too large.
 */
-cpl_vector*     kmo_fit_profile_1D(const cpl_vector *lambda_in,
+cpl_vector*     kmo_fit_profile_1D(cpl_vector *lambda_in,
                                    const cpl_vector *data_in,
-                                   const cpl_vector *noise_in,
+                                   cpl_vector *noise_in,
                                    const char *method,
                                    cpl_vector **data_out,
                                    cpl_propertylist **pl)
@@ -78,6 +85,7 @@ cpl_vector*     kmo_fit_profile_1D(const cpl_vector *lambda_in,
 
     double          *pfit_pars      = NULL,
                     max_val         = 0.0,
+                    min_val         = 0.0,
                     max_pos         = 0,
                     *pdata_out      = NULL,
                     result          = 0.0,
@@ -121,6 +129,7 @@ cpl_vector*     kmo_fit_profile_1D(const cpl_vector *lambda_in,
             kmo_vector_get_maxpos_old(data_in, &tmp_int));
         max_pos = cpl_vector_get(lambda_in, tmp_int);
         max_val = cpl_vector_get_max(data_in);
+        min_val = cpl_vector_get_min(data_in);
 
         // calculate fit parameters
         if (strcmp(method, "gauss") == 0) {
@@ -153,7 +162,7 @@ cpl_vector*     kmo_fit_profile_1D(const cpl_vector *lambda_in,
                  fit_pars = kmo_vector_fit_lorentz(lambda_in, data_in,
                                                    noise_in,
                                                    max_pos, max_val,
-                                                   pl, FALSE));
+                                                   min_val, pl, FALSE));
         }
 
         // calculate fitted function to return
@@ -394,7 +403,7 @@ cpl_vector*    kmo_fit_profile_2D(const cpl_image *data_in,
 
 */
 cpl_vector* kmo_vector_fit_gauss(const cpl_vector *x, const cpl_vector *y,
-                                 const cpl_vector *noise,
+                                 cpl_vector *noise,
                                  double max_pos,
                                  cpl_propertylist **pl)
 {
@@ -431,7 +440,7 @@ cpl_vector* kmo_vector_fit_gauss(const cpl_vector *x, const cpl_vector *y,
             KMO_TRY_EXIT_IF_ERROR(
                 cpl_vector_fill(sigma_y, 1.0));
         } else {
-            sigma_y = (cpl_vector*)noise;
+            sigma_y = noise;
         }
 
         KMO_TRY_EXIT_IF_ERROR(
@@ -570,8 +579,8 @@ cpl_vector* kmo_vector_fit_gauss(const cpl_vector *x, const cpl_vector *y,
     @li CPL_ERROR_NULL_INPUT    if @c x or @c y is NULL.
     @li CPL_ERROR_ILLEGAL_INPUT if @c x and @c y don't have the same length.
 */
-cpl_vector* kmo_vector_fit_moffat(const cpl_vector *x, const cpl_vector *y,
-                                  const cpl_vector *noise,
+cpl_vector* kmo_vector_fit_moffat(cpl_vector *x, const cpl_vector *y,
+                                  cpl_vector *noise,
                                   double max_pos, double max_val,
                                   cpl_propertylist **pl)
 {
@@ -614,7 +623,7 @@ cpl_vector* kmo_vector_fit_moffat(const cpl_vector *x, const cpl_vector *y,
 //kmo_debug_vector(fit_par);
         KMO_TRY_EXIT_IF_NULL(
             x_mat = cpl_matrix_wrap(cpl_vector_get_size(x), 1,
-                                    (double*)cpl_vector_get_data_const(x)));
+                                    cpl_vector_get_data(x)));
 
         // if no noise is provided, create a sigma-vector filled with ones
         if (noise == NULL) {
@@ -623,7 +632,7 @@ cpl_vector* kmo_vector_fit_moffat(const cpl_vector *x, const cpl_vector *y,
             KMO_TRY_EXIT_IF_ERROR(
                 cpl_vector_fill(sigma_y, 1.0));
         } else {
-            sigma_y = (cpl_vector*)noise;
+            sigma_y = noise;
         }
 
         fit_error = cpl_fit_lvmq(x_mat, NULL,
@@ -775,263 +784,231 @@ cpl_vector* kmo_vector_fit_moffat(const cpl_vector *x, const cpl_vector *y,
     return fit_par;
 }
 
+/*----------------------------------------------------------------------------*/
 /**
-    @brief
-        Fits a lorentz function to vectors.
-
-    @param x          The x data vector.
-    @param y          The y data vector.
-    @param noise      The associated noise.
-    @param max_pos    The position of the maximum value. (If CRPIX, CDELT and
-                      CRVAL are provided, max_pos is a spectral value. Otherwise
-                      a pixel value). Needed as initial estimate.
-    @param max_val    The maximum value. Needed as initial estimate.
-    @param pl         (Optinal output) If @c pl is non-null, a propertylist will
-                      be created containing the fit parameters. If the fit was
-                      successful also the associated errors and the
-                      reduced chi squared are returned.
-    @param fit_linear FALSE: if linear component shouldn't be fitted
-                      TRUE: if linear component should be fitted
-
-    @return
-        The fitted parameters.
-
-    The lorentz function is fitted using the Levenberg-Marquardt method.
-
-    The fit parameters are returned in a vector of length four where the first
-    value is the constant term:
-        f(x) = fit_par[0] + fit_par[1]/Pi*(fit_par[3]/2) /
-                                             ((x-fit_par[2]^2 + (fit_par[3]/2)^2
-               + fit_par[4]*x
-    (fit_par[4] will be always zero when fit_linear==FALSE)
-
-    The returned vector an pl have to be deleted manually afterwards.
-
-    Possible cpl_error_code set in this function:
+  @brief    Fits a lorentz function to vectors
+  @param  	x	    The x data vector
+  @param    y       The y data vector
+  @param    noise   The associated noise
+  @param    peak_pos The position of the maximum value. (If CRPIX, CDELT
+                    and CRVAL are provided, max_pos is a spectral value. 
+                    Otherwise a pixel value). Needed as initial estimate.
+  @param    peak_val The maximum value. Needed as initial estimate.
+  @param    background_val  The background value
+  @param    pl      (Optinal output) If @c pl is non-null, a propertylist will 
+                    be created containing the fit parameters. If the fit was 
+                    successful also the associated errors and the reduced chi 
+                    squared are returned.
+  @param    fit_linear  FALSE: if linear component shouldn't be fitted
+                        TRUE: if linear component should be fitted
+  @return   The fitted parameters
+  @see      kmos_oscan_mid_var_tukey()
+    
+  The lorentz function is fitted using the Levenberg-Marquardt method.
+  The fit parameters are returned in a vector of length four where the first
+  value is the constant term:
+  f(x) = fit_par[0] + fit_par[1]/Pi*(fit_par[3]/2) /
+    ((x-fit_par[2]^2 + (fit_par[3]/2)^2 + fit_par[4]*x
+  (fit_par[4] will be always zero when fit_linear==FALSE)
+  The returned vector an pl have to be deleted manually afterwards.
 
+  Possible cpl_error_code set in this function:
     @li CPL_ERROR_NULL_INPUT    if @c x or @c y is NULL.
     @li CPL_ERROR_ILLEGAL_INPUT if @c x and @c y don't have the same length.
-
-*/
-cpl_vector* kmo_vector_fit_lorentz(const cpl_vector *x, const cpl_vector *y,
-                                   const cpl_vector *noise,
-                                   double max_pos, double max_val,
-                                   cpl_propertylist **pl,
-                                   int fit_linear)
+ */
+/*----------------------------------------------------------------------------*/
+cpl_vector * kmo_vector_fit_lorentz(
+        cpl_vector          *   x,
+        const cpl_vector    *   y,
+        cpl_vector          *   noise,
+        double                  peak_pos, 
+        double                  peak_val,
+        double                  background_val,
+        cpl_propertylist    **  pl,
+        int                     fit_linear)
 {
-    cpl_vector      *fit_par    = NULL,
-                    *sigma_y    = NULL;
+    cpl_vector      *   fit_par ;
+    cpl_vector      *   sigma_y ;
+    cpl_matrix      *   x_mat ;
+    double          *   pfit_par ;
+    cpl_matrix      *   covariance ;
+    int             *   valid ;
+    cpl_error_code      fit_error ;
+    double              cdelt, red_chisq;
 
-    cpl_matrix      *x_mat      = NULL;
-
-    cpl_error_code  fit_error   = CPL_ERROR_NONE;
-
-    double          cdelt       = 0.0,
-                    red_chisq   = 0.0,
-                    *pfit_par   = NULL;
-
-    cpl_matrix      *covariance = NULL;
-
-    int             *valid      = NULL;
-
-    KMO_TRY
-    {
-        KMO_TRY_ASSURE((x != NULL) &&
-                       (y != NULL),
-                       CPL_ERROR_NULL_INPUT,
-                       "Not all input data is provided!");
-
-        KMO_TRY_ASSURE(cpl_vector_get_size(x) == cpl_vector_get_size(y),
-                       CPL_ERROR_ILLEGAL_INPUT,
-                       "x and y don't have same size!");
-
-        KMO_TRY_EXIT_IF_NULL(
-            fit_par = cpl_vector_new(5));
-
-        // initial estimates
-        cdelt = cpl_vector_get(x, 1) - cpl_vector_get(x, 0);
-        cpl_vector_set(fit_par, 0, 0.0);
-        cpl_vector_set(fit_par, 1, max_val);
-        cpl_vector_set(fit_par, 2, max_pos);
-        cpl_vector_set(fit_par, 3, cdelt);
-        cpl_vector_set(fit_par, 4, 0.0);
-
-        if (fit_linear == FALSE) {
-            KMO_TRY_EXIT_IF_NULL(
-                valid = (int*)cpl_malloc(5*sizeof(int)));
-            valid[0] = 1.0;
-            valid[1] = 1.0;
-            valid[2] = 1.0;
-            valid[3] = 1.0;
-            valid[4] = 0.0;
-        }
-
-//printf("*********************************************\n");
-//printf("### ESTIMATES ### LORENTZ 1D ################\n");
-//kmo_debug_vector(fit_par);
-        KMO_TRY_EXIT_IF_NULL(
-            x_mat = cpl_matrix_wrap(cpl_vector_get_size(x), 1,
-                                    (double*)cpl_vector_get_data_const(x)));
-
-        // if no noise is provided, create a sigma-vector filled with ones
-        if (noise == NULL) {
-            KMO_TRY_EXIT_IF_NULL(
-                sigma_y = cpl_vector_new(cpl_vector_get_size(x)));
-            KMO_TRY_EXIT_IF_ERROR(
-                cpl_vector_fill(sigma_y, 1.0));
-        } else {
-            sigma_y = (cpl_vector*)noise;
-        }
-
-        fit_error = cpl_fit_lvmq(x_mat, NULL,
-                                 y, sigma_y,
-                                 fit_par, valid,
-                                 &kmo_priv_lorentz1d_fnc, &kmo_priv_lorentz1d_fncd,
-                                 CPL_FIT_LVMQ_TOLERANCE,  /* 0.01 */
-                                 CPL_FIT_LVMQ_COUNT,      /* 5 */
-                                 CPL_FIT_LVMQ_MAXITER,    /* 1000 */
-                                 NULL,
-                                 &red_chisq,
-                                 &covariance);
-//printf("### 1st FIT ###################\n");
-//kmo_debug_vector(fit_par);
-//printf("ERROR: %d %s\n", fit_error);
-        if (fit_error == CPL_ERROR_CONTINUE)
-        {
-            KMO_TRY_RECOVER();
-
-            // try to fit again with previously fitted parameters
-            // and a LVMQ_COUNT of 2
-            fit_error = cpl_fit_lvmq(x_mat, NULL,
-                                    y, sigma_y,
-                                    fit_par, valid,
-                                    &kmo_priv_lorentz1d_fnc, &kmo_priv_lorentz1d_fncd,
-                                    CPL_FIT_LVMQ_TOLERANCE,  /* 0.01 */
-                                    2,//CPL_FIT_LVMQ_COUNT,      /* 5 */
-                                    CPL_FIT_LVMQ_MAXITER,    /* 1000 */
-                                    NULL,
-                                    &red_chisq,
-                                    &covariance);
-//printf("### 2nd FIT ###################\n");
-//kmo_debug_vector(fit_par);
-//printf("ERROR: %d\n", fit_error);
-            if (fit_error == CPL_ERROR_CONTINUE)
-            {
-                KMO_TRY_RECOVER();
-
-                // try to fit again a last time
-                // with first estimates and a LVMQ_COUNT of 1
-                cpl_vector_set(fit_par, 0, 0);
-                cpl_vector_set(fit_par, 1, max_val);
-                cpl_vector_set(fit_par, 2, max_pos);
-                cpl_vector_set(fit_par, 3, cdelt);
-                cpl_vector_set(fit_par, 4, 0.0);
-
-                fit_error = cpl_fit_lvmq(x_mat, NULL,
-                                        y, sigma_y,
-                                        fit_par, valid,
-                                        &kmo_priv_lorentz1d_fnc, &kmo_priv_lorentz1d_fncd,
-                                        CPL_FIT_LVMQ_TOLERANCE,  /* 0.01 */
-                                        1,//CPL_FIT_LVMQ_COUNT,      /* 5 */
-                                        CPL_FIT_LVMQ_MAXITER,    /* 1000 */
-                                        NULL,
-                                        &red_chisq,
-                                        &covariance);
-//printf("### 3rd FIT ###################\n");
-//kmo_debug_vector(fit_par);
-//printf("ERROR: %d\n", fit_error);
-
-                // if it didn't convert again, give up and take the
-                // estimated value
-                KMO_TRY_RECOVER();
-            }
-        }
-
-        if (pl != NULL) {
-            // put the fit parameters and errors into a propertylist
-            KMO_TRY_EXIT_IF_NULL(
-                pfit_par = cpl_vector_get_data(fit_par));
-
-            KMO_TRY_EXIT_IF_NULL(
-                *pl = cpl_propertylist_new());
-
-            KMO_TRY_EXIT_IF_ERROR(
-                kmclipm_update_property_double(*pl, FIT_MAX_PIX,
-                                               max_pos,
-                                            "[pix] position of the maximum"));
-            KMO_TRY_EXIT_IF_ERROR(
-                kmclipm_update_property_double(*pl, FIT_CENTROID,
-                                               pfit_par[2],
-                                           "[pix] position of the centroid"));
-            KMO_TRY_EXIT_IF_ERROR(
-                kmclipm_update_property_double(*pl, FIT_OFFSET,
-                                               pfit_par[0],
-                                               "[adu] offset/background"));
-            KMO_TRY_EXIT_IF_ERROR(
-                kmclipm_update_property_double(*pl, FIT_INTENSITY,
-                                               pfit_par[1],
-                                          "[adu] intensity of the function"));
-            KMO_TRY_EXIT_IF_ERROR(
-                kmclipm_update_property_double(*pl, FIT_SCALE,
-                                               pfit_par[3],
-                                               "[adu] scale"));
-
-            if (covariance == NULL) {
-//                cpl_msg_warning(cpl_func, "The function fit didn't converge! "
-//                                "The fitted function is anyway calculated, "
-//                                "but no errors can be provided. (Try to narrow "
-//                                "the range to fit!)");
-            } else {
-                // append errors to the propertylist
-                KMO_TRY_EXIT_IF_ERROR(
-                    kmclipm_update_property_double(*pl, FIT_RED_CHISQ,
-                                               red_chisq,
-                                    "[] reduced chi square of function fit"));
-                KMO_TRY_EXIT_IF_ERROR(
-                    kmclipm_update_property_double(*pl, FIT_ERR_OFFSET,
-                        sqrt(red_chisq * cpl_matrix_get(covariance, 0, 0)),
-                        "[adu] error in the offset/background"));
-                KMO_TRY_EXIT_IF_ERROR(
-                    kmclipm_update_property_double(*pl, FIT_ERR_INTENSITY,
-                        sqrt(red_chisq * cpl_matrix_get(covariance, 1, 1)),
-                        "[adu] error in the intensity of the function"));
-                KMO_TRY_EXIT_IF_ERROR(
-                    kmclipm_update_property_double(*pl, FIT_ERR_CENTROID,
-                        sqrt(red_chisq * cpl_matrix_get(covariance, 2, 2)),
-                        "[pix] error in the position of the centroid"));
-                KMO_TRY_EXIT_IF_ERROR(
-                    kmclipm_update_property_double(*pl, FIT_ERR_SCALE,
-                        sqrt(red_chisq * cpl_matrix_get(covariance, 3, 3)),
-                        "[adu] error in the scale"));
-            }
-        }
+    /* Check entries */
+    if (x==NULL || y==NULL) {
+        cpl_msg_error(__func__, "NULL inputs") ;
+        cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
+        return NULL ;
     }
-    KMO_CATCH
-    {
-//        KMO_CATCH_MSG();  // commented out to be more silent when
-                            // kmo_remove_line() can't fit a lorentz
-        cpl_vector_delete(fit_par); fit_par = NULL;
-        if (pl!=NULL) {
-            cpl_propertylist_delete(*pl); 
-            *pl = NULL;
-        }
+    if (cpl_vector_get_size(x) != cpl_vector_get_size(y)) {
+        cpl_msg_error(__func__, "x and y don't have same size") ;
+        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
+        return NULL ;
     }
+    
+    /* Initialise */
+    covariance = NULL ;
+    red_chisq = 0.0 ;
+    valid = NULL ;
 
+    /* Create Estimates */
+    cdelt = cpl_vector_get(x, 1) - cpl_vector_get(x, 0);
+    fit_par = cpl_vector_new(5);
+    cpl_vector_set(fit_par, 0, 0.0);
+    cpl_vector_set(fit_par, 1, -1*(peak_val-background_val));
+    cpl_vector_set(fit_par, 2, peak_pos);
+    cpl_vector_set(fit_par, 3, 3 * cdelt);
+    cpl_vector_set(fit_par, 4, 0.0);
 
-    cpl_matrix_unwrap(x_mat);
-    cpl_matrix_delete(covariance); covariance = NULL;
-
-    if (noise == NULL) {
-        cpl_vector_delete(sigma_y); sigma_y = NULL;
+    /* Plot in debug mode */
+    if (cpl_msg_get_level() == CPL_MSG_DEBUG) {
+        kmos_fit_lorentz_plot(x, y, fit_par, peak_pos, 0) ;
     }
 
     if (fit_linear == FALSE) {
-        cpl_free(valid); valid = NULL;
+        valid = (int*)cpl_malloc(5*sizeof(int));
+        valid[0] = 1.0;
+        valid[1] = 1.0;
+        valid[2] = 1.0;
+        valid[3] = 1.0;
+        valid[4] = 0.0;
     }
 
+    x_mat = cpl_matrix_wrap(cpl_vector_get_size(x), 1, 
+            cpl_vector_get_data(x));
+
+    /* if no noise is provided, create a sigma-vector filled with ones */
+    if (noise == NULL) {
+        sigma_y = cpl_vector_new(cpl_vector_get_size(x));
+        cpl_vector_fill(sigma_y, 1.0);
+    } else {
+        sigma_y = noise;
+    }
+
+    if ((fit_error = cpl_fit_lvmq(x_mat, NULL, y, sigma_y, fit_par, valid,
+            &kmo_priv_lorentz1d_fnc, &kmo_priv_lorentz1d_fncd,
+            CPL_FIT_LVMQ_TOLERANCE, CPL_FIT_LVMQ_COUNT, CPL_FIT_LVMQ_MAXITER,
+            NULL, &red_chisq, &covariance)) != CPL_ERROR_NONE) {
+        cpl_error_reset() ;
+
+        cpl_msg_warning(__func__, "Cannot fit the line") ;
+        /* Try to fit again with previously fitted parameters */
+        if ((fit_error = cpl_fit_lvmq(x_mat, NULL, y, sigma_y, fit_par, valid,
+                        &kmo_priv_lorentz1d_fnc, &kmo_priv_lorentz1d_fncd,
+                        CPL_FIT_LVMQ_TOLERANCE, 2, CPL_FIT_LVMQ_MAXITER, NULL,
+                        &red_chisq, &covariance)) != CPL_ERROR_NONE) {
+            cpl_error_reset() ;
+
+            /* Try to fit again a last time */
+            cpl_vector_set(fit_par, 0, 0.0);
+            cpl_vector_set(fit_par, 1, peak_val-background_val);
+            cpl_vector_set(fit_par, 2, peak_pos);
+            cpl_vector_set(fit_par, 3, 3 * cdelt);
+            cpl_vector_set(fit_par, 4, 0.0);
+
+            if ((fit_error = cpl_fit_lvmq(x_mat, NULL, y, sigma_y, fit_par, 
+                            valid, &kmo_priv_lorentz1d_fnc, 
+                            &kmo_priv_lorentz1d_fncd, CPL_FIT_LVMQ_TOLERANCE, 
+                            1, CPL_FIT_LVMQ_MAXITER, NULL, &red_chisq, 
+                            &covariance)) != CPL_ERROR_NONE) {
+                /* give up and take the estimated value */
+                cpl_error_reset() ;
+            }
+        }
+    }
+    cpl_matrix_unwrap(x_mat);
+    if (noise == NULL) cpl_vector_delete(sigma_y);
+    if (fit_linear == FALSE) cpl_free(valid); 
+
+    /* Plot in debug mode */
+    if (cpl_msg_get_level() == CPL_MSG_DEBUG) {
+        kmos_fit_lorentz_plot(x, y, fit_par, peak_pos, 1) ;
+    }
+
+    /* Put the fit parameters and errors into a propertylist */
+    if (pl != NULL) {
+        pfit_par = cpl_vector_get_data(fit_par);
+        *pl = cpl_propertylist_new();
+        kmclipm_update_property_double(*pl, FIT_MAX_PIX, peak_pos,
+                "[pix] position of the maximum");
+        kmclipm_update_property_double(*pl, FIT_CENTROID, pfit_par[2],
+                "[pix] position of the centroid");
+        kmclipm_update_property_double(*pl, FIT_OFFSET, pfit_par[0],
+                "[adu] offset/background");
+        kmclipm_update_property_double(*pl, FIT_INTENSITY, pfit_par[1],
+                "[adu] intensity of the function");
+        kmclipm_update_property_double(*pl, FIT_SCALE, pfit_par[3],
+                "[adu] scale");
+
+        /* Append errors to the propertylist */
+        if (covariance != NULL) {
+            kmclipm_update_property_double(*pl, FIT_RED_CHISQ, red_chisq,
+                    "[] reduced chi square of function fit");
+            kmclipm_update_property_double(*pl, FIT_ERR_OFFSET, 
+                    sqrt(red_chisq * cpl_matrix_get(covariance, 0, 0)),
+                    "[adu] error in the offset/background");
+            kmclipm_update_property_double(*pl, FIT_ERR_INTENSITY,
+                    sqrt(red_chisq * cpl_matrix_get(covariance, 1, 1)),
+                    "[adu] error in the intensity of the function");
+            kmclipm_update_property_double(*pl, FIT_ERR_CENTROID,
+                    sqrt(red_chisq * cpl_matrix_get(covariance, 2, 2)),
+                    "[pix] error in the position of the centroid");
+            kmclipm_update_property_double(*pl, FIT_ERR_SCALE,
+                    sqrt(red_chisq * cpl_matrix_get(covariance, 3, 3)),
+                    "[adu] error in the scale");
+        }
+    }
+
+    /* Free and return  */
+    if (covariance != NULL) cpl_matrix_delete(covariance);
     return fit_par;
 }
 
+static int kmos_fit_lorentz_plot(
+        const cpl_vector    *   x,
+        const cpl_vector    *   y_spec,
+        const cpl_vector    *   fit_par, 
+        double                  peak_pos, 
+        int                     fitted)
+{
+	char        *   title ;
+    double          x_array[1] ;
+    double          y_array[1] ;
+    cpl_vector  *   y ;
+    double      *   py ;
+    int             i ;
+
+    /* if (peak_pos != 1.27882) return 0 ; */
+
+    /* Create the vector to plot */
+    y = cpl_vector_duplicate(x) ;
+    py = cpl_vector_get_data(y) ;
+    for (i = 0; i < cpl_vector_get_size(y); i++) {
+        x_array[0] = cpl_vector_get(x, i);
+        kmo_priv_lorentz1d_fnc(x_array, cpl_vector_get_data_const(fit_par), 
+                y_array);
+        py[i] = y_array[0];
+    }
+
+    if (fitted) {
+        title = cpl_sprintf("t 'Fitted (%g)' w lines", peak_pos) ;
+    } else {
+        /* Plot the spectrum to fit */
+        title = cpl_sprintf("t 'Spectrum to Fit (%g)' w lines", peak_pos) ;
+        cpl_plot_vector("set grid;", title, "", y_spec);
+        cpl_free(title) ;
+
+        /* Plot the guess */
+        title = cpl_sprintf("t 'Guess (%g)' w lines", peak_pos) ;
+    }
+	cpl_plot_vector("set grid;", title, "", y);
+	cpl_free(title) ;
+    cpl_vector_delete(y) ;
+    return 0 ;
+}
+
 /**
     @brief
         Fits a 2D gauss to an image.
