@@ -497,8 +497,13 @@ int kmo_priv_fits_stack(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         switch(cpl_propertylist_get_int(header, NAXIS)) {
                             case 3:
                                 z = cpl_propertylist_get_int(header, NAXIS3);
+                                y = cpl_propertylist_get_int(header, NAXIS2);
+                                x = cpl_propertylist_get_int(header, NAXIS1);
+                                break;
                             case 2:
                                 y = cpl_propertylist_get_int(header, NAXIS2);
+                                x = cpl_propertylist_get_int(header, NAXIS1);
+                                break;
                             case 1:
                                 x = cpl_propertylist_get_int(header, NAXIS1);
                                 break;
@@ -639,7 +644,6 @@ int kmo_priv_fits_stack(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
                 // rewind file and read now values and fill into table
                 int br = FALSE,
-                    j = 0,
                     cnt = FALSE;
                 char line[2000],
                      *pEnd = NULL,
@@ -1163,7 +1167,7 @@ int kmo_priv_fits_stack(cpl_parameterlist *parlist, cpl_frameset *frameset)
             }
 
             // add additional KMOS keywords to sub-header
-            int j = 0;
+            j = 0;
             if (subkey_values != NULL) {
                 while (subkey_values[j] != NULL) {
                     if (strcmp("string", subkey_values[j+1]) == 0) {
