@@ -181,6 +181,7 @@ void kmos_band_pars_create(
     cpl_free(tmpstr);
 
     /* --b_start */
+    /*
     tmpstr = cpl_sprintf("%s.%s", recipe_name, "b_start");
     p = cpl_parameter_new_value(tmpstr, CPL_TYPE_DOUBLE,
             "The lowest wavelength [um] to use when reconstructing. "
@@ -190,8 +191,10 @@ void kmos_band_pars_create(
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(pl, p);
     cpl_free(tmpstr);
+    */
 
     /* --b_end */
+    /*
     tmpstr = cpl_sprintf("%s.%s", recipe_name, "b_end");
     p = cpl_parameter_new_value(tmpstr, CPL_TYPE_DOUBLE,
             "The highest wavelength [um] to use when reconstructing. "
@@ -201,6 +204,7 @@ void kmos_band_pars_create(
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(pl, p);
     cpl_free(tmpstr);
+    */
 
     return ;
 }
@@ -345,7 +349,6 @@ cpl_error_code kmos_band_pars_load(
         const char          *   recipe_name)
 {
     char    *   tmpstr ;
-    double      tol ;
    
     /* Check Entries */
     if (pl ==NULL || recipe_name == NULL) {
@@ -355,7 +358,6 @@ cpl_error_code kmos_band_pars_load(
     }
     
     /* Initialise */
-    tol = 0.001;
 
     /* b_samples */
     tmpstr = cpl_sprintf("%s.%s", recipe_name, "b_samples");
@@ -368,31 +370,35 @@ cpl_error_code kmos_band_pars_load(
     }
 
     /* b_start */
+    /*
     tmpstr = cpl_sprintf("%s.%s", recipe_name, "b_start");
     kmclipm_band_start = kmo_dfs_get_parameter_double(pl, tmpstr);
     cpl_free(tmpstr);
 
     if (!(fabs(kmclipm_band_start + 1.0) < tol)) {
-        /* Check only if value has been provided */
+        // Check only if value has been provided
         if (kmclipm_band_start <= 0.0) {
             cpl_msg_error(__func__, "b_start must be greater than 0.0") ;
             cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
             return CPL_ERROR_ILLEGAL_INPUT ;
         }
     }
+    */
 
     /* b_end */
+    /*
     tmpstr = cpl_sprintf("%s.%s", recipe_name, "b_end");
     kmclipm_band_end = kmo_dfs_get_parameter_double(pl, tmpstr);
     cpl_free(tmpstr); 
     if (!(fabs(kmclipm_band_end + 1.0) < tol)) {
-        /* Check only if value has been provided */
+        // Check only if value has been provided
         if (kmclipm_band_end <= kmclipm_band_start) {
             cpl_msg_error(__func__, "b_end must be greater than b_start") ;
             cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
             return CPL_ERROR_ILLEGAL_INPUT ;
         }
     }
+    */
     return CPL_ERROR_NONE;
 }
 
@@ -1718,10 +1724,12 @@ cpl_error_code  kmo_check_frame_setup_sampling(cpl_frameset *frameset)
 {
     cpl_error_code      ret_error       = CPL_ERROR_NONE;
     cpl_propertylist    *mainLcal       = NULL,
-                        *mainTell       = NULL;
+                        *mainTell       = NULL,
+                        *mainTellGen    = NULL;
     int                 matchError      = FALSE;
     const char          *b_lcal         = NULL,
-                        *b_tell         = NULL;
+                        *b_tell         = NULL,
+                        *b_tellgen      = NULL;
 
     KMO_TRY
     {
@@ -1746,39 +1754,32 @@ cpl_error_code  kmo_check_frame_setup_sampling(cpl_frameset *frameset)
                 cpl_msg_warning("","***  The parameter b_samples isn't the same in LCAL and TELLURIC!  ***");
                 cpl_msg_warning("","***     ==> LCAL (%s) and TELLURIC (%s)", b_lcal, b_tell);
             }
+        }
 
-            // check if b_start is equal
+        mainTellGen = kmo_dfs_load_primary_header(frameset, TELLURIC_GEN);
+        if (mainTellGen != NULL) {
+            // check if b_samples is equal
             KMO_TRY_EXIT_IF_NULL(
-                b_lcal =  kmo_get_pro_keyword_val(mainLcal, "b_start"));
+                b_lcal =  kmo_get_pro_keyword_val(mainLcal, "b_samples"));
             KMO_TRY_EXIT_IF_NULL(
-                b_tell =  kmo_get_pro_keyword_val(mainTell, "b_start"));
+                b_tellgen =  kmo_get_pro_keyword_val(mainTellGen, "b_samples"));
 
-            if (strcmp(b_lcal, b_tell) != 0) {
+            if (strcmp(b_lcal, b_tellgen) != 0) {
                 matchError = TRUE;
-                cpl_msg_warning("","***  The parameter b_start isn't the same in LCAL and TELLURIC!    ***");
-                cpl_msg_warning("","***     ==> LCAL (%s) and TELLURIC (%s)", b_lcal, b_tell);
-            }
-
-            // check if b_end is equal
-            KMO_TRY_EXIT_IF_NULL(
-                b_lcal =  kmo_get_pro_keyword_val(mainLcal, "b_end"));
-            KMO_TRY_EXIT_IF_NULL(
-                b_tell =  kmo_get_pro_keyword_val(mainTell, "b_end"));
-
-            if (strcmp(b_lcal, b_tell) != 0) {
-                matchError = TRUE;
-                cpl_msg_warning("","***  The parameter b_end isn't the same in LCAL and TELLURIC!      ***");
-                cpl_msg_warning("","***     ==> LCAL (%s) and TELLURIC (%s)", b_lcal, b_tell);
-            }
-
-            if (matchError) {
-                cpl_msg_warning("","***                                                                ***");
-                cpl_msg_warning("","***        The recipe will be executed, but the                    ***");
-                cpl_msg_warning("","***        results should be mistrusted !!!                        ***");
                 cpl_msg_warning("","**********************************************************************");
                 cpl_msg_warning("","**********************************************************************");
+                cpl_msg_warning("","***  The parameter b_samples isn't the same in LCAL and TELLURIC_GEN!  ***");
+                cpl_msg_warning("","***     ==> LCAL (%s) and TELLURIC_GEN (%s)", b_lcal, b_tellgen);
             }
         }
+
+        if (matchError) {
+            cpl_msg_warning("","***                                                                ***");
+            cpl_msg_warning("","***        The recipe will be executed, but the                    ***");
+            cpl_msg_warning("","***        results should be mistrusted !!!                        ***");
+            cpl_msg_warning("","**********************************************************************");
+            cpl_msg_warning("","**********************************************************************");
+        }
     }
     KMO_CATCH
     {
@@ -1787,6 +1788,7 @@ cpl_error_code  kmo_check_frame_setup_sampling(cpl_frameset *frameset)
     }
     cpl_propertylist_delete(mainLcal); mainLcal = NULL;
     cpl_propertylist_delete(mainTell); mainTell = NULL;
+    cpl_propertylist_delete(mainTellGen); mainTellGen = NULL;
     return ret_error;
 }
 
