@@ -126,13 +126,4 @@ const char*         kmo_get_pro_keyword_val(
 cpl_error_code      kmo_check_frame_setup_sampling(
                                 cpl_frameset *frameset);
 
-kmclipm_vector*     kmo_tweak_load_telluric(cpl_frameset *frameset,
-                                int ifu_nr,
-                                int is_noise,
-                                int no_subtract);
-
-int                 kmo_tweak_find_ifu(
-                                cpl_frameset *frameset,
-                                int ifu_nr);
-
 #endif
