@@ -249,8 +249,8 @@ cpl_image *kmo_lcorr_create_object_mask (const cpl_imagelist *cube,
     double l_low, l_up = 0.0;
     double max_value = 0.0;
     int *cnts = NULL;
-    const double *m_data   = NULL;
-    float        *mask_data = NULL;
+    double *m_data    = NULL;
+    float  *mask_data = NULL;
 
     KMO_TRY
     {
@@ -319,9 +319,9 @@ cpl_image *kmo_lcorr_create_object_mask (const cpl_imagelist *cube,
         KMO_TRY_EXIT_IF_NULL(
                 m_img =  cpl_image_cast(tmp_img, CPL_TYPE_DOUBLE));
        KMO_TRY_EXIT_IF_NULL(
-                m_data = cpl_image_get_data_double_const(m_img));
+                m_data = cpl_image_get_data_double(m_img));
         KMO_TRY_EXIT_IF_NULL(
-                m_vector = cpl_vector_wrap(nx * ny, (double *) m_data));
+                m_vector = cpl_vector_wrap(nx * ny, m_data));
         KMO_TRY_EXIT_IF_NULL(
                 sorted_sum = cpl_vector_duplicate(m_vector));
         cpl_vector_sort(sorted_sum, CPL_SORT_ASCENDING);
@@ -514,14 +514,14 @@ cpl_bivector *kmo_lcorr_read_reference_spectrum(const char *filename, const cpl_
 
             vsize = cpl_vector_get_size(lambda);
 
+            KMO_TRY_EXIT_IF_NULL(
+                    lambda_out = cpl_vector_duplicate(lambda));
+
             spec_data = cubicspline_reg_irreg(naxis1, crval + (1-crpix)*cdelt, cdelt, file_data,
-                vsize, (double *) cpl_vector_get_data_const(lambda), NATURAL);
+                vsize, cpl_vector_get_data(lambda_out), NATURAL);
 
             KMO_TRY_EXIT_IF_NULL(
                 spec_out = cpl_vector_wrap(vsize, spec_data));
-
-            KMO_TRY_EXIT_IF_NULL(
-                    lambda_out = cpl_vector_duplicate(lambda));
         }
 
         KMO_TRY_EXIT_IF_NULL(
@@ -756,7 +756,7 @@ double fit_peak (const cpl_bivector *spectrum, const cpl_size size, double lambd
     const double sqrt2pi = sqrt(2. * 3.14159265358979323846);
 
     sigma = *sigma_par;
-    if (IDL !=NULL ) fprintf(IDL, "%20s:  %f  %d %d %f\n","fitpeak input",  lambda_in, half_width, size, sigma);
+    if (IDL !=NULL ) fprintf(IDL, "%20s:  %f  %d %lld %f\n", "fitpeak input",  lambda_in, half_width, size, sigma);
 
     if ((lambda_in < cpl_vector_get(cpl_bivector_get_x_const(spectrum),  0)) ||
         (lambda_in > cpl_vector_get(cpl_bivector_get_x_const(spectrum),size-1))) {
@@ -779,9 +779,9 @@ double fit_peak (const cpl_bivector *spectrum, const cpl_size size, double lambd
     vy = cpl_vector_extract(cpl_bivector_get_y_const(spectrum), low_bound, high_bound, 1);
 //    printf("low: %5d   high: %5d    lamda_in: %f\n", low_bound, high_bound, lambda_in);
     if (IDL !=NULL ) {
-        fprintf(IDL, "%20s:  %d %d %d\n", "fitpeak selection",  low_bound, high_bound, cpl_vector_get_size(vx));
-        fprintf(IDL, "%20s: %d", "fitpeak vx",cpl_vector_get_size(vx)); cpl_vector_dump(vx, IDL);
-        fprintf(IDL, "%20s: %d", "fitpeak vy",cpl_vector_get_size(vx)); cpl_vector_dump(vy, IDL);
+        fprintf(IDL, "%20s: %lld %lld %lld\n", "fitpeak selection",  low_bound, high_bound, cpl_vector_get_size(vx));
+        fprintf(IDL, "%20s: %lld",             "fitpeak vx", cpl_vector_get_size(vx)); cpl_vector_dump(vx, IDL);
+        fprintf(IDL, "%20s: %lld",             "fitpeak vy", cpl_vector_get_size(vx)); cpl_vector_dump(vy, IDL);
     }
     if (high_bound-low_bound < 4) {
         if (vx != NULL) {cpl_vector_delete(vx);}
@@ -922,7 +922,7 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
             resolution = 1800.;
         } else if (strcmp(band_id, "IZ") == 0) {
             resolution = 3200.;
-        } else if (strcmp(band_id, "YJ") == 0) {
+        } else { /* if (strcmp(band_id, "YJ") == 0) { */
             resolution = 3200.;
         }
 
@@ -930,12 +930,12 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
         ref_size = cpl_bivector_get_size(reference);
         no_peaks = cpl_vector_get_size(peaks);
         if (IDL !=NULL ) {
-            fprintf(IDL, "%20s: %d %d %d %f\n", "xcorr input", obj_size, ref_size, no_peaks, resolution);
-            fprintf(IDL, "%20s: %d ", "xcorr object_l", obj_size); cpl_vector_dump(cpl_bivector_get_x_const(object), IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr object_v", obj_size); cpl_vector_dump(cpl_bivector_get_y_const(object), IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr reference_l", ref_size); cpl_vector_dump(cpl_bivector_get_x_const(reference), IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr reference_v", ref_size); cpl_vector_dump(cpl_bivector_get_y_const(reference), IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr peaks", no_peaks); cpl_vector_dump(peaks, IDL);
+            fprintf(IDL, "%20s: %lld %lld %lld %f\n", "xcorr input", obj_size, ref_size, no_peaks, resolution);
+            fprintf(IDL, "%20s: %lld ", "xcorr object_l",    obj_size); cpl_vector_dump(cpl_bivector_get_x_const(object), IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr object_v",    obj_size); cpl_vector_dump(cpl_bivector_get_y_const(object), IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr reference_l", ref_size); cpl_vector_dump(cpl_bivector_get_x_const(reference), IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr reference_v", ref_size); cpl_vector_dump(cpl_bivector_get_y_const(reference), IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr peaks",       no_peaks); cpl_vector_dump(peaks, IDL);
         }
 
         KMO_TRY_ASSURE(obj_size > 1 && ref_size > 1 ,
@@ -1016,9 +1016,9 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
         KMO_TRY_EXIT_IF_ERROR(
                 cpl_vector_set_size(sigma_tmp,peak_idx));
         if (IDL !=NULL ) {
-            fprintf(IDL, "%20s: %d ", "xcorr lambda_ref", peak_idx); cpl_vector_dump(lambda_ref, IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr lambda_tmp", peak_idx); cpl_vector_dump(lambda_tmp, IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr sigma_tmp", peak_idx); cpl_vector_dump(sigma_tmp, IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr lambda_ref", peak_idx); cpl_vector_dump(lambda_ref, IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr lambda_tmp", peak_idx); cpl_vector_dump(lambda_tmp, IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr sigma_tmp",  peak_idx); cpl_vector_dump(sigma_tmp,  IDL);
         }
 
         KMO_TRY_EXIT_IF_ERROR(
@@ -1102,9 +1102,9 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
         KMO_TRY_EXIT_IF_ERROR(
                 cpl_vector_set_size(sigma_tmp,peak_idx));
         if (IDL !=NULL ) {
-            fprintf(IDL, "%20s: %d ", "xcorr lambda_ref", peak_idx); cpl_vector_dump(lambda_ref, IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr lambda_tmp", peak_idx); cpl_vector_dump(lambda_tmp, IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr sigma_tmp", peak_idx); cpl_vector_dump(sigma_tmp, IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr lambda_ref", peak_idx); cpl_vector_dump(lambda_ref, IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr lambda_tmp", peak_idx); cpl_vector_dump(lambda_tmp, IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr sigma_tmp",  peak_idx); cpl_vector_dump(sigma_tmp, IDL);
         }
 
         KMO_TRY_EXIT_IF_ERROR(
@@ -1144,7 +1144,7 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
         KMO_TRY_EXIT_IF_NULL(
 			     dbg_msg = cpl_malloc((no_peaks * 2 + 1) * sizeof(char)));
 	dbg_msg[no_peaks*2] = '\0';
-        if (IDL !=NULL ) fprintf(IDL, "%20s: %d", "xcorr invalid peaks", no_peaks);
+        if (IDL !=NULL ) fprintf(IDL, "%20s: %lld", "xcorr invalid peaks", no_peaks);
         for (i = 0; i < no_peaks; i++){
 	    sprintf(&dbg_msg[2*i], "%2d", invalid_index[i]);
             if (invalid_index[i] == 0) {
@@ -1179,9 +1179,9 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
             }
         }
         if (IDL !=NULL ) {
-            fprintf(IDL, "%20s: %d ", "xcorr final_obj_in", no_valid_peaks); cpl_vector_dump(final_obj_in, IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr final_obj_fit", no_valid_peaks); cpl_vector_dump(final_obj_fit, IDL);
-            fprintf(IDL, "%20s: %d ", "xcorr final_obj_diff", no_valid_peaks); cpl_vector_dump(final_obj_diff, IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr final_obj_in",   no_valid_peaks); cpl_vector_dump(final_obj_in,   IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr final_obj_fit",  no_valid_peaks); cpl_vector_dump(final_obj_fit,  IDL);
+            fprintf(IDL, "%20s: %lld ", "xcorr final_obj_diff", no_valid_peaks); cpl_vector_dump(final_obj_diff, IDL);
         }
 
         cpl_size degree[1] = {2};
@@ -1206,7 +1206,7 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
 
         if (IDL !=NULL ) {
             cpl_size pows[1];
-            fprintf(IDL, "%20s: %d", "xcorr polyfit", cpl_polynomial_get_degree(coeffs));
+            fprintf(IDL, "%20s: %lld", "xcorr polyfit", cpl_polynomial_get_degree(coeffs));
             for (i = 0; i <= cpl_polynomial_get_degree(coeffs); i++) {
                 pows[0] = i;
                 fprintf(IDL, " %f", cpl_polynomial_get_coeff(coeffs,pows));
@@ -1237,7 +1237,7 @@ cpl_polynomial *kmo_lcorr_crosscorrelate_spectra(
 void kmo_lcorr_open_debug_file (char* filename) {
     IDL = fopen(filename,"w");
 }
-void kmo_lcorr_close_debug_file () {
+void kmo_lcorr_close_debug_file (void) {
     fclose(IDL);
     IDL = NULL;
 }
