@@ -493,7 +493,7 @@ cpl_vector* kmo_interpolate_vector_wcs(const cpl_frame *frame,
                                  same length.
 */
 cpl_error_code kmo_divide_blackbody(cpl_vector *ydata,
-                                    const cpl_vector *xdata,
+                                    cpl_vector *xdata,
                                     double temperature)
 {
     cpl_error_code  ret_err = CPL_ERROR_NONE;
@@ -558,15 +558,18 @@ cpl_error_code kmo_divide_blackbody(cpl_vector *ydata,
             KMO_TRY_EXIT_IF_NULL(
                     plots[1] = cpl_bivector_wrap_vectors((cpl_vector*)xdata,
                                                          ydata));
-            char *options[2] = {"w l t 'input'",
-                                "w l t 'divided by blackbody'"};
+            const char *options[] = {"w l t 'input'",
+                                     "w l t 'divided by blackbody'"};
+
+            CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
             KMO_TRY_EXIT_IF_ERROR(
                     error_code = cpl_plot_bivectors(
                             "set datafile missing 'nan';"
                             "set title 'blackbody division';",
-                            (const char**)options,
+                            options,
                             "",
                             (const cpl_bivector**)plots, 2));
+            CPL_DIAG_PRAGMA_POP;
         }
     }
     KMO_CATCH
@@ -620,7 +623,7 @@ cpl_error_code kmo_remove_line(
     double              *   pbase ;
     double                  x_array[1] ;
     double                  y_array[1] ;
-    double                  min ;
+    double                  min, max ;
     int                     lowIndex, highIndex, i ;
 
     /* Check entries */
@@ -668,16 +671,10 @@ cpl_error_code kmo_remove_line(
     /* Divide by atmos */
     cpl_vector_divide(spectrum_range, atmos_range);
 
-    /*
-    if (line_center == 0.88635) {
-        cpl_plot_vector("set grid;", "t 'line to fit' w lines", "",
-                spectrum_range);
-    }
-    */
-
     min = cpl_vector_get_min(spectrum_range);
+    max = cpl_vector_get_max(spectrum_range);
     if ((fit_par = kmo_vector_fit_lorentz(lambda_range, spectrum_range, NULL, 
-            line_center, min, NULL, 1)) == NULL) {
+            line_center, min, max, NULL, 1)) == NULL) {
         cpl_msg_warning("","   Couldn't identify the line at %g [um]", 
                 line_center);
         cpl_error_reset();
@@ -694,15 +691,6 @@ cpl_error_code kmo_remove_line(
         }
         cpl_vector_delete(fit_par) ;
 
-        /*
-        if (line_center == 0.88635) {
-            cpl_plot_vector("set grid;", "t 'line to fit' w lines", "",
-                    spectrum_range);
-            cpl_plot_vector("set grid;", "t 'Fitted' w lines", "",
-                    fit);
-        }
-        */ 
-
         cpl_vector_multiply(spectrum_range, atmos_range);
         cpl_msg_info(__func__, "Removed line at %g [um]", line_center);
     }
@@ -1094,7 +1082,7 @@ cpl_error_code kmo_calc_mean_throughput(double *throughput,
     @li CPL_ERROR_NULL_INPUT    if any of the inputs is NULL or fmethod is
                                 empty or cube is empty.
 */
-cpl_error_code kmo_calculate_std_trace(const cpl_imagelist *cube,
+cpl_error_code kmo_calculate_std_trace(cpl_imagelist *cube,
                                        const char *fmethod,
                                        double *std_trace)
 {
@@ -1138,7 +1126,7 @@ cpl_error_code kmo_calculate_std_trace(const cpl_imagelist *cube,
         cnt = 0;
         for (i = 300; i <=400; i++) {
             KMO_TRY_EXIT_IF_NULL(
-                tmp_img = cpl_imagelist_get((cpl_imagelist*)cube, i));
+                tmp_img = cpl_imagelist_get(cube, i));
             KMO_TRY_EXIT_IF_ERROR(
                 cpl_imagelist_set(cube1, cpl_image_duplicate(tmp_img), cnt++));
         }
@@ -1146,7 +1134,7 @@ cpl_error_code kmo_calculate_std_trace(const cpl_imagelist *cube,
         cnt = 0;
         for (i = 1600; i <=1700; i++) {
             KMO_TRY_EXIT_IF_NULL(
-                tmp_img = cpl_imagelist_get((cpl_imagelist*)cube, i));
+                tmp_img = cpl_imagelist_get(cube, i));
             KMO_TRY_EXIT_IF_ERROR(
                 cpl_imagelist_set(cube2, cpl_image_duplicate(tmp_img), cnt++));
         }
@@ -1469,7 +1457,7 @@ void kmo_delete_skySkyStruct(skySkyStruct *sky_sky_struct)
         for (i = 0; i < KMOS_NR_IFUS; i++) {
             cpl_free(sky_sky_struct[i].skyPairs); sky_sky_struct[i].skyPairs = NULL;
         }
-        cpl_free(sky_sky_struct); sky_sky_struct = NULL;
+        cpl_free(sky_sky_struct);
     }
 }
 
