@@ -74,7 +74,7 @@ cpl_vector*             kmo_interpolate_vector_wcs(
 
 cpl_error_code          kmo_divide_blackbody(
                                     cpl_vector *ydata,
-                                    const cpl_vector *xdata,
+                                    cpl_vector *xdata,
                                     double temperature);
 
 cpl_error_code          kmo_remove_line(cpl_vector *spectrum,
@@ -115,7 +115,7 @@ cpl_error_code          kmo_calc_mean_throughput(
                                     double *stdev);
 
 cpl_error_code          kmo_calculate_std_trace(
-                                    const cpl_imagelist *cube,
+                                    cpl_imagelist *cube,
                                     const char * fmethod,
                                     double *std_trace);
 
