@@ -27,30 +27,30 @@
 #include <cpl.h>
 #include "kmclipm_vector.h"
 
-/** @brief Available calibration lamps configurations */
-enum lampConfiguration {ARGON, NEON, ARGON_NEON};
+typedef enum {
+    ARGON, 
+    NEON, 
+    ARGON_NEON
+} lampConfiguration;
 
 /*------------------------------------------------------------------------------
  *                        Prototypes
  *----------------------------------------------------------------------------*/
 
-cpl_bivector * kmo_get_lines(
+cpl_bivector * kmos_get_lines(
         const cpl_table         *   arclines,
-        enum lampConfiguration      lamp_config) ;
+        lampConfiguration           lamp_config) ;
 
 cpl_error_code kmos_calc_wave_calib(
         const cpl_image     *   data,
         const cpl_image     *   bad_pix,
-        const cpl_image     *   xcal,
-        const cpl_image     *   ycal,
         const char          *   filter_id,
-        enum lampConfiguration  lamp_config,
+        lampConfiguration       lamp_config,
         const int               detector_nr,
         cpl_array           *   ifu_inactive,
         cpl_table           **  edge_table,
-        const cpl_bivector  *   lines,
-        const cpl_table     *   reflines,
-        double                  disp,
+        cpl_bivector        *   lines,
+        cpl_table           *   reflines,
         cpl_image           **  lcal,
         double              *   qc_ar_eff,
         double              *   qc_ne_eff,
@@ -69,7 +69,7 @@ cpl_image * kmo_reconstructed_arc_image(
         int                 device_nr,
         const char      *   suffix,
         const char      *   filter_id,
-        enum lampConfiguration  lamp_config,
+        lampConfiguration   lamp_config,
         cpl_propertylist ** qc_header) ;
 
 double kmo_calc_fitted_slitlet_edge(
