@@ -605,7 +605,8 @@ cpl_error_code kmos_molecfit_load_spectrums(
   }
 
   /* In KMOS IFU STAR_SPEC = {DATA,NOISE}. The odd extension are .DATA (1,3,...,N_EXTENSIONS-1) and the even extension are .NOISE (2,4,...,N_EXTENSIONS) */
-  cpl_msg_info(cpl_func, "Loading data spectrums ('%s') from the file: '%s', rot_angle=%f (more close=%d)", tag, fileData, conf->rot_angle, rot_angle_close);
+  cpl_msg_info(cpl_func, "Loading ('%s') from the file: '%s', rot_angle=%f (more close=%d)",
+               tag, fileData, conf->rot_angle, rot_angle_close);
   for (cpl_size n_ifu = 0; n_ifu < N_IFUS; n_ifu++) {
 
       /* Get and initialize a specific ifu */
@@ -618,15 +619,15 @@ cpl_error_code kmos_molecfit_load_spectrums(
       ifu->kernel.ext               = (n_ifu * 6) + (rot_angle_close / 60) + 1;
 
       /* Load data */
-      if (       strcmp(tag, STAR_SPEC         ) == 0 ||
-          strcmp(tag, EXTRACT_SPEC      ) == 0 ){
+      if (   strcmp(tag, STAR_SPEC   ) == 0
+          || strcmp(tag, EXTRACT_SPEC) == 0 ){
 
           if (kmos_molecfit_load_spectrum_1D(ifu, fileData, (ext24 == 1)) != CPL_ERROR_NONE) {
               return cpl_error_get_code();
           }
 
-      } else if (strcmp(tag, SCIENCE           ) == 0 ||
-          strcmp(tag, RECONSTRUCTED_CUBE) == 0 ){
+      } else if (   strcmp(tag, SCIENCE           ) == 0
+                 || strcmp(tag, RECONSTRUCTED_CUBE) == 0 ){
 
           if (kmos_molecfit_load_spectrum_3D(ifu, fileData, (ext24 == 1), recipe_name, conf->ifus) != CPL_ERROR_NONE) {
               return cpl_error_get_code();
@@ -688,7 +689,7 @@ static cpl_error_code kmos_molecfit_load_spectrum_1D(
       ifu->header_1D_data = NULL;
       ifu->data           = NULL;
 
-      cpl_msg_info(cpl_func, "IFU.%02d - Extension: %02d:%s --> Properties charged.",	ifu->num, ifu->ext, ifu->name);
+      cpl_msg_info(cpl_func, "IFU.%02d - Extension: %02d:%s --> Properties charged (No data).",	ifu->num, ifu->ext, ifu->name);
 
   } else {
 
@@ -756,8 +757,8 @@ static cpl_error_code kmos_molecfit_load_spectrum_3D(
 
       /* It's not an IFU mapping */
       ifu->data = NULL;
-      cpl_msg_info(cpl_func, "IFU.%02d - Extension: %02d:%s --> Properties charged (Not IFU mapping).",
-                   ifu->num, ifu->ext, ifu->name);
+      cpl_msg_info(cpl_func, "IFU.%02d - Extension[%02d]=%s (Mapping IFU.%02d) --> Only properties charged (Not match the mapping).",
+                   ifu->num, ifu->ext, ifu->name, ifu->map);
 
   } else {
 
@@ -788,7 +789,8 @@ static cpl_error_code kmos_molecfit_load_spectrum_3D(
               ifu->header_1D_data = NULL;
               ifu->data           = NULL;
 
-              cpl_msg_info(cpl_func, "IFU.%02d - Extension: %02d:%s --> Properties charged.",	ifu->num, ifu->ext, ifu->name);
+              cpl_msg_info(cpl_func, "IFU.%02d - Extension[%02d]=%s (Mapping IFU.%02d) --> Properties charged.",
+                           ifu->num, ifu->ext, ifu->name, ifu->map);
 
           } else {
 
@@ -802,8 +804,8 @@ static cpl_error_code kmos_molecfit_load_spectrum_3D(
               }
               cpl_vector_delete(data);
 
-              cpl_msg_info(cpl_func, "IFU.%02d - Extension: %02d:%s --> Properties charged in extension: %02d and 1D data spectrum extracted!)",
-                           ifu->num, ifu->ext, ifu->name, ext);
+              cpl_msg_info(cpl_func, "IFU.%02d - Extension[%02d]=%s (Mapping IFU.%02d) --> Properties charged in extension: %02d and 1D data spectrum extracted!)",
+                           ifu->num, ifu->ext, ifu->name, ifu->map, ext);
           }
 
       } else {
@@ -811,6 +813,10 @@ static cpl_error_code kmos_molecfit_load_spectrum_3D(
           /* Recipe kmos_recipe_calctrans */
           int ext_data = -1;
 
+          /* Get errorstate preState */
+          cpl_errorstate preState       = cpl_errorstate_get();
+          cpl_boolean    right_detector = CPL_TRUE;
+
           /* Get the first data spectrum that match with the map of my ifu */
           for (cpl_size n_ifu = 0; n_ifu < N_IFUS && !data; n_ifu++) {
 
@@ -821,16 +827,15 @@ static cpl_error_code kmos_molecfit_load_spectrum_3D(
               /* IFU_X = ifu->num : Get the first with data spectrum */
               if (ifus[n_ifu].map == ifu->num) {
 
-                  /* Get errorstate preState */
-                  cpl_errorstate preState = cpl_errorstate_get();
-
                   /* Cleanup header, if it was storage in a previous loop */
                   if (header_convert1D) cpl_propertylist_delete(header_convert1D);
 
                   header_convert1D = cpl_propertylist_load(filename, ext_data);
                   if (!header_convert1D) {
                       cpl_free(noise_name);
-                      return cpl_error_set_message(cpl_func, cpl_error_get_code(), "Cannot load data propertylist from file=%s, ext=%d", filename, ext_data);
+                      return cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                                   "Cannot load data propertylist from file=%s, ext=%02d",
+                                                   filename, ext_data);
                   }
 
                   /* Extract 1D spectrum from extension in filename (FITS file) */
@@ -846,16 +851,64 @@ static cpl_error_code kmos_molecfit_load_spectrum_3D(
                       cpl_propertylist_delete(header_convert1D);
                       if (data) cpl_vector_delete(data);
                       return cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
-                                                   "Load raw spectrum and the STAR_SPEC from IFU.%02d failed!", ifu->num);
+                                                   "Load raw spectrum and the STAR_SPEC from IFU.%02d failed!",
+                                                   ifu->num);
                   }
               }
           }
 
-          /* Check that all of IFU_Y have data */
+          /* If no data check in all of the input data science file */
           if (!data) {
-              cpl_free(noise_name);
-              if (header_convert1D) cpl_propertylist_delete(header_convert1D);
-              return cpl_error_set_message(cpl_func, CPL_ERROR_ILLEGAL_INPUT, "Data science datacube spectrum not found to IFU_Y=%d", ifu->num);
+
+              /* Get the first data spectrum with data */
+              for (cpl_size n_ifu = 0; n_ifu < N_IFUS && !data; n_ifu++) {
+
+                  if (ext24) ext_data =  n_ifu      + 1;
+                  else       ext_data = (n_ifu * 2) + 1;
+
+
+                  /* IFU_X != ifu->num : Get the first with data spectrum */
+                  if (ifus[n_ifu].map != ifu->num) {
+
+                      /* Cleanup header, if it was storage in a previous loop */
+                      if (header_convert1D) cpl_propertylist_delete(header_convert1D);
+
+                      header_convert1D = cpl_propertylist_load(filename, ext_data);
+                      if (!header_convert1D) {
+                          cpl_free(noise_name);
+                          return cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                                       "Cannot load data propertylist from file=%s, ext=%02d",
+                                                       filename, ext_data);
+                      }
+
+                      /* Extract 1D spectrum from extension in filename (FITS file) */
+                      data = kmos_molecfit_extract_spec_from_datacube(filename, ext_data, header_convert1D);
+                      if (!data && cpl_error_get_code() == CPL_ERROR_FILE_IO){
+                          cpl_errorstate_set(preState);
+                      }
+
+                      /* Check prestate */
+                      if (!cpl_errorstate_is_equal(preState)) {
+                          cpl_free(noise_name);
+                          cpl_propertylist_delete(header_convert1D);
+                          if (data) cpl_vector_delete(data);
+                          return cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
+                                                       "Load raw spectrum and the STAR_SPEC from IFU.%02d failed!",
+                                                       ifu->num);
+                      }
+                  }
+              }
+
+              /* Check that all of IFU_Y have data */
+              if (data) {
+                  right_detector = CPL_FALSE;
+              } else {
+                  cpl_free(noise_name);
+                  if (header_convert1D) cpl_propertylist_delete(header_convert1D);
+                  return cpl_error_set_message(cpl_func, CPL_ERROR_ILLEGAL_INPUT,
+                                               "IFU_X.%02d - Extension[%02d]=%s (Mapping IFU_Y.%02d) --> Not founded any data science IFU_X datacube spectrum to load in %s",
+                                               ifu->num, ifu->ext, ifu->name, ifu->map, filename);
+              }
           }
 
           /* Parse from cpl_vector to 1D spectrum: Need to storage cpl_propertylist form 3D Datacube to 1D spectrumn */
@@ -868,8 +921,14 @@ static cpl_error_code kmos_molecfit_load_spectrum_3D(
           }
           cpl_vector_delete(data);
 
-          cpl_msg_info(cpl_func, "IFU.%02d - Extension: %02d:%s --> Properties charged in extension: %02d and 1D data spectrum extracted!)",
-                       ifu->num, ifu->ext, ifu->name, ext_data);
+          if (right_detector) {
+              cpl_msg_info(cpl_func, "IFU.%02d - Extension[%02d]=%s (Mapping IFU.%02d) --> First IFU_X with data [IFU_X.%02d] : Properties charged and 1D data spectrum extracted from a his cube data!)",
+                           ifu->num, ifu->ext, ifu->name, ifu->map, ext_data);
+          } else {
+              cpl_msg_warning(cpl_func, "IFU.%02d - Detector doesn't contain datacube spectrum --> Taken from another detector! All his mapping group take this other data spectrum",  ifu->num);
+              cpl_msg_warning(cpl_func, "IFU.%02d - Extension[%02d]=%s (Mapping IFU.%02d) --> First IFU_X with data [IFU_X.%02d] : Properties charged and 1D data spectrum extracted from a his cube data!)",
+                                         ifu->num, ifu->ext, ifu->name, ifu->map, ext_data);
+          }
       }
 
       /* If data, turn coherente the headers */
@@ -1567,6 +1626,7 @@ cpl_error_code kmos_molecfit_save(
     cpl_propertylist        *list,
     const char              *tag,
     const char              *gratingname,
+    cpl_boolean             suppress_extension,
     const char              *filename)
 {
   /* Check inputs */
@@ -1587,11 +1647,11 @@ cpl_error_code kmos_molecfit_save(
   /* Get filename: If filename not NULL get this, if NULL create with tag */
   char *tag_fits;
   if (filename) {
-      tag_fits = cpl_sprintf("%s",             filename);
-  } else if (gratingname){
+      tag_fits = cpl_sprintf("%s", filename);
+  } else if (gratingname && !suppress_extension){
       tag_fits = cpl_sprintf("%s_%s%s%s.fits", tag, gratingname, gratingname, gratingname);
   } else {
-      tag_fits = cpl_sprintf("%s.fits",        tag);
+      tag_fits = cpl_sprintf("%s.fits", tag);
   }
 
   /* Save to disk the fits file */
@@ -1631,6 +1691,7 @@ cpl_error_code kmos_molecfit_save_mf_results(
     cpl_propertylist *header_noise,
     const char       *tag,
     const char       *gratingname,
+    cpl_boolean      suppress_extension,
     const char       *filename,
     cpl_table        *table,
     cpl_vector       *vec)
@@ -1646,7 +1707,7 @@ cpl_error_code kmos_molecfit_save_mf_results(
   char *tag_fits;
   if (filename) {
       tag_fits = cpl_sprintf("%s",             filename);
-  } else if (gratingname){
+  } else if (gratingname && !suppress_extension){
       tag_fits = cpl_sprintf("%s_%s%s%s.fits", tag, gratingname, gratingname, gratingname);
   } else {
       tag_fits = cpl_sprintf("%s.fits",        tag);
