@@ -29,6 +29,7 @@
 #include <string.h>
 
 #include "kmos_pfits.h"
+#include "kmo_dfs.h"
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -103,6 +104,31 @@ double kmos_pfits_get_rotangle(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist, "ESO OCS ROT NAANGLE") ;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the OBS TARG NAME
+  @param    plist       property list to read from
+  @return   pointer to statically allocated character string
+ */
+/*----------------------------------------------------------------------------*/
+const char * kmos_pfits_get_obs_targ_name(const cpl_propertylist * plist)
+{
+    return (const char *)cpl_propertylist_get_string(plist,"ESO OBS TARG NAME");
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the PRO REFLEX SUFFIX
+  @param    plist       property list to read from
+  @return   pointer to statically allocated character string
+ */
+/*----------------------------------------------------------------------------*/
+const char * kmos_pfits_get_reflex_suffix(const cpl_propertylist * plist)
+{
+    return (const char *)cpl_propertylist_get_string(plist,
+            "ESO PRO REFLEX SUFFIX");
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    find out the extname
@@ -360,6 +386,19 @@ int kmos_pfits_get_naxis3(const cpl_propertylist * plist)
     return cpl_propertylist_get_int(plist, "NAXIS3")  ;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the DATE-OBS value 
+  @param    plist       property list to read from
+  @return   the requested value
+ */
+/*----------------------------------------------------------------------------*/
+const char * kmos_pfits_get_date_obs(const cpl_propertylist * plist)
+{
+    return cpl_propertylist_get_string(plist, KEY_DATEOBS)  ;
+}
+
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    find out the MJD-OBS value 
@@ -369,7 +408,19 @@ int kmos_pfits_get_naxis3(const cpl_propertylist * plist)
 /*----------------------------------------------------------------------------*/
 double kmos_pfits_get_mjd_obs(const cpl_propertylist * plist)
 {
-    return cpl_propertylist_get_double(plist, "MJD-OBS")  ;
+    return cpl_propertylist_get_double(plist, KEY_MJDOBS)  ;
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the PRO DATE-OBS value 
+  @param    plist       property list to read from
+  @return   the requested value
+ */
+/*----------------------------------------------------------------------------*/
+const char * kmos_pfits_get_pro_date_obs(const cpl_propertylist * plist)
+{
+    return cpl_propertylist_get_string(plist, PRO_DATE_OBS)  ;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -381,7 +432,7 @@ double kmos_pfits_get_mjd_obs(const cpl_propertylist * plist)
 /*----------------------------------------------------------------------------*/
 double kmos_pfits_get_pro_mjd_obs(const cpl_propertylist * plist)
 {
-    return cpl_propertylist_get_double(plist, "ESO PRO MJD-OBS")  ;
+    return cpl_propertylist_get_double(plist, PRO_MJD_OBS)  ;
 }
 
 /*----------------------------------------------------------------------------*/
