@@ -8,7 +8,7 @@ float   test_global_seed_data            = 1.1;
 /**
     @brief Switches off error-messages.
 */
-void kmo_test_verbose_off()
+void kmo_test_verbose_off(void)
 {
     if (getenv("KMO_TEST_VERBOSE") == NULL) {
         cpl_msg_set_level(CPL_MSG_OFF);
@@ -18,7 +18,7 @@ void kmo_test_verbose_off()
 /**
     @brief Switches on error-messages.
 */
-void kmo_test_verbose_on()
+void kmo_test_verbose_on(void)
 {
     if (getenv("KMO_TEST_VERBOSE") == NULL) {
         cpl_msg_set_level(CPL_MSG_WARNING);
