@@ -46,7 +46,7 @@ void kmo_test_fill_cube(cpl_imagelist *cube, float seed, float offset);
 /**
     @brief   tests kmo_image_histogram()
  */
-void test_kmo_image_histogram()
+void test_kmo_image_histogram(void)
 {
     cpl_image   *img    = cpl_image_new(2, 2, CPL_TYPE_FLOAT);
     cpl_vector  *res    = NULL;
@@ -63,7 +63,7 @@ void test_kmo_image_histogram()
 /**
     @brief   tests kmo_image_sort()
  */
-void test_kmo_image_sort()
+void test_kmo_image_sort(void)
 {
     cpl_image   *img    = cpl_image_new(2, 2, CPL_TYPE_FLOAT);
     cpl_vector  *res    = NULL;
@@ -80,7 +80,7 @@ void test_kmo_image_sort()
 /**
     @brief   tests kmo_image_fill()
  */
-void test_kmo_image_fill()
+void test_kmo_image_fill(void)
 {
     cpl_image   *img    = cpl_image_new(2, 2, CPL_TYPE_FLOAT);
     float       tol     = 0.01;
@@ -94,7 +94,7 @@ void test_kmo_image_fill()
 /**
     @brief   tests kmo_image_get_flux()
  */
-void test_kmo_image_get_flux()
+void test_kmo_image_get_flux(void)
 {
     kmo_test_verbose_off();
     kmo_image_get_flux(NULL);
@@ -116,7 +116,7 @@ void test_kmo_image_get_flux()
 /**
     @brief   tests kmo_image_reject_from_mask()
  */
-void test_kmo_image_reject_from_mask()
+void test_kmo_image_reject_from_mask(void)
 {
     cpl_image *img = cpl_image_new(2, 1, CPL_TYPE_FLOAT);
     cpl_image *map = cpl_image_new(2, 1, CPL_TYPE_FLOAT);
@@ -148,7 +148,7 @@ void test_kmo_image_reject_from_mask()
 /**
     @brief   tests kmo_imagelist_power()
  */
-void test_kmo_imagelist_power()
+void test_kmo_imagelist_power(void)
 {
     cpl_imagelist   *cube1  = cpl_imagelist_new();
 
@@ -189,7 +189,7 @@ void test_kmo_imagelist_power()
 /**
     @brief   tests test_kmo_imagelist_get_mean()
  */
-void test_kmo_imagelist_get_mean()
+void test_kmo_imagelist_get_mean(void)
 {
     cpl_imagelist   *cube1  = cpl_imagelist_new();
 
@@ -206,7 +206,7 @@ void test_kmo_imagelist_get_mean()
 /**
     @brief   tests test_kmo_imagelist_get_flux()
  */
-void test_kmo_imagelist_get_flux()
+void test_kmo_imagelist_get_flux(void)
 {
     cpl_imagelist   *cube1  = cpl_imagelist_new();
 
@@ -223,7 +223,7 @@ void test_kmo_imagelist_get_flux()
 /**
     @brief   tests kmo_imagelist_turn()
  */
-void test_kmo_imagelist_turn()
+void test_kmo_imagelist_turn(void)
 {
     int t;
     kmo_test_verbose_off();
@@ -260,7 +260,7 @@ void test_kmo_imagelist_turn()
 /**
     @brief   tests kmo_vector_divide()
  */
-void test_kmo_vector_divide()
+void test_kmo_vector_divide(void)
 {
     cpl_vector           *vec1  = cpl_vector_new(3),
                          *vec2  = cpl_vector_new(3);
@@ -285,7 +285,7 @@ void test_kmo_vector_divide()
 /**
     @brief   tests kmo_array_fill_int()
 */
-void test_kmo_array_fill_int()
+void test_kmo_array_fill_int(void)
 {
     kmo_test_verbose_off();
     kmo_array_fill_int(NULL, 0.0);
@@ -302,7 +302,8 @@ void test_kmo_array_fill_int()
 /**
     @brief   tests kmo_vector_histogram_old()
 */
-void test_kmo_vector_histogram_old() {
+void test_kmo_vector_histogram_old(void)
+{
     /* all the same values in input vector --> all values in first entry of out-vector */
     cpl_vector* in = cpl_vector_new(108);
     cpl_vector_fill(in, 1.23457834678);
@@ -328,7 +329,7 @@ void test_kmo_vector_histogram_old() {
 /**
     @brief   tests kmo_image_divide_scalar()
  */
-void test_kmo_image_divide_scalar()
+void test_kmo_image_divide_scalar(void)
 {
     cpl_image       *img1   = cpl_image_new(2, 2, CPL_TYPE_FLOAT);
     int             rej     = 0;
@@ -347,7 +348,7 @@ void test_kmo_image_divide_scalar()
 /**
     @brief   tests kmo_image_divide()
  */
-void test_kmo_image_divide()
+void test_kmo_image_divide(void)
 {
     cpl_image       *img1   = cpl_image_new(2, 2, CPL_TYPE_FLOAT),
                     *img2   = cpl_image_new(2, 2, CPL_TYPE_FLOAT);
@@ -370,7 +371,7 @@ void test_kmo_image_divide()
 /**
     @brief   tests kmo_image_power()
  */
-void test_kmo_image_power()
+void test_kmo_image_power(void)
 {
     cpl_image       *img1   = cpl_image_new(2, 2, CPL_TYPE_FLOAT);
     float           tol     = 0.01;
@@ -386,7 +387,7 @@ void test_kmo_image_power()
 /**
     @brief   tests kmo_imagelist_divide_scalar()
  */
-void test_kmo_imagelist_divide_scalar()
+void test_kmo_imagelist_divide_scalar(void)
 {
     cpl_imagelist   *cube3  = cpl_imagelist_new();
     cpl_image       *tmp    = NULL;
@@ -413,7 +414,7 @@ void test_kmo_imagelist_divide_scalar()
 /**
     @brief   tests kmo_imagelist_divide()
  */
-void test_kmo_imagelist_divide()
+void test_kmo_imagelist_divide(void)
 {
     cpl_imagelist   *cube4  = cpl_imagelist_new(),
                     *cube5  = cpl_imagelist_new();
@@ -444,7 +445,7 @@ void test_kmo_imagelist_divide()
 /**
     @brief   Tests for cpl extension functions.
  */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
