@@ -48,7 +48,7 @@ void kmo_test_alloc_cube(cpl_imagelist *cube, int x, int y, int z);
 /**
  * @brief   test strlower
  */
-void test_strlower()
+void test_strlower(void)
 {
     char *s = cpl_sprintf("%s", "GAGA");
     cpl_test_nonnull(strlower(s));
@@ -59,7 +59,7 @@ void test_strlower()
 /**
  * @brief   test kmo_extname_extractor
  */
-void test_kmo_extname_extractor()
+void test_kmo_extname_extractor(void)
 {
     char *s = cpl_sprintf("%s", "DET.1.DATA");
     enum kmo_frame_type type = illegal_frame;
@@ -77,7 +77,7 @@ void test_kmo_extname_extractor()
 /**
  * @brief   test kmo_extname_creator
  */
-void test_kmo_extname_creator()
+void test_kmo_extname_creator(void)
 {
     char *s = kmo_extname_creator(detector_frame, 2, EXT_NOISE);
 
@@ -89,7 +89,7 @@ void test_kmo_extname_creator()
 /**
  * @brief   test kmo_get_index_from_ocs_name
  */
-void test_kmo_get_index_from_ocs_name()
+void test_kmo_get_index_from_ocs_name(void)
 {
     cpl_frame  *fr = NULL;
     cpl_vector *v  = NULL;
@@ -150,7 +150,7 @@ void test_kmo_get_index_from_ocs_name()
 /**
  * @brief   test kmo_update_sub_keywords
  */
-void test_kmo_update_sub_keywords()
+void test_kmo_update_sub_keywords(void)
 {
     cpl_propertylist *pl = cpl_propertylist_new();
 
@@ -177,7 +177,7 @@ void test_kmo_update_sub_keywords()
 /**
  * @brief   test kmo_dfs_load_primary_header
  */
-void test_kmo_dfs_load_primary_header()
+void test_kmo_dfs_load_primary_header(void)
 {
     cpl_propertylist    *pl         = NULL;
     cpl_frameset        *fs         = cpl_frameset_new();
@@ -207,7 +207,7 @@ void test_kmo_dfs_load_primary_header()
 /**
  * @brief   test kmo_dfs_load_sub_header
  */
-void test_kmo_dfs_load_sub_header()
+void test_kmo_dfs_load_sub_header(void)
 {
     cpl_propertylist    *pl         = NULL;
     cpl_frameset        *fs         = cpl_frameset_new();
@@ -241,7 +241,7 @@ void test_kmo_dfs_load_sub_header()
 /**
  * @brief   test kmo_dfs_load_vector()
  */
-void test_kmo_dfs_load_vector()
+void test_kmo_dfs_load_vector(void)
 {
     cpl_frameset     *fs          = NULL;
     cpl_frame        *fr          = NULL;
@@ -293,7 +293,7 @@ void test_kmo_dfs_load_vector()
 /**
  * @brief   test kmo_dfs_load_image()
  */
-void test_kmo_dfs_load_image()
+void test_kmo_dfs_load_image(void)
 {
     cpl_frameset     *fs          = NULL;
     cpl_frame        *fr          = NULL;
@@ -344,7 +344,7 @@ void test_kmo_dfs_load_image()
 /**
  * @brief   test kmo_dfs_load_image_window()
  */
-void test_kmo_dfs_load_image_window()
+void test_kmo_dfs_load_image_window(void)
 {
     cpl_frameset     *fs          = NULL;
     cpl_frame        *fr          = NULL;
@@ -401,7 +401,7 @@ void test_kmo_dfs_load_image_window()
 /**
  * @brief   test kmo_dfs_load_image_frame()
  */
-void test_kmo_dfs_load_image_frame()
+void test_kmo_dfs_load_image_frame(void)
 {
     cpl_frame        *fr          = NULL;
     cpl_image        *img         = cpl_image_new(2, 2, CPL_TYPE_FLOAT),
@@ -446,7 +446,7 @@ void test_kmo_dfs_load_image_frame()
 /**
  * @brief   test kmo_dfs_load_image_frame_window()
  */
-void test_kmo_dfs_load_image_frame_window()
+void test_kmo_dfs_load_image_frame_window(void)
 {
     cpl_frame        *fr          = NULL;
     cpl_image        *img         = cpl_image_new(2, 2, CPL_TYPE_FLOAT),
@@ -503,7 +503,7 @@ void test_kmo_dfs_load_image_frame_window()
 /**
  * @brief   test kmo_dfs_load_cube()
  */
-void test_kmo_dfs_load_cube()
+void test_kmo_dfs_load_cube(void)
 {
     cpl_frameset     *fs          = NULL;
     cpl_frame        *fr          = NULL;
@@ -557,7 +557,7 @@ void test_kmo_dfs_load_cube()
 /**
  * @brief   test kmo_dfs_load_table()
  */
-void test_kmo_dfs_load_table()
+void test_kmo_dfs_load_table(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_dfs_load_table(NULL, NULL, -1, -1));
@@ -585,7 +585,7 @@ void test_kmo_dfs_load_table()
 /**
  * @brief   test kmo_dfs_create_filename()
  */
-void test_kmo_dfs_create_filename()
+void test_kmo_dfs_create_filename(void)
 {
     /*
     char *s = NULL;
@@ -608,7 +608,7 @@ void test_kmo_dfs_create_filename()
 /**
  * @brief   test kmo_dfs_save_main_header()
  */
-void test_kmo_dfs_save_main_header()
+void test_kmo_dfs_save_main_header(void)
 {
     cpl_propertylist    *pl         = NULL;
     cpl_frameset        *fs         = cpl_frameset_new();
@@ -654,7 +654,7 @@ void test_kmo_dfs_save_main_header()
 /**
  * @brief   test kmo_dfs_save_sub_header()
  */
-void test_kmo_dfs_save_sub_header()
+void test_kmo_dfs_save_sub_header(void)
 {
     cpl_propertylist    *pl         = NULL;
 
@@ -682,7 +682,7 @@ void test_kmo_dfs_save_sub_header()
 /**
  * @brief   test kmo_dfs_save_vector()
  */
-void test_kmo_dfs_save_vector()
+void test_kmo_dfs_save_vector(void)
 {
     cpl_propertylist  *pl          = cpl_propertylist_new(),
                       *main_header = NULL,
@@ -741,7 +741,7 @@ void test_kmo_dfs_save_vector()
 /**
  * @brief   test kmo_dfs_save_image()
  */
-void test_kmo_dfs_save_image()
+void test_kmo_dfs_save_image(void)
 {
     cpl_propertylist *pl          = cpl_propertylist_new(),
                      *main_header = NULL,
@@ -803,7 +803,7 @@ void test_kmo_dfs_save_image()
 /**
  * @brief   test kmo_dfs_save_cube()
  */
-void test_kmo_dfs_save_cube()
+void test_kmo_dfs_save_cube(void)
 {
     cpl_propertylist *pl          = cpl_propertylist_new(),
                      *main_header = NULL,
@@ -860,7 +860,7 @@ void test_kmo_dfs_save_cube()
 /**
  * @brief   test kmo_dfs_save_table()
  */
-void test_kmo_dfs_save_table()
+void test_kmo_dfs_save_table(void)
 {
     cpl_frameset *fs = cpl_frameset_new();
     cpl_frame *fr = kmo_test_frame_new("aga_vec.fits", "", CPL_FRAME_GROUP_RAW);
@@ -883,7 +883,7 @@ void test_kmo_dfs_save_table()
 /**
  * @brief   test kmo_dfs_get_frame
  */
-void test_kmo_dfs_get_frame()
+void test_kmo_dfs_get_frame(void)
 {
     int                 flag        = 0;
     cpl_frameset        *fs         = NULL;
@@ -917,7 +917,7 @@ void test_kmo_dfs_get_frame()
 /**
  * @brief   test kmo_dfs_get_parameter_bool
  */
-void test_kmo_dfs_get_parameter_bool()
+void test_kmo_dfs_get_parameter_bool(void)
 {
     cpl_parameterlist *parl = cpl_parameterlist_new();
     cpl_parameter *par = NULL;
@@ -945,7 +945,7 @@ void test_kmo_dfs_get_parameter_bool()
 /**
  * @brief   test kmo_dfs_get_parameter_int
  */
-void test_kmo_dfs_get_parameter_int()
+void test_kmo_dfs_get_parameter_int(void)
 {
     cpl_parameterlist *parl = cpl_parameterlist_new();
     cpl_parameter     *par  = NULL;
@@ -972,7 +972,7 @@ void test_kmo_dfs_get_parameter_int()
 /**
  * @brief   test kmo_dfs_get_parameter_double
  */
-void test_kmo_dfs_get_parameter_double()
+void test_kmo_dfs_get_parameter_double(void)
 {
     cpl_parameterlist *parl = cpl_parameterlist_new();
     cpl_parameter     *par  = NULL;
@@ -1000,7 +1000,7 @@ void test_kmo_dfs_get_parameter_double()
 /**
  * @brief   test kmo_dfs_get_parameter_string
  */
-void test_kmo_dfs_get_parameter_string()
+void test_kmo_dfs_get_parameter_string(void)
 {
     cpl_parameterlist *parl = cpl_parameterlist_new();
     cpl_parameter *par = NULL;
@@ -1027,7 +1027,7 @@ void test_kmo_dfs_get_parameter_string()
 /**
  * @brief   test kmo_dfs_print_parameter_help
  */
-void test_kmo_dfs_print_parameter_help()
+void test_kmo_dfs_print_parameter_help(void)
 {
     kmo_test_verbose_off();
     kmo_dfs_print_parameter_help(NULL, NULL);
@@ -1053,7 +1053,7 @@ void test_kmo_dfs_print_parameter_help()
 /**
  * @brief   test kmo_dfs_get_property_bool
  */
-void test_kmo_dfs_get_property_bool()
+void test_kmo_dfs_get_property_bool(void)
 {
     cpl_propertylist *pl = cpl_propertylist_new();
     cpl_propertylist_append_bool(pl, "bool", FALSE);
@@ -1075,7 +1075,7 @@ void test_kmo_dfs_get_property_bool()
 /**
  * @brief   test kmo_dfs_get_property_int
  */
-void test_kmo_dfs_get_property_int()
+void test_kmo_dfs_get_property_int(void)
 {
     cpl_propertylist *pl = cpl_propertylist_new();
     cpl_propertylist_append_int(pl, "int", 33);
@@ -1098,7 +1098,7 @@ void test_kmo_dfs_get_property_int()
 /**
  * @brief   test kmo_dfs_get_property_double
  */
-void test_kmo_dfs_get_property_double()
+void test_kmo_dfs_get_property_double(void)
 {
     cpl_propertylist *pl = cpl_propertylist_new();
     cpl_propertylist_append_double(pl,  "dbl", 2.987);
@@ -1121,7 +1121,7 @@ void test_kmo_dfs_get_property_double()
 /**
  * @brief   test kmo_dfs_get_property_string
  */
-void test_kmo_dfs_get_property_string()
+void test_kmo_dfs_get_property_string(void)
 {
     cpl_propertylist *pl = cpl_propertylist_new();
     cpl_propertylist_append_string(pl, "str", "aga");
@@ -1144,7 +1144,7 @@ void test_kmo_dfs_get_property_string()
 /**
  * @brief   test kmo_identify_index
  */
-void test_kmo_identify_index()
+void test_kmo_identify_index(void)
 {
     cpl_frameset        *fs         = cpl_frameset_new();
     cpl_frame           *fr         = NULL;
@@ -1173,7 +1173,7 @@ void test_kmo_identify_index()
 /**
  * @brief   test kmo_check_lamp
  */
-void test_kmo_check_lamp()
+void test_kmo_check_lamp(void)
 {
     kmo_test_verbose_off();
     kmo_check_lamp(NULL, NULL);
@@ -1203,7 +1203,7 @@ void test_kmo_check_lamp()
 /**
  * @brief   Test of DFS helper functions
  */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
