@@ -1,5 +1,4 @@
-/* $Id: kmo_functions-test.c,v 1.4 2013-10-08 11:18:19 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-10-08 11:18:19 $
- * $Revision: 1.4 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -41,7 +33,7 @@
 /**
     @brief   test kmo_reconstruct_sci()
 */
-void test_kmo_reconstruct_sci()
+void test_kmo_reconstruct_sci(void)
 {
 /*erwtest*/
 }
@@ -49,9 +41,9 @@ void test_kmo_reconstruct_sci()
 /**
  * @brief   Test of helper functions
  */
-int main()
+int main(void)
 {
-    cpl_test_init("<kmos-spark@mpe.mpg.de>", CPL_MSG_WARNING);
+    cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
     test_kmo_reconstruct_sci();
 
