@@ -43,7 +43,7 @@ void kmo_test_alloc_cube(cpl_imagelist *cube, int x, int y, int z);
 /**
     @brief   test for kmo_arithmetic_1D_1D()
  */
-void test_kmo_arithmetic_1D_1D()
+void test_kmo_arithmetic_1D_1D(void)
 {
     // test data only
     int size    = 3;
@@ -101,7 +101,7 @@ void test_kmo_arithmetic_1D_1D()
 /**
     @brief   test for kmo_arithmetic_1D_scalar()
  */
-void test_kmo_arithmetic_1D_scalar()
+void test_kmo_arithmetic_1D_scalar(void)
 {
     // test data only
     int size    = 3;
@@ -143,7 +143,7 @@ void test_kmo_arithmetic_1D_scalar()
 /**
     @brief   test for kmo_arithmetic_2D_2D()
  */
-void test_kmo_arithmetic_2D_2D()
+void test_kmo_arithmetic_2D_2D(void)
 {
     // test data only
     int size = 100, rej = 0;
@@ -184,7 +184,7 @@ void test_kmo_arithmetic_2D_2D()
 /**
     @brief   test for kmo_arithmetic_2D_scalar()
  */
-void test_kmo_arithmetic_2D_scalar()
+void test_kmo_arithmetic_2D_scalar(void)
 {
     int size = 100, rej = 0;
     float tol     = 0.01;
@@ -217,7 +217,7 @@ void test_kmo_arithmetic_2D_scalar()
 /**
     @brief   test for kmo_arithmetic_3D_3D()
  */
-void test_kmo_arithmetic_3D_3D()
+void test_kmo_arithmetic_3D_3D(void)
 {
     int size2D = 100, size3D = 10, rej;
     float tol = 0.01;
@@ -278,7 +278,7 @@ void test_kmo_arithmetic_3D_3D()
 /**
     @brief   test for kmo_arithmetic_3D_2D()
  */
-void test_kmo_arithmetic_3D_2D()
+void test_kmo_arithmetic_3D_2D(void)
 {
     // test data only
     int size2D = 100, size3D = 10, rej;
@@ -329,7 +329,7 @@ void test_kmo_arithmetic_3D_2D()
 /**
     @brief   test for kmo_arithmetic_3D_1D()
  */
-void test_kmo_arithmetic_3D_1D()
+void test_kmo_arithmetic_3D_1D(void)
 {
     int size2D = 100, size3D = 10, rej;
     float tol = 0.01;
@@ -392,7 +392,7 @@ void test_kmo_arithmetic_3D_1D()
 /**
     @brief   test for kmo_arithmetic_3D_scalar()
  */
-void test_kmo_arithmetic_3D_scalar()
+void test_kmo_arithmetic_3D_scalar(void)
 {
     int size2D = 100, size3D = 10, rej;
     cpl_imagelist *cube1        = cpl_imagelist_new();
@@ -410,7 +410,7 @@ void test_kmo_arithmetic_3D_scalar()
 /**
     @brief   test for kmo_arithmetic_3D_scalar_noise()
  */
-void test_kmo_arithmetic_3D_scalar_noise()
+void test_kmo_arithmetic_3D_scalar_noise(void)
 {
         int size2D = 100, size3D = 10, rej;
         float tol = 0.01;
@@ -459,7 +459,7 @@ void test_kmo_arithmetic_3D_scalar_noise()
 /**
  * @brief   Test of helper functions for kmo_arithmetic
  */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
