@@ -46,7 +46,7 @@ void kmo_test_alloc_cube(cpl_imagelist *cube, int x, int y, int z);
  * @brief   Test for kmo_align_subpix()
  */
 /*----------------------------------------------------------------------------*/
-void test_kmo_align_subpix()
+void test_kmo_align_subpix(void)
 {
     double              xshift          = 0.1,
                         yshift          = 0.3,
@@ -162,7 +162,7 @@ void test_kmo_align_subpix()
  * @brief   Test for kmo_priv_combine()
  */
 /*----------------------------------------------------------------------------*/
-void test_kmo_priv_combine()
+void test_kmo_priv_combine(void)
 {
     int                 nr_frames       = 3;
     cpl_imagelist       **data          = NULL,
@@ -398,7 +398,7 @@ void test_kmo_priv_combine()
     @brief   Test of helper functions for kmo_combine
 */
 /*----------------------------------------------------------------------------*/
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
     test_kmo_priv_combine();
