@@ -42,7 +42,7 @@ void kmo_test_alloc_cube(cpl_imagelist *cube, int x, int y, int z);
 /**
  * @brief   Test for kmo_copy_scalar_F1I()
  */
-void test_kmo_copy_scalar_F1I()
+void test_kmo_copy_scalar_F1I(void)
 {
     int size2D = 100;
     float tol = 0.01;
@@ -69,7 +69,7 @@ void test_kmo_copy_scalar_F1I()
 /**
  * @brief   Test for kmo_copy_scalar_F2I()
  */
-void test_kmo_copy_scalar_F2I()
+void test_kmo_copy_scalar_F2I(void)
 {
     int size2D = 100;
     float tol = 0.01;
@@ -98,7 +98,7 @@ void test_kmo_copy_scalar_F2I()
 /**
  * @brief   Test for kmo_copy_scalar_F3I()
  */
-void test_kmo_copy_scalar_F3I()
+void test_kmo_copy_scalar_F3I(void)
 {
     int size2D = 100, size3D = 10;
     float tol = 0.01;
@@ -132,7 +132,7 @@ void test_kmo_copy_scalar_F3I()
 /**
  * @brief   Test for kmo_copy_vector_F1I()
  */
-void test_kmo_copy_vector_F1I()
+void test_kmo_copy_vector_F1I(void)
 {
     int            size2D = 100;
     float          tol = 0.01;
@@ -165,7 +165,7 @@ void test_kmo_copy_vector_F1I()
 /**
  * @brief   Test for kmo_copy_vector_F2I_x()
  */
-void test_kmo_copy_vector_F2I_x()
+void test_kmo_copy_vector_F2I_x(void)
 {
     int size2D = 100;
     float tol = 0.01;
@@ -209,7 +209,7 @@ void test_kmo_copy_vector_F2I_x()
 /**
  * @brief   Test for kmo_copy_vector_F2I_y()
  */
-void test_kmo_copy_vector_F2I_y()
+void test_kmo_copy_vector_F2I_y(void)
 {
     int size2D = 100;
     float tol = 0.01;
@@ -254,7 +254,7 @@ void test_kmo_copy_vector_F2I_y()
 /**
  * @brief   Test for kmo_copy_vector_F3I_x()
  */
-void test_kmo_copy_vector_F3I_x()
+void test_kmo_copy_vector_F3I_x(void)
 {
     int size2D = 100, size3D = 10;
     float tol = 0.01;
@@ -296,7 +296,7 @@ void test_kmo_copy_vector_F3I_x()
 /**
  * @brief   Test for kmo_copy_vector_F3I_y()
  */
-void test_kmo_copy_vector_F3I_y()
+void test_kmo_copy_vector_F3I_y(void)
 {
     int size2D = 100, size3D = 10;
     float tol = 0.01;
@@ -338,7 +338,7 @@ void test_kmo_copy_vector_F3I_y()
 /**
  * @brief   Test for kmo_copy_vector_F3I_z()
  */
-void test_kmo_copy_vector_F3I_z()
+void test_kmo_copy_vector_F3I_z(void)
 {
     int size2D = 100, size3D = 10;
     float tol = 0.01;
@@ -382,7 +382,7 @@ void test_kmo_copy_vector_F3I_z()
 /**
  * @brief   Test for kmo_copy_image_F2I()
  */
-void test_kmo_copy_image_F2I()
+void test_kmo_copy_image_F2I(void)
 {
     int size2D = 100, rej = 0;
     float tol = 0.01;
@@ -428,7 +428,7 @@ void test_kmo_copy_image_F2I()
 /**
  * @brief   Test for kmo_copy_image_F3I_x()
  */
-void test_kmo_copy_image_F3I_x()
+void test_kmo_copy_image_F3I_x(void)
 {
     int size2D = 100, size3D = 10, rej = 0;
     float tol = 0.01;
@@ -480,7 +480,7 @@ void test_kmo_copy_image_F3I_x()
 /**
  * @brief   Test for kmo_copy_image_F3I_y()
  */
-void test_kmo_copy_image_F3I_y()
+void test_kmo_copy_image_F3I_y(void)
 {
     int size2D = 100, size3D = 10, rej = 0;
     float tol = 0.01;
@@ -532,7 +532,7 @@ void test_kmo_copy_image_F3I_y()
 /**
  * @brief   Test for kmo_copy_image_F3I_z()
  */
-void test_kmo_copy_image_F3I_z()
+void test_kmo_copy_image_F3I_z(void)
 {
     int size2D = 100, size3D = 10, rej = 0;
     float tol = 0.01;
@@ -584,7 +584,7 @@ void test_kmo_copy_image_F3I_z()
 /**
  * @brief   Test for kmo_copy_cube_F3I()
  */
-void test_kmo_copy_cube_F3I()
+void test_kmo_copy_cube_F3I(void)
 {
     int size2D = 100, size3D = 10, rej = 0;
     float tol = 0.01;
@@ -644,7 +644,7 @@ void test_kmo_copy_cube_F3I()
 /**
     @brief   Test of helper functions for kmo_copy
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
