@@ -41,7 +41,7 @@ void kmo_test_verbose_on();
 /**
     @brief   test for kmo_create_bad_pix_dark()
 */
-void test_kmo_create_bad_pix_dark()
+void test_kmo_create_bad_pix_dark(void)
 {
     cpl_image  *img    = NULL,
                *badpix = NULL;
@@ -92,7 +92,7 @@ void test_kmo_create_bad_pix_dark()
 /**
     @brief   test for kmo_add_bad_pix_border()
 */
-void test_kmo_add_bad_pix_border()
+void test_kmo_add_bad_pix_border(void)
 {
     int tmp;
 
@@ -157,7 +157,7 @@ void test_kmo_add_bad_pix_border()
 /**
     @brief   Test of helper functions for kmo_dark
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
