@@ -39,7 +39,7 @@ cpl_imagelist* kmo_test_create_cube(int x, int y, int z, int gauss, int *offset)
 /**
     @brief   test for kmo_priv_extract_spec()
 */
-void test_kmo_priv_extract_spec()
+void test_kmo_priv_extract_spec(void)
 {
     float tol = 0.01;
     int offset = 0;
@@ -135,7 +135,7 @@ void test_kmo_priv_extract_spec()
 /**
     @brief   test for kmo_priv_update_header()
 */
-void test_kmo_priv_update_header()
+void test_kmo_priv_update_header(void)
 {
     cpl_propertylist *pl = cpl_propertylist_new();
 
@@ -169,7 +169,7 @@ void test_kmo_priv_update_header()
 /**
     @brief   Test of helper functions for kmo_extract_spec
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
