@@ -38,7 +38,7 @@
 /**
     @brief   test for kmo_fit_profile_1D()
 */
-void test_kmo_fit_profile_1D()
+void test_kmo_fit_profile_1D(void)
 {
     float               tol     = 0.01;
     int                 i       = 0,
@@ -126,7 +126,7 @@ void test_kmo_fit_profile_1D()
                                                    "lorentz",
                                                    &vec, &pl));
 
-    cpl_test_abs(cpl_vector_get_mean(par), 28.4, tol);
+    cpl_test_abs(cpl_vector_get_mean(par), 24, tol);
     cpl_test_abs(cpl_vector_get_mean(vec), 2.00381, tol);
     cpl_vector_subtract(y, vec);
     cpl_test_abs(cpl_vector_get_mean(y), 0.0, tol);
@@ -145,7 +145,7 @@ void test_kmo_fit_profile_1D()
 /**
     @brief   test for kmo_fit_profile_2D()
 */
-void test_kmo_fit_profile_2D()
+void test_kmo_fit_profile_2D(void)
 {
     float               tol         = 0.01,
                         *pimg       = NULL;
@@ -231,7 +231,7 @@ void test_kmo_fit_profile_2D()
 /**
     @brief   test for kmo_vector_fit_gauss()
 */
-void test_kmo_vector_fit_gauss()
+void test_kmo_vector_fit_gauss(void)
 {
     float               tol     = 0.01;
     cpl_vector          *x      = cpl_vector_new(256),
@@ -291,7 +291,7 @@ void test_kmo_vector_fit_gauss()
 /**
     @brief   test for kmo_vector_fit_moffat()
 */
-void test_kmo_vector_fit_moffat()
+void test_kmo_vector_fit_moffat(void)
 {
     float               tol     = 0.01;
     cpl_vector          *x      = cpl_vector_new(256),
@@ -340,7 +340,7 @@ void test_kmo_vector_fit_moffat()
 /**
     @brief   test for kmo_vector_fit_lorentz()
 */
-void test_kmo_vector_fit_lorentz()
+void test_kmo_vector_fit_lorentz(void)
 {
     float               tol     = 0.01;
     cpl_vector          *x      = cpl_vector_new(256),
@@ -373,7 +373,7 @@ void test_kmo_vector_fit_lorentz()
 
     // fit without linear element
     cpl_test_nonnull(par = kmo_vector_fit_lorentz(x, y, NULL,
-                                                 max_pos, max_val, &pl, FALSE));
+                                     max_pos, max_val, 0.0, &pl, FALSE));
     cpl_test_nonnull(pl);
     cpl_test_abs(cpl_vector_get_mean(par), 28.4, tol);
     cpl_test_eq(5, cpl_vector_get_size(par));
@@ -396,7 +396,7 @@ void test_kmo_vector_fit_lorentz()
     max_val = cpl_vector_get_max(y);
 
     cpl_test_nonnull(par = kmo_vector_fit_lorentz(x, y, NULL,
-                                                 max_pos, max_val, &pl, TRUE));
+                                     max_pos, max_val, 0.0, &pl, TRUE));
     cpl_test_nonnull(pl);
     cpl_test_abs(cpl_vector_get_mean(par), 28.4, tol);
     cpl_test_eq(5, cpl_vector_get_size(par));
@@ -413,7 +413,7 @@ void test_kmo_vector_fit_lorentz()
 /**
     @brief   test for kmo_image_fit_gauss()
 */
-void test_kmo_image_fit_gauss()
+void test_kmo_image_fit_gauss(void)
 {
     float               tol         = 0.01,
                         *pimg       = NULL;
@@ -473,7 +473,7 @@ void test_kmo_image_fit_gauss()
 /**
     @brief   test for kmo_image_fit_moffat()
 */
-void test_kmo_image_fit_moffat()
+void test_kmo_image_fit_moffat(void)
 {
     float               tol         = 0.01,
                         *pimg       = NULL;
@@ -512,7 +512,7 @@ void test_kmo_image_fit_moffat()
 /**
     @brief   test for kmo_priv_gauss1d_fnc()
 */
-void test_kmo_priv_gauss1d_fnc()
+void test_kmo_priv_gauss1d_fnc(void)
 {
     double  res     = 0.0,
             xx[1]   = {2},
@@ -527,7 +527,7 @@ void test_kmo_priv_gauss1d_fnc()
 /**
     @brief   test for kmo_priv_moffat1d_fnc()
 */
-void test_kmo_priv_moffat1d_fnc()
+void test_kmo_priv_moffat1d_fnc(void)
 {
     float           tol      = 0.01;
     double          x[1]    = {129},
@@ -543,7 +543,7 @@ void test_kmo_priv_moffat1d_fnc()
 /**
     @brief   test for kmo_priv_moffat1d_fncd()
 */
-void test_kmo_priv_moffat1d_fncd()
+void test_kmo_priv_moffat1d_fncd(void)
 {
     double  res[5],
             xx[1]   = {2},
@@ -562,7 +562,7 @@ void test_kmo_priv_moffat1d_fncd()
 /**
     @brief   test for kmo_priv_lorentz1d_fnc()
 */
-void test_kmo_priv_lorentz1d_fnc()
+void test_kmo_priv_lorentz1d_fnc(void)
 {
     float           tol     = 0.01;
     double          x[1]    = {129},
@@ -578,7 +578,7 @@ void test_kmo_priv_lorentz1d_fnc()
 /**
     @brief   test for kmo_priv_lorentz1d_fncd()
 */
-void test_kmo_priv_lorentz1d_fncd()
+void test_kmo_priv_lorentz1d_fncd(void)
 {
     double  res[5],
             xx[1]   = {2},
@@ -597,7 +597,7 @@ void test_kmo_priv_lorentz1d_fncd()
 /**
     @brief   test for kmo_priv_gauss2d_fnc()
 */
-void test_kmo_priv_gauss2d_fnc()
+void test_kmo_priv_gauss2d_fnc(void)
 {
     float           tol     = 0.01;
     double          x[2]    = {120, 130},
@@ -613,7 +613,7 @@ void test_kmo_priv_gauss2d_fnc()
 /**
     @brief   test for kmo_priv_gauss2d_fncd()
 */
-void test_kmo_priv_gauss2d_fncd()
+void test_kmo_priv_gauss2d_fncd(void)
 {
     double  res[7],
             xx[2]   = {2, 3},
@@ -634,7 +634,7 @@ void test_kmo_priv_gauss2d_fncd()
 /**
     @brief   test for kmo_priv_moffat2d_fnc()
 */
-void test_kmo_priv_moffat2d_fnc()
+void test_kmo_priv_moffat2d_fnc(void)
 {
     float           tol     = 0.01;
     double          x[2]    = {50, 30},
@@ -650,7 +650,7 @@ void test_kmo_priv_moffat2d_fnc()
 /**
     @brief   test for kmo_priv_moffat2d_fncd()
 */
-void test_kmo_priv_moffat2d_fncd()
+void test_kmo_priv_moffat2d_fncd(void)
 {
     double  res[8] = {0,0,0,0,0,0,0,0},
             xx[2]   = {2, 3},
@@ -672,7 +672,7 @@ void test_kmo_priv_moffat2d_fncd()
 /**
  * @brief   Test of helper functions for kmo_flat
  */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
