@@ -41,7 +41,7 @@ void kmo_test_verbose_on();
 /**
     @brief   test for kmo_priv_fits_stack()
 */
-void test_kmo_priv_fits_stack()
+void test_kmo_priv_fits_stack(void)
 {
     cpl_parameterlist   *parlist    = NULL;
     cpl_frameset        *fs         = NULL,
@@ -411,7 +411,7 @@ void test_kmo_priv_fits_stack()
 /**
     @brief   test for kmo_priv_check_dimensions()
 */
-void test_kmo_priv_check_dimensions()
+void test_kmo_priv_check_dimensions(void)
 {
     /* --- invalid tests --- */
     kmo_test_verbose_off();
@@ -436,7 +436,7 @@ void test_kmo_priv_check_dimensions()
 /**
     @brief   Test of helper functions for kmo_fits_stack
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
