@@ -46,7 +46,7 @@ void kmo_test_verbose_on();
 /**
     @brief   test for kmo_create_bad_pix_flat_thresh()
 */
-void test_kmo_create_bad_pix_flat_thresh()
+void test_kmo_create_bad_pix_flat_thresh(void)
 {
     cpl_image       *img1    = NULL,
                     *img2    = NULL;
@@ -98,7 +98,7 @@ void test_kmo_create_bad_pix_flat_thresh()
 /**
     @brief   test for kmo_polyfit_edge()
 */
-void test_kmo_polyfit_edge()
+void test_kmo_polyfit_edge(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_polyfit_edge(NULL, NULL, 3));
@@ -127,7 +127,7 @@ void test_kmo_polyfit_edge()
 /**
     @brief   test for kmo_edge_trace()
 */
-void test_kmo_edge_trace()
+void test_kmo_edge_trace(void)
 {
     kmo_test_verbose_off();
     kmo_edge_trace(NULL, NULL, NULL, -1, -1);
@@ -171,7 +171,7 @@ kmclipm_vector_delete(ddd);
 /**
     @brief   test for kmo_calc_calib_frames()
 */
-void test_kmo_calc_calib_frames()
+void test_kmo_calc_calib_frames(void)
 {
     kmo_test_verbose_off();
     kmo_calc_calib_frames(NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL);
@@ -197,7 +197,7 @@ void test_kmo_calc_calib_frames()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
+        fread(ddd, sizeof(double), 4*2*m, fp);
     }
     fclose(fp);
     kmo_calc_calib_frames(slit_ids, edgepars, 0, NULL, NULL, NULL, NULL, NULL);
@@ -254,7 +254,7 @@ void test_kmo_calc_calib_frames()
 /**
     @brief   test for kmo_curvature_qc()
 */
-void test_kmo_curvature_qc()
+void test_kmo_curvature_qc(void)
 {
     kmo_test_verbose_off();
     kmo_curvature_qc(NULL, NULL, NULL, NULL, NULL, NULL, NULL);
@@ -269,7 +269,7 @@ void test_kmo_curvature_qc()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
+        fread(ddd, sizeof(double), 4*2*m, fp);
     }
     fclose(fp);
     kmo_curvature_qc(edgepars, NULL, NULL, NULL, NULL, NULL, NULL);
@@ -305,7 +305,7 @@ void test_kmo_curvature_qc()
 /**
     @brief   test for kmo_edgepars_to_table()
 */
-void test_kmo_edgepars_to_table()
+void test_kmo_edgepars_to_table(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_edgepars_to_table(NULL, NULL));
@@ -332,7 +332,7 @@ void test_kmo_edgepars_to_table()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
+        fread(ddd, sizeof(double), 4*2*m, fp);
     }
     fclose(fp);
     cpl_table **edge_par = NULL;
@@ -396,7 +396,7 @@ void test_kmo_edgepars_to_table()
 /**
     @brief   test for kmo_flat_interpolate_edge_parameters()
 */
-void test_kmo_flat_interpolate_edge_parameters()
+void test_kmo_flat_interpolate_edge_parameters(void)
 {
     double checksum = 0;
     int n = 8, m = 14;
@@ -408,7 +408,7 @@ void test_kmo_flat_interpolate_edge_parameters()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
+        fread(ddd, sizeof(double), 4*2*m, fp);
 
         checksum += cpl_matrix_get_mean(edgepars[i]);
     }
@@ -428,7 +428,7 @@ void test_kmo_flat_interpolate_edge_parameters()
 /**
     @brief   test for kmo_chebyshev_coefficients()
 */
-void test_kmo_chebyshev_coefficients()
+void test_kmo_chebyshev_coefficients(void)
 {
     double in[4] = {1764.78, -0.00416616, 4.09266e-05, -1.74782e-07},
             out[4];
@@ -443,7 +443,7 @@ void test_kmo_chebyshev_coefficients()
 /**
     @brief   test for kmo_split_frame()
 */
-void test_kmo_split_frame()
+void test_kmo_split_frame(void)
 {
     cpl_image       *xcal   = NULL;
     int             *bounds = NULL;
@@ -513,7 +513,7 @@ void test_kmo_split_frame()
 /**
     @brief   test for kmo_imagelist_get_saturated()
 */
-void test_kmo_imagelist_get_saturated()
+void test_kmo_imagelist_get_saturated(void)
 {
     cpl_imagelist   *list   = NULL;
     cpl_image       *img    = NULL;
@@ -560,7 +560,7 @@ void test_kmo_imagelist_get_saturated()
 /**
     @brief   test for kmo_create_line_profile()
 */
-void test_kmo_create_line_profile()
+void test_kmo_create_line_profile(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_create_line_profile(NULL, -1, -1));
@@ -595,7 +595,7 @@ void test_kmo_create_line_profile()
 /**
     @brief   test for kmo_get_slitedges()
 */
-void test_kmo_get_slitedges()
+void test_kmo_get_slitedges(void)
 {
     kmclipm_vector *pos, *midline;
 
@@ -716,7 +716,7 @@ void test_kmo_get_slitedges()
 /**
     @brief   test for kmo_analize_slitedges()
 */
-void test_kmo_analize_slitedges()
+void test_kmo_analize_slitedges(void)
 {
     kmclipm_vector  *midline        = NULL,
                     *t_value        = NULL,
@@ -788,7 +788,7 @@ void test_kmo_analize_slitedges()
 /**
     @brief   test for kmo_analize_slitedges_advanced()
 */
-void test_kmo_analize_slitedges_advanced()
+void test_kmo_analize_slitedges_advanced(void)
 {
     kmclipm_vector  *midline        = NULL,
                     *pos            = NULL;
@@ -868,7 +868,7 @@ void test_kmo_analize_slitedges_advanced()
 /**
     @brief   test for kmos_analyze_flat()
 */
-void test_kmos_analyze_flat()
+void test_kmos_analyze_flat(void)
 {
     int             i;
     cpl_image       *data,
@@ -1900,7 +1900,7 @@ void test_kmos_analyze_flat()
 /**
     @brief   test for kmo_calc_curvature()
 */
-void test_kmo_calc_curvature()
+void test_kmo_calc_curvature(void)
 {
     kmo_test_verbose_off();
     kmo_calc_curvature(NULL, NULL, NULL, NULL, 0, NULL, NULL,
@@ -2027,7 +2027,7 @@ void test_kmo_calc_curvature()
 /**
     @brief   Test of helper functions for kmo_flat
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
     /* test_kmo_create_bad_pix_flat_thresh(); */
