@@ -42,7 +42,7 @@ void kmo_test_fill_vector(cpl_vector *vec, float seed, float offset);
 /**
     @brief   test for kmo_create_lambda_vec
 */
-void test_kmo_create_lambda_vec()
+void test_kmo_create_lambda_vec(void)
 {
     float       tol  = 0.01;
     cpl_vector  *vec = NULL;
@@ -71,7 +71,7 @@ void test_kmo_create_lambda_vec()
 /**
     @brief   test for kmo_is_in_range()
 */
-void test_kmo_is_in_range()
+void test_kmo_is_in_range(void)
 {
     cpl_vector  *ranges = NULL,
                 *lambda = NULL;
@@ -123,7 +123,7 @@ void test_kmo_is_in_range()
 /**
     @brief   test for kmo_is_in_range()
 */
-void test_kmo_identify_slices()
+void test_kmo_identify_slices(void)
 {
     cpl_vector  *slices = NULL,
                 *ranges = NULL;
@@ -154,7 +154,7 @@ void test_kmo_identify_slices()
 /**
     @brief   test for kmo_is_in_range()
 */
-void test_kmo_identify_ranges()
+void test_kmo_identify_ranges(void)
 {
     float       tol     = 0.01;
     cpl_vector  *vec    = NULL;
@@ -213,7 +213,7 @@ void test_kmo_identify_ranges()
 /**
     @brief   test for kmo_identify_values()
 */
-void test_kmo_identify_values()
+void test_kmo_identify_values(void)
 {
     float       tol     = 0.01;
     cpl_vector  *vec    = NULL;
@@ -271,7 +271,7 @@ void test_kmo_identify_values()
 /**
  * @brief   test for kmo_image_get_stdev_median()
  */
-void test_kmo_image_get_stdev_median()
+void test_kmo_image_get_stdev_median(void)
 {
     cpl_image  *img    = NULL;
 
@@ -310,7 +310,7 @@ void test_kmo_image_get_stdev_median()
 /**
  * @brief   test for kmos_combine_pars_create()
  */
-void test_kmos_combine_pars_create()
+void test_kmos_combine_pars_create(void)
 {
     cpl_test_eq(-1, kmos_combine_pars_create(NULL, NULL, NULL, -1));
 
@@ -338,7 +338,7 @@ void test_kmos_combine_pars_create()
 /**
  * @brief   test for kmos_band_pars_create()
  */
-void test_kmos_band_pars_create()
+void test_kmos_band_pars_create(void)
 {
     kmos_band_pars_create(NULL, NULL);
 
@@ -347,7 +347,7 @@ void test_kmos_band_pars_create()
     cpl_test_eq(0, cpl_parameterlist_get_size(pl));
 
     kmos_band_pars_create(pl, "recipeA");
-    cpl_test_eq(3, cpl_parameterlist_get_size(pl));
+    cpl_test_eq(1, cpl_parameterlist_get_size(pl));
 
     cpl_test_error(CPL_ERROR_NONE);
 
@@ -357,7 +357,7 @@ void test_kmos_band_pars_create()
 /**
  * @brief   test for kmos_combine_pars_load()
  */
-void test_kmos_combine_pars_load()
+void test_kmos_combine_pars_load(void)
 {
     kmo_test_verbose_off();
     kmos_combine_pars_load(NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, FALSE);
@@ -417,7 +417,7 @@ void test_kmos_combine_pars_load()
 /**
  * @brief   test for kmos_band_pars_load()
  */
-void test_kmos_band_pars_load()
+void test_kmos_band_pars_load(void)
 {
     kmo_test_verbose_off();
     kmos_band_pars_load(NULL, NULL);
@@ -442,7 +442,7 @@ void test_kmos_band_pars_load()
 /**
  * @brief   test for kmo_check_frameset_setup()
  */
-void test_kmo_check_frameset_setup()
+void test_kmo_check_frameset_setup(void)
 {
     kmo_test_verbose_off();
     kmo_check_frameset_setup(NULL, NULL, 0, 0, 0);
@@ -513,7 +513,7 @@ void test_kmo_check_frameset_setup()
 /**
  * @brief   test for kmo_check_frame_setup()
  */
-void test_kmo_check_frame_setup()
+void test_kmo_check_frame_setup(void)
 {
     kmo_test_verbose_off();
     kmo_check_frame_setup(NULL, NULL, NULL, 0, 0, 0);
@@ -584,7 +584,7 @@ void test_kmo_check_frame_setup()
 /**
  * @brief   test for kmo_priv_compare_frameset_setup()
  */
-void test_kmo_priv_compare_frameset_setup()
+void test_kmo_priv_compare_frameset_setup(void)
 {
     cpl_frame *fr1 = cpl_frame_new();
     cpl_frame_set_tag(fr1, FLAT_ON);
@@ -655,7 +655,7 @@ void test_kmo_priv_compare_frameset_setup()
 /**
     @brief   Test of helper functions needed in several recipes
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
