@@ -38,7 +38,6 @@ void kmo_test_verbose_off();
 */
 void test_kmo_lcorr_create_lambda_vector(cpl_propertylist *header) {
 
-    cpl_vector *spectrum = NULL;
     double tol = 0.000001;
 
     /* --- invalid tests --- */
@@ -46,6 +45,7 @@ void test_kmo_lcorr_create_lambda_vector(cpl_propertylist *header) {
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     /* --- valid tests --- */
+    cpl_vector *spectrum = NULL;
     cpl_test_noneq_ptr(NULL, spectrum = kmo_lcorr_create_lambda_vector(header));
     cpl_test_abs(cpl_vector_get(spectrum, 0), 1.46000003814697, tol);
     cpl_test_abs(cpl_vector_get(spectrum, 1), 1.4604639053577531, tol);
@@ -53,13 +53,11 @@ void test_kmo_lcorr_create_lambda_vector(cpl_propertylist *header) {
     cpl_test_abs(cpl_vector_get(spectrum, 1001), 1.924331116140817, tol);
     cpl_test_abs(cpl_vector_get(spectrum, 2046), 2.4090723514091188, tol);
     cpl_test_abs(cpl_vector_get(spectrum, 2047), 2.4095362186199019, tol);
-
     cpl_vector_delete(spectrum);
 }
 
 void test_kmo_lcorr_read_reference_spectrum(const char *filename, cpl_vector *lambda) {
 
-    cpl_bivector *spectrum = NULL;
     double tol = 0.000001;
 
     /* --- invalid tests --- */
@@ -69,36 +67,37 @@ void test_kmo_lcorr_read_reference_spectrum(const char *filename, cpl_vector *la
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     /* --- valid tests --- */
-    cpl_test_noneq_ptr(NULL, spectrum = kmo_lcorr_read_reference_spectrum(filename, lambda));
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),0), 0.045893, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),1), 0.658884, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),1165), 0.21426816, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),1166), 0.90487508, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),1488), 0.077060191, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),1489), 0.80229586, tol);
-    cpl_bivector_delete(spectrum);
+    cpl_bivector *spectrum1 = NULL;
+    cpl_test_noneq_ptr(NULL, spectrum1 = kmo_lcorr_read_reference_spectrum(filename, lambda));
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum1),0), 0.045893, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum1),1), 0.658884, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum1),1165), 0.21426816, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum1),1166), 0.90487508, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum1),1488), 0.077060191, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum1),1489), 0.80229586, tol);
+    cpl_bivector_delete(spectrum1);
 
-    cpl_test_noneq_ptr(NULL, spectrum = kmo_lcorr_read_reference_spectrum(filename, NULL));
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum),0), 1.40000, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum),1), 1.40001, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum),2), 1.40002, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),0), 0.00077955999026654127, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),1), 0.00073621104860563684, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),2), 0.00069448298810292073, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum),10553), 1.50553, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum),10554), 1.50554, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum),10555), 1.50555, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),10553), 1.2842280400003749, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),10554), 1.2861153919782762, tol);
-    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum),10555), 1.2852328623318428, tol);
-    cpl_bivector_delete(spectrum);
+    cpl_bivector *spectrum2 = NULL;
+    cpl_test_noneq_ptr(NULL, spectrum2 = kmo_lcorr_read_reference_spectrum(filename, NULL));
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum2),0), 1.40000, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum2),1), 1.40001, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum2),2), 1.40002, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum2),0), 0.00077955999026654127, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum2),1), 0.00073621104860563684, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum2),2), 0.00069448298810292073, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum2),10553), 1.50553, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum2),10554), 1.50554, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_x(spectrum2),10555), 1.50555, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum2),10553), 1.2842280400003749, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum2),10554), 1.2861153919782762, tol);
+    cpl_test_abs(cpl_vector_get(cpl_bivector_get_y(spectrum2),10555), 1.2852328623318428, tol);
+    cpl_bivector_delete(spectrum2);
 }
 void test_kmo_lcorr_extract_spectrum (
         cpl_imagelist *obj_cube,
         cpl_propertylist *header,
         cpl_vector *ref_spectrum) {
 
-    cpl_bivector *spectrum = NULL;
     double min_frac = 0.8;
     cpl_vector *range = cpl_vector_new(4);
     cpl_vector *broken_range = cpl_vector_new(3);
@@ -114,13 +113,15 @@ void test_kmo_lcorr_extract_spectrum (
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     /* --- valid tests --- */
-    spectrum = kmo_lcorr_extract_spectrum(obj_cube, header, min_frac, range);
-    cpl_bivector_delete(spectrum);
+    cpl_bivector *spectrum1 = NULL;
+    spectrum1 = kmo_lcorr_extract_spectrum(obj_cube, header, min_frac, range);
+    cpl_bivector_delete(spectrum1);
 
-    spectrum = kmo_lcorr_extract_spectrum(obj_cube, header, min_frac, NULL);
-    cpl_test_vector_abs(cpl_bivector_get_y(spectrum), ref_spectrum, 1.);
+    cpl_bivector *spectrum2 = NULL;
+    spectrum2 = kmo_lcorr_extract_spectrum(obj_cube, header, min_frac, NULL);
+    cpl_test_vector_abs(cpl_bivector_get_y(spectrum2), ref_spectrum, 1.);
 //    cpl_vector_save(cpl_bivector_get_y(spectrum), "lcorr_spec.fits", CPL_TYPE_DOUBLE, NULL, CPL_IO_CREATE);
-    cpl_bivector_delete(spectrum);
+    cpl_bivector_delete(spectrum2);
 
     cpl_vector_delete(range);
     cpl_vector_delete(broken_range);
@@ -238,7 +239,6 @@ void test_kmo_lcorr_get_peak_positions(cpl_bivector *spectrum) {
 
 void test_kmo_lcorr_get_peak_lambdas(cpl_bivector *spectrum) {
 
-    cpl_vector *pos;
     double min_frac = 0.2;
     double tol = 0.00001;
     cpl_vector *range = cpl_vector_new(4);
@@ -254,27 +254,30 @@ void test_kmo_lcorr_get_peak_lambdas(cpl_bivector *spectrum) {
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     /* --- valid tests --- */
-    cpl_test_noneq_ptr(NULL, pos = kmo_lcorr_get_peak_lambdas(spectrum, min_frac, NULL));
-    cpl_test_eq(cpl_vector_get_size(pos), 77);
-    cpl_vector_delete(pos);
 
-    cpl_test_noneq_ptr(NULL, pos = kmo_lcorr_get_peak_lambdas(spectrum, min_frac, range));
-    cpl_test_abs(cpl_vector_get_size(pos), 40, tol);
-    cpl_test_abs(cpl_vector_get(pos,0), 1.50554, tol);
-    cpl_test_abs(cpl_vector_get(pos,1), 1.50689, tol);
-    cpl_test_abs(cpl_vector_get(pos,20), 1.66923, tol);
-    cpl_test_abs(cpl_vector_get(pos,21), 1.67088, tol);
+    cpl_vector *pos1;
+    cpl_test_noneq_ptr(NULL, pos1 = kmo_lcorr_get_peak_lambdas(spectrum, min_frac, NULL));
+    cpl_test_eq(cpl_vector_get_size(pos1), 77);
+    cpl_vector_delete(pos1);
+
+    cpl_vector *pos2;
+    cpl_test_noneq_ptr(NULL, pos2 = kmo_lcorr_get_peak_lambdas(spectrum, min_frac, range));
+    cpl_test_abs(cpl_vector_get_size(pos2), 40, tol);
+    cpl_test_abs(cpl_vector_get(pos2,0), 1.50554, tol);
+    cpl_test_abs(cpl_vector_get(pos2,1), 1.50689, tol);
+    cpl_test_abs(cpl_vector_get(pos2,20), 1.66923, tol);
+    cpl_test_abs(cpl_vector_get(pos2,21), 1.67088, tol);
+    cpl_vector_delete(pos2);
 
 
     cpl_vector_delete(range);
     cpl_vector_delete(broken_range);
-    cpl_vector_delete(pos);
 }
 
 void test_kmo_lcorr_crosscorrelate_spectra (cpl_bivector *object,
         cpl_bivector *reference,
         cpl_vector *peaks,
-        char *band_id) {
+        const char *band_id) {
     cpl_polynomial *coeffs = NULL;
     cpl_size pows[1];
     double tol = 0.00001;
@@ -294,7 +297,7 @@ void test_kmo_lcorr_crosscorrelate_spectra (cpl_bivector *object,
 /**
     @brief   Test of helper functions for kmo_reconstruct
 */
-int main()
+int main(void)
 {
     cpl_imagelist  *obj_cube = NULL;
     cpl_image      *obj_mask = NULL;
