@@ -38,7 +38,7 @@ void kmo_test_fill_vector(cpl_vector *vec, float seed, float offset);
 /**
     @brief   test for kmo_identify_slices_with_oh()
 */
-void test_kmo_identify_slices_with_oh()
+void test_kmo_identify_slices_with_oh(void)
 {
     cpl_vector  *data   = NULL,
                 *lambda = NULL,
@@ -94,7 +94,7 @@ void test_kmo_identify_slices_with_oh()
 /**
     @brief   Test of helper functions for kmo_make_image
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
