@@ -37,7 +37,7 @@ void kmo_test_fill_image(cpl_image *img, float seed, float offset);
 /**
     @brief   test for kmo_calc_noise_map
 */
-void test_kmo_calc_noise_map()
+void test_kmo_calc_noise_map(void)
 {
     int       size2D        = 100,
               rej           = 0;
@@ -76,7 +76,7 @@ void test_kmo_calc_noise_map()
 /**
     @brief   Test of helper functions for kmo_noise_map
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
