@@ -39,7 +39,7 @@ void kmo_test_verbose_on();
 /**
     @brief   test for kmo_calc_flux_in()
 */
-void test_kmo_calc_flux_in()
+void test_kmo_calc_flux_in(void)
 {
     float tol = 0.01;
 
@@ -90,41 +90,51 @@ void test_kmo_calc_flux_in()
 /**
     @brief   test for kmo_calc_wcs_gd()
 */
-void test_kmo_calc_wcs_gd()
+void test_kmo_calc_wcs_gd(void)
 {
     gridDefinition gd;
+    gd.lamdaDistanceScale    = 1.0;
+    gd.x.start               = -KMOS_PIXEL_RANGE/2;
+    gd.x.delta               = KMOS_PIXEL_RESOLUTION;
+    gd.x.dim                 = KMOS_SLITLET_X;
+    gd.y.start               = -KMOS_PIXEL_RANGE/2;
+    gd.y.delta               = KMOS_PIXEL_RESOLUTION;
+    gd.y.dim                 = KMOS_SLITLET_Y;
+    gd.l.dim                 = kmclipm_band_samples;
+    gd.neighborHood.distance = 1.001;
+    gd.neighborHood.scale    = PIXEL;
+    gd.neighborHood.type     = N_CUBE;
+    gd.method                = CUBIC_SPLINE;
+    gd.rot_na_angle          = 0.;
+    gd.rot_off_angle         = 0.;
+    gd.l.start               = -1;
+    gd.l.delta               = -1;
+
+
+    /* Illegal inputs */
+
     kmo_test_verbose_off();
-    kmo_calc_wcs_gd(NULL, NULL, -1, gd);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
 
-    char *my_path = cpl_sprintf("%s/ref_data/head.fits", getenv("srcdir"));
-    cpl_propertylist *pl1 = kmclipm_propertylist_load(my_path, 0);
-    cpl_propertylist_update_double(pl1, "ESO OCS TARG DITHA", 0);
-    cpl_propertylist_update_double(pl1, "ESO OCS TARG DITHD", 0);
-    kmo_calc_wcs_gd(pl1, NULL, -1, gd);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
+      kmo_calc_wcs_gd(NULL, NULL, -1, gd);
+      cpl_test_error(CPL_ERROR_NULL_INPUT);
+
+      char *my_path = cpl_sprintf("%s/ref_data/head.fits", getenv("srcdir"));
+      cpl_propertylist *pl1 = kmclipm_propertylist_load(my_path, 0);
+      cpl_propertylist_update_double(pl1, "ESO OCS TARG DITHA", 0);
+      cpl_propertylist_update_double(pl1, "ESO OCS TARG DITHD", 0);
+      kmo_calc_wcs_gd(pl1, NULL, -1, gd);
+      cpl_test_error(CPL_ERROR_NULL_INPUT);
+
+      cpl_propertylist *pl2 = kmclipm_propertylist_load(my_path, 1);
+      cpl_free(my_path);
+      kmo_calc_wcs_gd(pl1, pl2, -1, gd);
+      cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
 
-    cpl_propertylist *pl2 = kmclipm_propertylist_load(my_path, 1);
-    cpl_free(my_path);
-    kmo_calc_wcs_gd(pl1, pl2, -1, gd);
-    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     kmo_test_verbose_on();
 
-    gd.lamdaDistanceScale = 1.0;
-    gd.x.start = -KMOS_PIXEL_RANGE/2;
-    gd.x.delta = KMOS_PIXEL_RESOLUTION;
-    gd.x.dim = KMOS_SLITLET_X;
-    gd.y.start = -KMOS_PIXEL_RANGE/2;
-    gd.y.delta = KMOS_PIXEL_RESOLUTION;
-    gd.y.dim = KMOS_SLITLET_Y;
-    gd.l.dim = kmclipm_band_samples;
-    gd.neighborHood.distance = 1.001;
-    gd.neighborHood.scale = PIXEL;
-    gd.neighborHood.type = N_CUBE;
-    gd.method = CUBIC_SPLINE;
 
-    gd.l.start = -1;
-    gd.l.delta = -1;
+    /* Legal inputs */
+
     kmo_calc_wcs_gd(pl1, pl2, 2, gd);
     cpl_test_error(CPL_ERROR_NONE);
 
@@ -132,6 +142,10 @@ void test_kmo_calc_wcs_gd()
     gd.l.delta = 0.01;
     kmo_calc_wcs_gd(pl1, pl2, 2, gd);
     cpl_test_error(CPL_ERROR_NONE);
+
+
+    /* Test values */
+
     cpl_test_abs(0.0444875, cpl_propertylist_get_double(pl2, CRVAL1), 0.0001);
     cpl_test_abs(-84.9851, cpl_propertylist_get_double(pl2, CRVAL2), 0.0001);
     cpl_test_abs(10, cpl_propertylist_get_double(pl2, CRVAL3), 0.0001);
@@ -156,6 +170,9 @@ void test_kmo_calc_wcs_gd()
     cpl_test_eq_string("H", cpl_propertylist_get_string(pl2, "ESO INS FILT1 ID"));
 
     cpl_test_error(CPL_ERROR_NONE);
+
+
+    /* Clean up */
     cpl_propertylist_delete(pl1);
     cpl_propertylist_delete(pl2);
 }
@@ -163,7 +180,7 @@ void test_kmo_calc_wcs_gd()
 /**
     @brief   test for kmo_save_det_img_ext()
 */
-void test_kmo_save_det_img_ext()
+void test_kmo_save_det_img_ext(void)
 {
 
     cpl_test_error(CPL_ERROR_NONE);
@@ -172,7 +189,7 @@ void test_kmo_save_det_img_ext()
 /**
     @brief   Test of helper functions for kmo_reconstruct
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
