@@ -36,7 +36,7 @@ void kmo_test_verbose_on();
 /**
     @brief   test for kmo_priv_rotate()
 */
-void test_kmo_priv_rotate()
+void test_kmo_priv_rotate(void)
 {
     kmo_test_verbose_off();
     kmo_priv_rotate(NULL, NULL, NULL, NULL, 20, 0, 2, "NN", NONE_CLIPPING);
@@ -243,7 +243,7 @@ void test_kmo_priv_rotate()
 /**
     @brief   Test of helper functions for kmo_rotate
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
