@@ -37,7 +37,7 @@ cpl_imagelist* kmo_test_create_cube(int x, int y, int z, int gauss, int *offset)
 /**
     @brief   test for kmo_calc_sky_mask()
 */
-void test_kmo_calc_sky_mask()
+void test_kmo_calc_sky_mask(void)
 {
     float           tol     = 0.1;
 
@@ -130,7 +130,7 @@ void test_kmo_calc_sky_mask()
 /**
     @brief   Test of helper functions for kmo_sky_mask
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
