@@ -37,7 +37,7 @@ void kmo_test_verbose_on();
 /**
     @brief   Test for kmo_calc_stats_cube()
  */
-void test_kmo_calc_stats_cube()
+void test_kmo_calc_stats_cube(void)
 {
     float           tol     = 0.01;
     int             i       = 0,
@@ -177,7 +177,7 @@ void test_kmo_calc_stats_cube()
 /**
     @brief   Test for kmo_calc_stats_img()
  */
-void test_kmo_calc_stats_img()
+void test_kmo_calc_stats_img(void)
 {
     float           tol     = 0.01;
     int             i       = 0,
@@ -293,7 +293,7 @@ void test_kmo_calc_stats_img()
 /**
     @brief   Test for kmo_calc_stats_vec()
  */
-void test_kmo_calc_stats_vec()
+void test_kmo_calc_stats_vec(void)
 {
     float           tol     = 0.01;
     int             dummy   = 0;
@@ -390,7 +390,7 @@ void test_kmo_calc_stats_vec()
 /**
     @brief   Test for kmo_count_masked_pixels()
  */
-void test_kmo_count_masked_pixels()
+void test_kmo_count_masked_pixels(void)
 {
     cpl_image       *img        = NULL;
 
@@ -412,7 +412,7 @@ void test_kmo_count_masked_pixels()
 /**
     @brief   Test for kmo_vector_identify_infinite()
  */
-void test_kmo_vector_identify_infinite()
+void test_kmo_vector_identify_infinite(void)
 {
     float           tol         = 0.01;
     cpl_vector      *vec1       = NULL,
@@ -443,7 +443,7 @@ void test_kmo_vector_identify_infinite()
 /**
     @brief   Test for kmo_imagelist_to_vector()
  */
-void test_kmo_imagelist_to_vector()
+void test_kmo_imagelist_to_vector(void)
 {
     float           tol         = 0.01;
     kmclipm_vector  *vec        = NULL;
@@ -533,7 +533,7 @@ void test_kmo_imagelist_to_vector()
 /**
     @brief   Test for kmo_image_to_vector()
  */
-void test_kmo_image_to_vector()
+void test_kmo_image_to_vector(void)
 {
     cpl_image       *img1 = NULL,
                     *img2 = NULL,
@@ -592,7 +592,7 @@ void test_kmo_image_to_vector()
 /**
     @brief   Test for kmo_calc_mode()
  */
-void test_kmo_calc_mode()
+void test_kmo_calc_mode(void)
 {
     float          tol          = 0.01;
     double         mode         = -1.0,
@@ -657,7 +657,7 @@ void test_kmo_calc_mode()
 /**
     @brief   Test for kmo_reject_sigma()
  */
-void test_kmo_reject_sigma()
+void test_kmo_reject_sigma(void)
 {
     float       tol     = 0.01;
     double      sigma   = 1.0;
@@ -707,7 +707,7 @@ void test_kmo_reject_sigma()
 /**
     @brief   Test for kmo_calc_remaining()
  */
-void test_kmo_calc_remaining()
+void test_kmo_calc_remaining(void)
 {
     kmclipm_vector  *vec1   = NULL,
                     *out    = NULL;
@@ -743,7 +743,7 @@ void test_kmo_calc_remaining()
 /**
     @brief   Test of helper functions for kmo_stats
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
