@@ -33,7 +33,7 @@
 /**
     @brief   test kmo_calc_fitted_slitlet_edge()
 */
-void test_kmo_calc_fitted_slitlet_edge()
+void test_kmo_calc_fitted_slitlet_edge(void)
 {
     int left_edge   = 0,
         right_edge  = 0;
@@ -89,7 +89,7 @@ void test_kmo_calc_fitted_slitlet_edge()
     cpl_test_error(CPL_ERROR_NONE);
 }
 
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
