@@ -45,7 +45,7 @@ void kmo_test_fill_vector(cpl_vector *vec, float seed, float offset);
 /**
     @brief   test for kmos_get_license()
 */
-void test_kmos_get_license()
+void test_kmos_get_license(void)
 {
     const char *ch = NULL;
 
@@ -55,7 +55,7 @@ void test_kmos_get_license()
 /**
     @brief   test kmo_cut_endings()
 */
-void test_kmo_cut_endings()
+void test_kmo_cut_endings(void)
 {
     cpl_vector  *vec = cpl_vector_new(5);
     int begin = 0, end = 0;
@@ -96,7 +96,7 @@ void test_kmo_cut_endings()
 /**
     @brief   test kmo_easy_gaussfit()
 */
-void test_kmo_easy_gaussfit()
+void test_kmo_easy_gaussfit(void)
 {
     cpl_vector  *x = cpl_vector_new(5),
                 *y = cpl_vector_new(5);
@@ -133,7 +133,7 @@ void test_kmo_easy_gaussfit()
 /**
     @brief   test kmo_polyfit_1d()
 */
-void test_kmo_polyfit_1d()
+void test_kmo_polyfit_1d(void)
 {
     cpl_vector  *x = cpl_vector_new(5),
                 *y = cpl_vector_new(5),
@@ -168,7 +168,7 @@ void test_kmo_polyfit_1d()
 /**
     @brief   test kmo_to_deg()
 */
-void test_kmo_to_deg()
+void test_kmo_to_deg(void)
 {
     kmo_test_verbose_off();
     cpl_test_abs(0, kmo_to_deg(10000001), 0.01);
@@ -185,7 +185,7 @@ void test_kmo_to_deg()
 /**
     @brief   test kmo_string_to_frame_type()
 */
-void test_kmo_string_to_frame_type()
+void test_kmo_string_to_frame_type(void)
 {
     cpl_test_eq(ifu_frame, kmo_string_to_frame_type("F2I"));
     cpl_test_eq(ifu_frame, kmo_string_to_frame_type("F3I"));
@@ -212,7 +212,7 @@ void test_kmo_string_to_frame_type()
 /**
     @brief   test kmo_identify_fits_header()
 */
-void test_kmo_identify_fits_header()
+void test_kmo_identify_fits_header(void)
 {
     main_fits_desc       main_desc;
 
@@ -247,7 +247,7 @@ void test_kmo_identify_fits_header()
 /**
     @brief   test kmo_identify_fits_sub_header()
 */
-void test_kmo_identify_fits_sub_header()
+void test_kmo_identify_fits_sub_header(void)
 {
     sub_fits_desc       sub_desc;
 
@@ -263,7 +263,7 @@ void test_kmo_identify_fits_sub_header()
 /**
     @brief   test for kmo_check_indices()
 */
-void test_kmo_check_indices()
+void test_kmo_check_indices(void)
 {
     kmo_test_verbose_off();
     kmo_check_indices(NULL, -1, -1);
@@ -295,7 +295,7 @@ void test_kmo_check_indices()
 /**
     @brief   test kmo_free_fits_desc()
 */
-void test_kmo_free_fits_desc()
+void test_kmo_free_fits_desc(void)
 {
     main_fits_desc       main_desc;
 
@@ -316,7 +316,7 @@ void test_kmo_free_fits_desc()
 /**
     @brief   test kmo_init_fits_desc()
 */
-void test_kmo_init_fits_desc()
+void test_kmo_init_fits_desc(void)
 {
     main_fits_desc       main_desc;
 
@@ -343,7 +343,7 @@ void test_kmo_init_fits_desc()
 /**
     @brief   test for kmo_init_fits_sub_desc()
 */
-void test_kmo_init_fits_sub_desc()
+void test_kmo_init_fits_sub_desc(void)
 {
     kmo_test_verbose_off();
     kmo_init_fits_sub_desc(NULL);
@@ -363,7 +363,7 @@ void test_kmo_init_fits_sub_desc()
 /**
     @brief   test kmo_idl_where()
 */
-void test_kmo_idl_where()
+void test_kmo_idl_where(void)
 {
     cpl_vector  *vec    = cpl_vector_new(5),
                 *res    = NULL;
@@ -385,7 +385,7 @@ void test_kmo_idl_where()
 /**
     @brief   test kmo_idl_values_at_indices()
 */
-void test_kmo_idl_values_at_indices()
+void test_kmo_idl_values_at_indices(void)
 {
     cpl_vector  *vec    = cpl_vector_new(5),
                 *res    = NULL,
@@ -416,7 +416,7 @@ void test_kmo_idl_values_at_indices()
 /**
     @brief   Test for kmo_get_unused_ifus()
 */
-void test_kmo_get_unused_ifus()
+void test_kmo_get_unused_ifus(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_get_unused_ifus(NULL, 1, 1));
@@ -501,7 +501,7 @@ void test_kmo_get_unused_ifus()
 /**
     @brief   Test for kmo_set_unused_ifus()
 */
-void test_kmo_set_unused_ifus()
+void test_kmo_set_unused_ifus(void)
 {
     kmo_test_verbose_off();
     kmo_set_unused_ifus(NULL, NULL, NULL);
@@ -567,7 +567,7 @@ void test_kmo_set_unused_ifus()
 /**
     @brief   Test for kmo_duplicate_unused_ifus()
 */
-void test_kmo_duplicate_unused_ifus()
+void test_kmo_duplicate_unused_ifus(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_duplicate_unused_ifus(NULL));
@@ -616,7 +616,7 @@ void test_kmo_duplicate_unused_ifus()
 /**
     @brief   Test for kmo_print_unused_ifus()
 */
-void test_kmo_print_unused_ifus()
+void test_kmo_print_unused_ifus(void)
 {
     kmo_test_verbose_off();
     kmo_print_unused_ifus(NULL, -1);
@@ -668,7 +668,7 @@ void test_kmo_print_unused_ifus()
 /**
     @brief   Test for kmo_free_unused_ifus()
 */
-void test_kmo_free_unused_ifus()
+void test_kmo_free_unused_ifus(void)
 {
     kmo_test_verbose_off();
     kmo_free_unused_ifus(NULL);
@@ -712,7 +712,7 @@ void test_kmo_free_unused_ifus()
 /**
     @brief   Test for kmo_strsplit()
 */
-void test_kmo_strsplit()
+void test_kmo_strsplit(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_strsplit(NULL, NULL, NULL));
@@ -767,7 +767,7 @@ void test_kmo_strsplit()
 /**
     @brief   Test for kmo_strfreev()
 */
-void test_kmo_strfreev()
+void test_kmo_strfreev(void)
 {
     kmo_strfreev(NULL);
     cpl_test_error(CPL_ERROR_NONE);
@@ -783,7 +783,7 @@ void test_kmo_strfreev()
 /**
     @brief   Test for kmo_strlower()
 */
-void test_kmo_strlower()
+void test_kmo_strlower(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_strlower(NULL));
@@ -809,7 +809,7 @@ void test_kmo_strlower()
 /**
     @brief   Test for kmo_strupper()
 */
-void test_kmo_strupper()
+void test_kmo_strupper(void)
 {
     kmo_test_verbose_off();
     cpl_test_null(kmo_strupper(NULL));
@@ -835,7 +835,7 @@ void test_kmo_strupper()
 /**
     @brief   Test of utility functions
 */
-int main()
+int main(void)
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
