@@ -19,8 +19,8 @@ void kmo_test_verbose_off();
 /**
     @brief  
  */
-int main(){
-
+int main(void)
+{
     cpl_imagelist  *obj_cube = NULL,
                    *sky_cube = NULL;
     cpl_propertylist *obj_header = NULL;
