@@ -23,6 +23,7 @@
 
 #include <string.h>
 
+#include <math.h>
 #include <cpl.h>
 
 #include "kmo_debug.h"
@@ -32,6 +33,8 @@
 #include "kmo_priv_arithmetic.h"
 #include "kmo_constants.h"
 
+#define     FORBIDDEN_SCALAR        -99999.9
+
 static int kmo_arithmetic_create(cpl_plugin *);
 static int kmo_arithmetic_exec(cpl_plugin *);
 static int kmo_arithmetic_destroy(cpl_plugin *);
@@ -179,7 +182,7 @@ static int kmo_arithmetic_create(cpl_plugin *plugin)
                                 CPL_TYPE_DOUBLE,
                                 "The scalar operand",
                                 "kmos.kmo_arithmetic",
-                                -DBL_MAX);
+                                FORBIDDEN_SCALAR);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "scalar");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
@@ -263,7 +266,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                      *op2_1d             = NULL,
                      *op1_noise_1d       = NULL,
                      *op2_noise_1d       = NULL;
-    double           op2_scalar          = -DBL_MAX;
+    double           op2_scalar          = FORBIDDEN_SCALAR;
     int              ret_val             = 0,
                      nr_devices          = 0,
                      i                   = 0,
@@ -304,7 +307,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
         KMO_TRY_ASSURE((cpl_frameset_get_size(frameset) == 2) ||
                        ((cpl_frameset_get_size(frameset) == 1) &&
-                       (op2_scalar != -DBL_MAX)),
+                       (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3)),
                        CPL_ERROR_NULL_INPUT,
                        "Two fits-files or one fits-file and one "
                        "scalar must be provided!");
@@ -364,7 +367,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        "(KMOSTYPE must be F3I, F2I, F1I, F2D or RAW)!");
 
         // load descriptor, header of second operand
-        if (op2_scalar == -DBL_MAX) {
+        if (fabs(op2_scalar-FORBIDDEN_SCALAR) < 1e-3) {
             desc2 = kmo_identify_fits_header(
                             cpl_frame_get_filename(op2_frame));
             KMO_TRY_CHECK_ERROR_STATE_MSG("Provided fits file doesn't seem to "
@@ -535,7 +538,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 devnr1 = desc1.sub_desc[2 * i - 1].device_nr;
             }
 
-            if (op2_scalar == -DBL_MAX) {
+            if (fabs(op2_scalar-FORBIDDEN_SCALAR) < 1e-3) {
                 if (desc2.ex_noise == FALSE) {
                     devnr2 = desc2.sub_desc[i - 1].device_nr;
                 } else {
@@ -572,7 +575,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                     //
                     // process RAW & scalar
                     //
-                    else if (op2_scalar != -DBL_MAX) {
+                    else if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                         KMO_TRY_EXIT_IF_ERROR(
                             kmo_arithmetic_2D_scalar(op1_2d, op2_scalar, NULL,
                                                      op));
@@ -620,7 +623,8 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                     //
                     // process F2D & scalar
                     //
-                    else if (op2_scalar != -DBL_MAX) {
+
+                    else if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                         // process data & noise
                         if (desc1.ex_noise == TRUE) {
                             KMO_TRY_EXIT_IF_NULL(
@@ -657,7 +661,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                     // check if IFUs are valid
                     if (desc1.ex_noise == FALSE) {
                         if (desc1.sub_desc[i - 1].valid_data == TRUE) {
-                            if (op2_scalar != -DBL_MAX) {
+                            if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                                 calc_f3i = TRUE;
                             } else if (((single_ifu == TRUE) &&
                                         (desc2.sub_desc[0].valid_data == TRUE))
@@ -799,7 +803,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         //
                         // process F3I & scalar
                         //
-                        else if (op2_scalar != -DBL_MAX) {
+                        else if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                             if (desc1.ex_noise == TRUE) {
                                 KMO_TRY_EXIT_IF_NULL(
                                     op1_noise_3d = kmo_dfs_load_cube(frameset,
@@ -849,7 +853,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                               ) &&
                                 (desc2.ex_noise == TRUE)
                              ) ||
-                                (op2_scalar != -DBL_MAX)
+                                (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3)
                             )
                            )
                         {
@@ -874,7 +878,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                     // check if IFUs are valid
                     if (desc1.ex_noise == FALSE) {
                         if (desc1.sub_desc[i - 1].valid_data == TRUE) {
-                            if (op2_scalar != -DBL_MAX) {
+                            if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                                 calc_f2i = TRUE;
                             } else if (((single_ifu == TRUE) &&
                                         (desc2.sub_desc[0].valid_data == TRUE))
@@ -947,7 +951,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         //
                         // process F2I & scalar
                         //
-                        else if (op2_scalar != -DBL_MAX) {
+                        else if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                             if (desc1.ex_noise == TRUE) {
                                 KMO_TRY_EXIT_IF_NULL(
                                     op1_noise_2d = kmo_dfs_load_image(
@@ -991,7 +995,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         if ((desc1.ex_noise == TRUE)
                             &&
                             (((desc2.fits_type == f2i_fits) && (desc2.ex_noise == TRUE)) ||
-                             (op2_scalar != -DBL_MAX)))
+                             (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3)))
                         {
 
                             KMO_TRY_EXIT_IF_NULL(
@@ -1013,7 +1017,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                     // check if IFUs are valid
                     if (desc1.ex_noise == FALSE) {
                         if (desc1.sub_desc[i - 1].valid_data == TRUE) {
-                            if (op2_scalar != -DBL_MAX) {
+                            if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                                 calc_f1i = TRUE;
                             } else if (((single_ifu == TRUE) &&
                                         (desc2.sub_desc[0].valid_data == TRUE))
@@ -1086,7 +1090,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         //
                         // process F1I & scalar
                         //
-                        else if (op2_scalar != -DBL_MAX) {
+                        else if (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3) {
                             if (desc1.ex_noise == TRUE) {
                                 KMO_TRY_EXIT_IF_NULL(
                                     op1_noise_1d = kmo_dfs_load_vector(
@@ -1130,7 +1134,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         if ((desc1.ex_noise == TRUE)
                             &&
                             (((desc2.fits_type == f2i_fits) && (desc2.ex_noise == TRUE)) ||
-                             (op2_scalar != -DBL_MAX)))
+                             (fabs(op2_scalar-FORBIDDEN_SCALAR) > 1e-3)))
                         {
 
                             KMO_TRY_EXIT_IF_NULL(
