@@ -313,7 +313,7 @@ static int kmo_make_image(cpl_parameterlist *parlist, cpl_frameset *frameset)
         KMO_TRY_ASSURE((parlist != NULL) && (frameset != NULL),
                 CPL_ERROR_NULL_INPUT, "Not all input data is provided");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_make_image") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                 CPL_ERROR_ILLEGAL_INPUT,"Cannot identify RAW and CALIB frames");
 
         cpl_msg_info("", "--- Parameter setup for kmo_make_image ----");
