@@ -55,6 +55,13 @@
  *                          Functions prototypes
  *----------------------------------------------------------------------------*/
 
+static double kmos_get_median_from_positives(
+        cpl_image   *   exp_mask) ;
+static double kmos_get_mode(
+        cpl_imagelist   *   error) ;
+static int kmos_idp_set_nans(
+        cpl_imagelist   *   data, 
+        cpl_imagelist   *   error) ;
 static int  kmos_combine_collect_data(
         const cpl_propertylist  *   recons_prim_header,
         const cpl_propertylist  *   recons_ext_header,
@@ -212,8 +219,8 @@ static int kmos_combine_create(cpl_plugin *plugin)
     /* --method */
     p = cpl_parameter_new_value("kmos.kmos_combine.method", CPL_TYPE_STRING,
             "The shifting method:   "
-            "'none': no shifting, combined directly, "
-            "'header': shift according to WCS (default), "
+            "'none': no shifting, combined directly (default), "
+            "'header': shift according to WCS, "
             "'center': centering algorithm, "
             "'user': read shifts from file",
             "kmos.kmos_combine", "none");
@@ -404,7 +411,11 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
     int                 *   skip_ifus ;
     char                *   skip_ifus_str ;
     enum extrapolationType  extrapol_enum = NONE_CLIPPING;
-    double                  light_speed ;
+    double                  light_speed, mjd_start, mjd_end ;
+    char                *   date_obs ;
+    char                *   object_key ;
+    char                *   object_data_key ;
+    char                *   object_stat_key ;
     int                     i, j ;
 
     /* Check initial Entries */
@@ -711,9 +722,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                 cpl_vector_set(fwhm_ne,fwhm_count,
                                         light_speed/fwhm_ne_val) ;
                                 cpl_vector_set(pos_ar,fwhm_count,
-                                        pos_ar_val*lambda*1000/light_speed) ;
+                                        pos_ar_val*lambda/light_speed) ;
                                 cpl_vector_set(pos_ne,fwhm_count,
-                                        pos_ne_val*lambda*1000/light_speed) ;
+                                        pos_ne_val*lambda/light_speed) ;
                                 fwhm_count++ ;
                             }
 
@@ -824,9 +835,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                 cpl_vector_set(fwhm_ne,fwhm_count,
                                         light_speed/fwhm_ne_val) ;
                                 cpl_vector_set(pos_ar,fwhm_count,
-                                        pos_ar_val*lambda*1000/light_speed) ;
+                                        pos_ar_val*lambda/light_speed) ;
                                 cpl_vector_set(pos_ne,fwhm_count,
-                                        pos_ne_val*lambda*1000/light_speed) ;
+                                        pos_ne_val*lambda/light_speed) ;
                                 fwhm_count++ ;
                             }
 
@@ -946,26 +957,54 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         }
         cpl_vector_delete(sky_res_vec) ;
 
+        /* Make sure sky_rerr is within limits */
+        if (sky_rerr > 1.0) sky_rerr = 0.3;
+        if (sky_rerr <  0.0) sky_rerr =  0.3;
+
         /* Create String for the output header - IFUs usage */
         used_ifus_str = kmos_combine_create_ifus_string(used_frame_idx, 
                 used_ifus, data_cube_counter);
-        cpl_free(used_frame_idx) ;
         cpl_free(used_ifus) ;
         skip_ifus_str = kmos_combine_create_ifus_string(skip_frame_idx, 
                 skip_ifus, skip_cube_counter);
         cpl_free(skip_frame_idx) ;
         cpl_free(skip_ifus) ;
 
+        /* Setup output category COMBINE + ESO PRO CATG */
+        main_header = kmo_dfs_load_primary_header(rawframes, "0");
+        const char *tag = cpl_propertylist_get_string(main_header, 
+                CPL_DFS_PRO_CATG);
+
         /* Combine data */
         exp_mask = NULL ;
         cube_combined_noise = NULL ;
         cube_combined_data = NULL ;
-        if (kmo_priv_combine(data_cube_list, noise_cube_list, data_header_list,
-                    noise_header_list, data_cube_counter, noise_cube_counter, 
-                    name_loc, ifus_txt, method, "BCS", fmethod, filename, 
-                    cmethod, cpos_rej, cneg_rej, citer, cmin, cmax, 
-                    extrapol_enum, flux, &cube_combined_data, 
-                    &cube_combined_noise, &exp_mask) != CPL_ERROR_NONE) {
+
+        cpl_error_code err;
+        if (!suppress_extension || strcmp(name_loc, "mapping") == 0) {
+            err = kmo_priv_combine(data_cube_list, noise_cube_list,
+                                   data_header_list, noise_header_list,
+                                   data_cube_counter, noise_cube_counter,
+                                   name_loc, ifus_txt, method, "BCS",
+                                   fmethod, filename, cmethod,
+                                   cpos_rej, cneg_rej, citer, cmin, cmax,
+                                   extrapol_enum, flux, &cube_combined_data,
+                                   &cube_combined_noise, &exp_mask);
+        } else {
+            char *name_suppress = cpl_sprintf("%d", suppress_index);
+            err = kmo_priv_combine(data_cube_list, noise_cube_list,
+                                   data_header_list, noise_header_list,
+                                   data_cube_counter, noise_cube_counter,
+                                   name_suppress, ifus_txt, method, "BCS",
+                                   fmethod, filename, cmethod,
+                                   cpos_rej, cneg_rej, citer, cmin, cmax,
+                                   extrapol_enum, flux, &cube_combined_data,
+                                   &cube_combined_noise, &exp_mask);
+            cpl_free(name_suppress);
+        }
+
+        if (err != CPL_ERROR_NONE) {
+
             for (i = 0; i < data_cube_counter ; i++) 
                 cpl_imagelist_delete(data_cube_list[i]);
             for (i = 0; i < noise_cube_counter ; i++) 
@@ -974,21 +1013,30 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 cpl_propertylist_delete(data_header_list[i]);
             for (i = 0; i < noise_cube_counter ; i++) 
                 cpl_propertylist_delete(noise_header_list[i]);
+
             if (ifus != NULL) cpl_vector_delete(ifus);
+
             cpl_free(data_cube_list);
             cpl_free(noise_cube_list);
             cpl_free(data_header_list);
             cpl_free(noise_header_list);
+
             for (i = 0; i < name_vec_size ; i++) cpl_free(name_vec[i]);
+
             cpl_free(name_vec);
             cpl_free(used_ifus_str) ;
             cpl_free(skip_ifus_str) ;
             cpl_frameset_delete(rawframes) ;
+			      cpl_free(used_frame_idx) ;
+
             if (mapping_mode != NULL) cpl_free(mapping_mode) ;
+
             cpl_msg_error(__func__, "Failed Combination") ;
             cpl_error_set(__func__,CPL_ERROR_ILLEGAL_INPUT);
+
             return -1 ;
         }
+
         for (i = 0; i < data_cube_counter ; i++) 
             cpl_imagelist_delete(data_cube_list[i]);
         for (i = 0; i < noise_cube_counter ; i++) 
@@ -1006,6 +1054,7 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_free(noise_header_list);
         for (i = 0; i < name_vec_size ; i++) cpl_free(name_vec[i]);
         cpl_free(name_vec);
+		    cpl_free(used_frame_idx) ;
         if (mapping_mode != NULL) cpl_free(mapping_mode) ;
         cpl_image_delete(exp_mask);
         cpl_imagelist_delete(cube_combined_noise);
@@ -1015,24 +1064,21 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_frameset_delete(rawframes) ;
         */
 
+        /* Replace 0s by NANs at the beginning and at the end of the cube */
+        kmos_idp_set_nans(cube_combined_data, cube_combined_noise) ;
+
         /* Compute ABMAGLIM */
         abmaglim = kmos_idp_compute_abmaglim(cube_combined_data,
                 sky_res, data_header_list[0]) ;
 
         /* Save data */
         if (!suppress_extension) {
-            /* Setup output category COMBINE + ESO PRO CATG */
-            main_header = kmo_dfs_load_primary_header(rawframes, "0");
-            fn_combine = cpl_sprintf("%s_%s_%s", COMBINE,
-                    cpl_propertylist_get_string(main_header, CPL_DFS_PRO_CATG),
-                    name_vec[nv]);
-            fn_mask = cpl_sprintf("%s_%s_%s", EXP_MASK,
-                    cpl_propertylist_get_string(main_header, CPL_DFS_PRO_CATG),
-                    name_vec[nv]);
-            cpl_propertylist_delete(main_header);
+            fn_combine = cpl_sprintf("%s_%s_%s", COMBINE,  tag, name_vec[nv]  );
+            fn_mask    = cpl_sprintf("%s_%s_%s", EXP_MASK, tag, name_vec[nv]  );
         } else {
-            fn_combine = cpl_sprintf("%s_%d", COMBINE, suppress_index);
-            fn_mask = cpl_sprintf("%s_%d", EXP_MASK, suppress_index++);
+            fn_combine = cpl_sprintf("%s_%s_%d", COMBINE,  tag, suppress_index);
+            fn_mask    = cpl_sprintf("%s_%s_%d", EXP_MASK, tag, suppress_index);
+            suppress_index++;
         }
 
         /* Create PRO keys plist */
@@ -1046,13 +1092,7 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
         /* QC EXPMASK AVG */
         cpl_propertylist_update_double(plist, "ESO QC EXPMASK AVG",
-                cpl_image_get_mean(exp_mask)) ;
-
-		/* PIXNOISE */
-		cpl_propertylist_update_double(plist, KEY_PIXNOISE, 
-                cpl_image_get_median(
-                    cpl_imagelist_get_const(cube_combined_data, 1000))) ;
-        cpl_propertylist_set_comment(plist, KEY_PIXNOISE, KEY_PIXNOISE_COMMENT);
+                kmos_get_median_from_positives(exp_mask)) ;
 
         /* Store SPEC_REC in the header */
         cpl_propertylist_update_double(plist, KEY_SPEC_RES, spec_res) ;
@@ -1088,17 +1128,211 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         /* Add REFLEX SUFFIX keyword */
         reflex_suffix = kmos_get_reflex_suffix(mapping_id,
                 ifus_txt, name, name_loc) ;
-        cpl_propertylist_update_string(plist, "ESO PRO REFLEX SUFFIX", 
+        cpl_propertylist_update_string(plist, "ESO PRO REFLEX SUFFIX",
                 reflex_suffix) ;
         cpl_free(reflex_suffix) ;
 
+        /* MJD Keys */
+        kmos_idp_compute_mjd(frameset, raw_tag, used_frame_idx,
+                data_cube_counter, &mjd_start, &mjd_end, &date_obs) ;
+
         /* Save Headers first */
         frame = cpl_frameset_find(rawframes, NULL);
-        kmo_dfs_save_main_header(frameset, fn_combine, "", frame, plist, 
-                parlist, cpl_func);
 
-        kmo_dfs_save_main_header(frameset, fn_mask, "", frame, plist, 
+        /* Build the Object keywords */
+        object_key =
+            cpl_sprintf("%s/%s", 
+                kmos_pfits_get_reflex_suffix(plist),
+                kmos_pfits_get_obs_targ_name(main_header));
+        object_data_key =
+            cpl_sprintf("%s/%s (DATA)", 
+                kmos_pfits_get_reflex_suffix(plist),
+                kmos_pfits_get_obs_targ_name(main_header));
+        object_stat_key =
+            cpl_sprintf("%s/%s (STAT)", 
+                kmos_pfits_get_reflex_suffix(plist),
+                kmos_pfits_get_obs_targ_name(main_header));
+
+        /* Truncate */
+        if (strlen(object_key) > 68) object_key[68] = 0;
+        if (strlen(object_data_key) > 68) object_data_key[68] = 0;
+        if (strlen(object_stat_key) > 68) object_stat_key[68] = 0;
+
+        /* Cleanup */
+        cpl_propertylist_delete(main_header);
+
+        /************/
+        /* EXP_MASK */
+        /************/
+
+        /***************************************************/
+        /* Replace the call kmo_dfs_save_main_header() */
+        /* because RA/DEC need to be changed              */
+        /***************************************************/
+        cpl_propertylist * plist2 = cpl_propertylist_duplicate(plist) ;
+
+        char * fname_expmap = cpl_sprintf("%s%s", fn_mask, ".fits") ;
+        char * my_procatg_expmap  = NULL ;
+        char * my_prodcatg_expmap  = NULL ;
+
+        /* NOTE: Modified to accept SINGLE_CUBES in kmos_combine (PIPE-7566) */
+        if (!strncmp(fn_mask, EXP_MASK_RECONS,
+                    strlen(EXP_MASK_RECONS))||
+                !strncmp(fn_mask, EXP_MASK_SINGLE_CUBES, 
+                    strlen(EXP_MASK_SINGLE_CUBES)) ){
+            /* DFS-6276 */
+            /* TRICK to fix the PROCATG=EXP_MASK_RECONS"_030" */
+            /* ------------->   PROCATG=EXP_MASK_RECONS */
+            my_procatg_expmap  = cpl_sprintf(EXP_MASK) ;
+            /* my_prodcatg_expmap = cpl_sprintf("ANCILLARY.EXPMAP") ; */
+            my_prodcatg_expmap = cpl_sprintf("ANCILLARY.PIXELCOUNTMAP") ;
+        } else {
+            my_procatg_expmap = cpl_strdup(fn_mask) ;
+        }
+        cpl_propertylist_update_string(plist2, CPL_DFS_PRO_CATG,
+                my_procatg_expmap);
+        if (my_prodcatg_expmap != NULL) {
+            cpl_propertylist_update_string(plist2, KEY_PRODCATG,
+                    my_prodcatg_expmap);
+            cpl_free(my_prodcatg_expmap) ;
+            cpl_propertylist_set_comment(plist2, KEY_PRODCATG,
+                    KEY_PRODCATG_COMMENT);
+        }
+        cpl_propertylist_update_string(plist2, INSTRUMENT, "KMOS") ;
+
+        cpl_msg_info(cpl_func, "Writing FITS propertylist product(%s): %s", 
+                my_procatg_expmap, fname_expmap);
+
+        cpl_frame * product_frame_expmap = cpl_frame_new();
+        cpl_frame_set_filename(product_frame_expmap, fname_expmap);
+        cpl_frame_set_tag(product_frame_expmap, my_procatg_expmap);
+        cpl_frame_set_type(product_frame_expmap, CPL_FRAME_TYPE_ANY);
+        cpl_frame_set_group(product_frame_expmap, CPL_FRAME_GROUP_PRODUCT);
+        cpl_frame_set_level(product_frame_expmap, CPL_FRAME_LEVEL_FINAL);
+        cpl_free(my_procatg_expmap) ;
+
+        /* Add DataFlow keywords */
+        cpl_dfs_setup_product_header(plist2, product_frame_expmap, frameset, 
+                parlist, cpl_func, VERSION, CPL_DFS_PRO_DID, frame);
+
+        /* Set RA/DEC */
+ 
+        /* Fix RA / DEC <- Set to CRVAL1 / CRVAL2 */
+        /* plist2(RA / DEC) from plist3(CRVAL1 / CRVAL2) */
+        crval1 = cpl_propertylist_get_double(data_header_list[0], CRVAL1);
+        crval2 = cpl_propertylist_get_double(data_header_list[0], CRVAL2);
+        kmclipm_update_property_double(plist2, "RA", crval1, "") ;
+        kmclipm_update_property_double(plist2, "DEC", crval2, "") ;
+
+        /* Update OBJECT */
+        cpl_propertylist_update_string(plist2, "OBJECT", object_key) ;
+
+        /* Save and register */
+        cpl_propertylist_save(plist2, fname_expmap, CPL_IO_CREATE);
+        cpl_free(fname_expmap) ;
+        cpl_frameset_insert(frameset, product_frame_expmap);
+        /* cpl_frame_delete(product_frame_expmap); */
+
+        cpl_propertylist_delete(plist2) ;
+
+        /***************************************************/
+        /* Instead of :                                    */
+        /***************************************************/
+        /*
+        kmo_dfs_save_main_header(frameset, fn_mask, "", frame, plist,
                 parlist, cpl_func);
+        */
+
+        /* ASSON PROV */
+        kmos_idp_add_files_infos(plist, frameset, raw_tag, used_frame_idx,
+                data_cube_counter) ;
+        cpl_free(used_frame_idx) ;
+
+        /************/
+        /* COMBINED */
+        /************/
+
+        /***************************************************/
+        /* Replace the call kmo_dfs_save_main_header() */
+        /* because MJD-OBS need to be changed              */
+        /***************************************************/
+
+        char * fname = cpl_sprintf("%s%s", fn_combine, ".fits") ;
+        char * my_procatg = NULL ;
+        char * my_prodcatg = NULL ;
+
+        /* NOTE: Modified to accept SINGLE_CUBES in kmos_combine (PIPE-7566) */
+        if (!strncmp(fn_combine, COMBINED_RECONS, strlen(COMBINED_RECONS)) ||
+                !strncmp(fn_combine, COMBINED_SINGLE_CUBES, 
+                    strlen(COMBINED_SINGLE_CUBES))){
+            /* DFS-6227 */
+            /* TRICK to fix the PROCATG=COMBINED_RECONS"_030" */
+            /* ------------->   PROCATG=COMBINED_RECONS */
+            my_procatg = cpl_sprintf(COMBINED_CUBE);
+        } else {
+            my_procatg = cpl_strdup(fn_combine) ;
+        }
+        cpl_propertylist_update_string(plist, CPL_DFS_PRO_CATG, my_procatg);
+        if (my_prodcatg != NULL) {
+            cpl_propertylist_update_string(plist, KEY_PRODCATG, my_prodcatg);
+            cpl_free(my_prodcatg) ;
+            cpl_propertylist_set_comment(plist, KEY_PRODCATG,
+                    KEY_PRODCATG_COMMENT);
+        }
+        cpl_propertylist_update_string(plist, INSTRUMENT, "KMOS") ;
+
+        cpl_msg_info(cpl_func, "Writing FITS propertylist product(%s): %s", 
+                my_procatg, fname);
+
+        cpl_frame * product_frame = cpl_frame_new();
+        cpl_frame_set_filename(product_frame, fname);
+        cpl_frame_set_tag(product_frame, my_procatg);
+        cpl_frame_set_type(product_frame, CPL_FRAME_TYPE_ANY);
+        cpl_frame_set_group(product_frame, CPL_FRAME_GROUP_PRODUCT);
+        cpl_frame_set_level(product_frame, CPL_FRAME_LEVEL_FINAL);
+        cpl_free(my_procatg) ;
+
+        /* Add DataFlow keywords */
+        cpl_dfs_setup_product_header(plist, product_frame, frameset, parlist, 
+                cpl_func, VERSION, CPL_DFS_PRO_DID, frame);
+
+        /* Set DATE-OBS / MJD-OBS / MJD-END */
+        if (mjd_start > 0.0) {
+            if (date_obs != NULL) {
+                cpl_propertylist_update_string(plist, KEY_DATEOBS, date_obs) ;
+                cpl_free(date_obs) ;
+            } else {
+                cpl_propertylist_update_string(plist, KEY_DATEOBS, "") ;
+            }
+            cpl_propertylist_set_comment(plist, KEY_DATEOBS, 
+                    KEY_DATEOBS_COMMENT);
+
+            cpl_propertylist_update_double(plist, KEY_MJDOBS, mjd_start) ;
+            cpl_propertylist_set_comment(plist, KEY_MJDOBS, KEY_MJDOBS_COMMENT);
+        }
+        if (mjd_end > 0.0) {
+            cpl_propertylist_update_double(plist, KEY_MJDEND, mjd_end) ;
+            cpl_propertylist_set_comment(plist, KEY_MJDEND, KEY_MJDEND_COMMENT);
+        }
+
+        /* Update OBJECT */
+        cpl_propertylist_update_string(plist, "OBJECT", object_key) ;
+
+        /* Save and register */
+        cpl_propertylist_save(plist, fname, CPL_IO_CREATE);
+        cpl_free(fname) ;
+        cpl_frameset_insert(frameset, product_frame);
+        /* cpl_frame_delete(product_frame); */
+
+        /***************************************************/
+        /* Instead of :                                    */
+        /***************************************************/
+        /*
+        kmo_dfs_save_main_header(frameset, fn_combine, "", frame, plist,
+                parlist, cpl_func);
+        */
+        /***************************************************/
+
         cpl_propertylist_delete(plist) ;
         cpl_free(used_ifus_str) ;
         cpl_free(skip_ifus_str) ;
@@ -1120,6 +1354,14 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 cpl_propertylist_erase(noise_header_list[0], "ESO PRO IFUNR");
             }
         }
+
+		/* BUNIT <- HIERARCH ESO QC CUBE_UNIT */
+        cpl_propertylist_update_string(data_header_list[0], "BUNIT", 
+                kmos_pfits_get_qc_cube_unit(data_header_list[0])) ;
+        if (noise_header_list[0] != NULL) 
+            cpl_propertylist_update_string(noise_header_list[0], "BUNIT", 
+                    kmos_pfits_get_qc_cube_unit(noise_header_list[0])) ;
+
         /* Save DATA extension */
         plist = cpl_propertylist_duplicate(data_header_list[0]) ;
 
@@ -1127,21 +1369,42 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_propertylist_update_double(plist, KEY_CRDER3, crder3) ;
         cpl_propertylist_set_comment(plist, KEY_CRDER3, KEY_CRDER3_COMMENT);
 
+        /* Remove EXPTIME */
+        cpl_propertylist_erase(plist, "EXPTIME") ;
+
+        /* Update OBJECT (DATA) */
+        cpl_propertylist_update_string(plist, "OBJECT", object_data_key) ;
+
         kmo_dfs_save_cube(cube_combined_data, fn_combine, "", plist, 0./0.);
         cpl_propertylist_delete(plist) ;
         cpl_imagelist_delete(cube_combined_data);
 
         /* Save NOISE extension */
         plist = cpl_propertylist_duplicate(noise_header_list[0]) ;
+
+        /* Remove EXPTIME */
+        cpl_propertylist_erase(plist, "EXPTIME") ;
+
+        /* Update OBJECT (STAT) */
+        cpl_propertylist_update_string(plist, "OBJECT", object_stat_key) ;
+
         kmo_dfs_save_cube(cube_combined_noise, fn_combine, "", plist, 0./0.);
         cpl_imagelist_delete(cube_combined_noise);
         cpl_propertylist_delete(plist) ;
         cpl_free(fn_combine);
         
         /* Clean 3rd dimension keys */
-        kmos_3dim_clean_plist(data_header_list[0]) ;
+        plist = cpl_propertylist_duplicate(data_header_list[0]) ;
+        kmos_3dim_clean_plist(plist) ;
 
-        kmo_dfs_save_image(exp_mask, fn_mask, "", data_header_list[0], 0./0.);
+		/* Set BUNIT to '' */
+		cpl_propertylist_update_string(plist, "BUNIT", "") ;
+
+        /* Update OBJECT (DATA) */
+        cpl_propertylist_update_string(plist, "OBJECT", object_data_key) ;
+
+        kmo_dfs_save_image(exp_mask, fn_mask, "", plist, 0./0.);
+        cpl_propertylist_delete(plist) ;
         cpl_free(fn_mask);
         cpl_image_delete(exp_mask);
 
@@ -1151,6 +1414,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
             cpl_propertylist_delete(noise_header_list[i]);
         if (noise_header_list!=NULL && noise_cube_counter==0) 
             cpl_propertylist_delete(noise_header_list[0]) ;
+        cpl_free(object_key) ;
+        cpl_free(object_data_key) ;
+        cpl_free(object_stat_key) ;
     } 
     if (skipped_bivector!=NULL) cpl_bivector_delete(skipped_bivector) ;
     if (ifus != NULL) cpl_vector_delete(ifus);
@@ -1162,15 +1428,18 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
     cpl_free(name_vec);
     cpl_free(mapping_mode) ;
 
+    /********************************************/
     /* Collapse the combined cubes if requested */
+    /********************************************/
     if (collapse_combined) {
     	kmos_collapse_cubes(COMBINED_CUBE, frameset, parlist, 0.1, "",
     	                DEF_REJ_METHOD, DEF_POS_REJ_THRES, DEF_NEG_REJ_THRES,
     	                DEF_ITERATIONS, DEF_NR_MIN_REJ, DEF_NR_MAX_REJ);
-
     }
 
+    /***************************/
     /* Create the IDP Products */
+    /***************************/
     cpl_frame * combined_frame ;
     const char * combined_fname ;
     char * idp_combined_fname ;
@@ -1178,8 +1447,8 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
     const char * const_data_extname ;
     char * data_extname ;
     char * error_extname ;
-    char * object ;
     cpl_frameset * combined_frames ;
+    double  pixnoise ;
 
     /* Loop on the Combined Frames */
     combined_frames = kmos_extract_frameset(frameset,       COMBINED_CUBE) ;
@@ -1193,6 +1462,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         /* Compute the IDP error */
         cube_combined_error = kmos_idp_compute_error(cube_combined_data);
 
+        /* Compute the PIXNOISE from ERROR -> Primary Header */
+        pixnoise = kmos_get_mode(cube_combined_error) ;
+
         /************* IDP  PRIMARY  **********/
         main_header =   cpl_propertylist_load(combined_fname, 0) ;
         plist =         cpl_propertylist_load(combined_fname, 1) ;
@@ -1222,10 +1494,22 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
         plist = cpl_propertylist_duplicate(main_header);
 
+        /* Keep the MJD values before the get updated */
+        mjd_start = cpl_propertylist_get_double(plist, KEY_MJDOBS);
+        date_obs = cpl_strdup(cpl_propertylist_get_string(plist, KEY_DATEOBS));
+        mjd_end = cpl_propertylist_get_double(plist, KEY_MJDEND);
+
+        /* Keep OBJECT value */
+        object_key = cpl_strdup(kmos_pfits_get_object(plist)) ;
+
         /* Add DataFlow keywords */
         cpl_dfs_setup_product_header(plist, product_frame, frameset, parlist, 
                 cpl_func, VERSION, CPL_DFS_PRO_DID, frame);
 
+        /* Restore OBJECT */
+        cpl_propertylist_update_string(plist, "OBJECT", object_key) ;
+        cpl_free(object_key) ;
+
         /* Fix RA / DEC <- Set to CRVAL1 / CRVAL2 */
         /* plist(RA / DEC) from plist2(CRVAL1 / CRVAL2) */
         cpl_propertylist * plist2 = cpl_propertylist_load(combined_fname, 1) ;
@@ -1235,6 +1519,26 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         kmclipm_update_property_double(plist, "RA", crval1, "") ;
         kmclipm_update_property_double(plist, "DEC", crval2, "") ;
 
+        /* Set DATE-OBS / MJD-OBS / MJD-END */
+        if (mjd_start > 0.0) {
+			if (date_obs != NULL) {
+				cpl_propertylist_update_string(plist, KEY_DATEOBS, date_obs) ;
+				cpl_propertylist_set_comment(plist, KEY_DATEOBS, 
+						KEY_DATEOBS_COMMENT);
+            }
+            cpl_propertylist_update_double(plist, KEY_MJDOBS, mjd_start) ;
+            cpl_propertylist_set_comment(plist, KEY_MJDOBS, KEY_MJDOBS_COMMENT);
+        }
+        if (date_obs != NULL) cpl_free(date_obs) ;
+        if (mjd_end > 0.0) {
+            cpl_propertylist_update_double(plist, KEY_MJDEND, mjd_end) ;
+            cpl_propertylist_set_comment(plist, KEY_MJDEND, KEY_MJDEND_COMMENT);
+        }
+
+        /* Add PIXNOISE */
+		cpl_propertylist_update_double(plist, KEY_PIXNOISE, pixnoise) ;
+        cpl_propertylist_set_comment(plist, KEY_PIXNOISE, KEY_PIXNOISE_COMMENT);
+
         /* Save and register */
         cpl_propertylist_save(plist, idp_combined_fname, CPL_IO_CREATE);
         cpl_propertylist_delete(plist) ;
@@ -1250,10 +1554,6 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         */
         /***************************************************/
 
-        /* Remember OBJECT for the extensions */
-        object = cpl_strdup(kmos_pfits_get_object(main_header)) ;
-
-        cpl_propertylist_delete(main_header) ;
 
         /************* IDP DATA extension **********/
         /* Handle extname values */
@@ -1262,7 +1562,7 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         error_extname = kmos_idp_compute_error_extname(const_data_extname) ;
 
         /* IDP Add DATA Keywords */
-        kmos_idp_prepare_data_keys(plist, error_extname, object) ;
+        kmos_idp_prepare_data_keys(plist, error_extname) ;
         cpl_free(error_extname) ;
 
         /* Ѕave Data */
@@ -1278,11 +1578,22 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         kmclipm_update_property_string(plist, EXTNAME, "DATA", "");
         data_extname = cpl_strdup(kmos_pfits_get_extname(plist)) ;
         error_extname = kmos_idp_compute_error_extname(data_extname) ;
-        kmos_idp_prepare_error_keys(plist, error_extname, data_extname, object);
-        cpl_free(object) ;
+        kmos_idp_prepare_error_keys(plist, error_extname, data_extname);
         cpl_free(error_extname) ;
         cpl_free(data_extname) ;
 
+        /* Recreate the OBJECT key here */
+        object_stat_key =
+            cpl_sprintf("%s/%s (STAT)",
+                kmos_pfits_get_reflex_suffix(main_header),
+                kmos_pfits_get_obs_targ_name(main_header));
+
+        /* Truncate */
+        if (strlen(object_stat_key) > 68) object_stat_key[68] = 0;
+
+        /* Update header */
+        cpl_propertylist_update_string(plist, "OBJECT", object_stat_key) ;
+
         /* Save ERROR extension */
         cpl_imagelist_save(cube_combined_error, idp_combined_fname, 
                 CPL_BPP_IEEE_FLOAT,
@@ -1290,6 +1601,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_imagelist_delete(cube_combined_error);
         cpl_propertylist_delete(plist) ;
         cpl_free(idp_combined_fname) ;
+        cpl_propertylist_delete(main_header) ;
+
+        cpl_free(object_stat_key);
 
         /* Next candidate */
         combined_frame = kmo_dfs_get_frame(combined_frames, NULL);
@@ -1489,3 +1803,210 @@ static int kmos_combine_is_skipped(
     return 0 ;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Converts 0s to NANs at the beginning and the end of the cube
+  @param    data    data cube
+  @param    error   error cube
+  @return   0 if ok, -1 in error case
+ */
+/*----------------------------------------------------------------------------*/
+static int kmos_idp_set_nans(
+        cpl_imagelist   *   data, 
+        cpl_imagelist   *   error)
+{
+    cpl_image   *   data_curr ;
+    cpl_image   *   error_curr ;
+    float       *   pdata_curr ;
+    float       *   perror_curr ;
+    int             set_to_nan ;
+    cpl_size        i, j, k, nx, ny, ni ;
+
+    /* Check entries */
+    if (data == NULL || error == NULL) return -1 ;
+
+    /* Initialise */
+    data_curr = cpl_imagelist_get(data, 0) ;
+    nx = cpl_image_get_size_x(data_curr) ;
+    ny = cpl_image_get_size_y(data_curr) ;
+    ni = cpl_imagelist_get_size(data) ;
+
+    /* Loop on the pixels and set the beginning of the cube to NAN */
+    for (j=0 ; j<ny ; j++) {
+        for (i=0 ; i<nx ; i++) {
+            set_to_nan = 1 ;
+            for (k=0 ; k<ni && set_to_nan ; k++) {
+                data_curr = cpl_imagelist_get(data, k) ;
+                pdata_curr = cpl_image_get_data_float(data_curr) ;
+                error_curr = cpl_imagelist_get(error, k) ;
+                perror_curr = cpl_image_get_data_float(error_curr) ;
+                /* Set to nan */
+                if (fabs(pdata_curr[i+j*nx])<1e-50) {
+                    pdata_curr[i+j*nx] = 0./0. ;
+                } else {
+                    set_to_nan = 0 ;
+                }
+            }
+        }
+    }
+
+    /* Loop on the pixels and set the end of the cube to NAN */
+    for (j=0 ; j<ny ; j++) {
+        for (i=0 ; i<nx ; i++) {
+            set_to_nan = 1 ;
+            for (k=ni-1 ; k>=0 && set_to_nan ; k--) {
+                data_curr = cpl_imagelist_get(data, k) ;
+                pdata_curr = cpl_image_get_data_float(data_curr) ;
+                error_curr = cpl_imagelist_get(error, k) ;
+                perror_curr = cpl_image_get_data_float(error_curr) ;
+                /* Set to nan */
+                if (fabs(pdata_curr[i+j*nx])<1e-50) {
+                    pdata_curr[i+j*nx] = 0./0. ;
+                } else {
+                    set_to_nan = 0 ;
+                }
+            }
+        }
+    }
+    return 0 ;
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Get the Mode of the error
+  @param    error   error cube
+  @return   the mode
+ */
+/*----------------------------------------------------------------------------*/
+static double kmos_get_mode(
+        cpl_imagelist   *   cube)
+{
+    cpl_image   *   data_curr ;
+    float       *   pdata_curr ;
+    cpl_vector  *   values ;
+    double      *   pvalues ;
+    double          min, max ;
+    cpl_size        i, j, k, nx, ny, ni, nval ;
+    int         *   bins ;
+    int             nbins, ind ;
+
+    /* Check entries */
+    if (cube == NULL) return -1 ;
+
+    /* Initialise */
+    data_curr = cpl_imagelist_get(cube, 0) ;
+    nx = cpl_image_get_size_x(data_curr) ;
+    ny = cpl_image_get_size_y(data_curr) ;
+    ni = cpl_imagelist_get_size(cube) ;
+    nbins = 100000 ;
+    nval = 0 ; 
+
+    /* Count values */
+    for (k=0 ; k<ni ; k++) {
+        data_curr = cpl_imagelist_get(cube, k) ;
+        pdata_curr = cpl_image_get_data_float(data_curr) ;
+        for (j=0 ; j<ny ; j++) {
+            for (i=0 ; i<nx ; i++) {
+                if (!isnan(pdata_curr[i+j*nx])) {
+                    nval++ ;
+                }
+            }
+        }
+    }
+
+    /* Store Values */
+    values = cpl_vector_new(nval) ;
+    pvalues = cpl_vector_get_data(values) ;
+    nval = 0 ;
+    for (k=0 ; k<ni ; k++) {
+        data_curr = cpl_imagelist_get(cube, k) ;
+        pdata_curr = cpl_image_get_data_float(data_curr) ;
+        for (j=0 ; j<ny ; j++) {
+            for (i=0 ; i<nx ; i++) {
+                if (!isnan(pdata_curr[i+j*nx])) {
+                    pvalues[nval] = pdata_curr[i+j*nx] ;
+                    nval++ ;
+                }
+            }
+        }
+    }
+
+    /* Sort values */
+    cpl_vector_sort(values, CPL_SORT_ASCENDING) ;
+    pvalues = cpl_vector_get_data(values) ;
+
+    /* Count the bins */
+    min = pvalues[0] ;
+    max = pvalues[nval-1] ;
+    bins = cpl_calloc(nbins, sizeof(int)) ;
+    for (k=0 ; k<nval ; k++) {
+        ind = (int)(nbins * (pvalues[k] - min) / (max - min)) ; 
+        /* printf("%g -> %d\n", pvalues[k], ind) ; */
+        bins[ind]++ ;
+    }
+    cpl_vector_delete(values) ;
+
+    /* Get the Maximum bin */
+    ind = 0 ;
+    for (k=0 ; k<nbins ; k++) {
+        if (bins[k] > bins[ind]) ind = k ;
+        /* printf("%d %d\n", k, bins[k]) ; */
+    }
+    /* printf("%g %g  ind : %d %d\n", min, max, ind, bins[ind]) ; */
+
+    cpl_free(bins) ;
+    return min + (ind * (max-min) / nbins) ;
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Median of positive values
+  @param  
+  @return  
+ */
+/*----------------------------------------------------------------------------*/
+static double kmos_get_median_from_positives(
+        cpl_image   *   exp_mask)
+{
+    double          med ;
+    float       *   pexp_mask ;
+    cpl_size        nx, ny, i, j, npos ;
+    cpl_vector  *   pos_values ;
+    double      *   ppos_values ;
+
+    /* Check entries */
+    if (exp_mask == NULL) return -1.0 ;
+
+    /* Initialise */
+    npos = 0 ;
+    pexp_mask = cpl_image_get_data_float(exp_mask) ;
+    nx = cpl_image_get_size_x(exp_mask) ;
+    ny = cpl_image_get_size_y(exp_mask) ;
+   
+    /* Count pos values */
+    for (j=0 ; j<ny ; j++) {
+        for (i=0 ; i<nx ; i++) {
+            if (pexp_mask[i+j*nx] > 1e-3) npos++ ;
+        }
+    }
+
+
+    /* Store the positive values */
+    pos_values = cpl_vector_new(npos) ;
+    ppos_values = cpl_vector_get_data(pos_values) ;
+    npos = 0 ;
+    for (j=0 ; j<ny ; j++) {
+        for (i=0 ; i<nx ; i++) {
+            if (pexp_mask[i+j*nx] > 1e-3) {
+                ppos_values[npos] = pexp_mask[i+j*nx] ;
+                npos++ ;
+            }
+        }
+    }
+
+    /* Compute the median */
+    med = cpl_vector_get_median(pos_values);
+    cpl_vector_delete(pos_values) ;
+
+    return med ;
+}
