@@ -245,11 +245,13 @@ static int kmos_extract_spec(
     const char          *   cmethod ;
     const char          *   centre_txt ;
     cpl_vector          *   centre ;
-    int                     cmin, cmax, valid_ifu, citer, save_mask,
-                            devnr1, index_data, index_noise, 
-                            nr_devices ;
-    double                  cpos_rej, cneg_rej, radius, r, x_lo, y_lo,
-                            x_hi, y_hi, cen_x, cen_y, loc_cen_x, loc_cen_y ;
+    int                     cmin, cmax, valid_ifu, citer, save_mask, devnr1;
+    int                     index_data ;
+    int                     index_noise;
+    int                     nr_devices ;
+    double                  cpos_rej, cneg_rej, r, x_lo, y_lo,
+                            x_hi, y_hi, loc_cen_x, loc_cen_y ;
+    double                  cen_x = 0., cen_y = 0., radius = -1;
     cpl_size                auto_cen_x, auto_cen_y ;
     cpl_imagelist       *   data_in ; 
     cpl_imagelist       *   noise_in ; 
@@ -259,7 +261,7 @@ static int kmos_extract_spec(
     cpl_vector          *   spec_noise_out ;
     cpl_vector          *   fit_par ;
     cpl_propertylist    *   sub_header_data ;
-    cpl_propertylist    *   sub_header_noise ;
+    cpl_propertylist    *   sub_header_noise = NULL ;
     cpl_propertylist    *   sub_header_mask ;
     cpl_propertylist    *   fit_pl ;
     cpl_frame           *   op1_frame ;
@@ -373,6 +375,8 @@ static int kmos_extract_spec(
         }
         if (desc1.ex_noise) {
             index_noise = kmo_identify_index_desc(desc1, devnr1, TRUE);
+        } else {
+           index_noise = -1;
         }
         sub_header_data = kmo_dfs_load_sub_header(frameset, "0", devnr1, FALSE);
 
@@ -480,7 +484,7 @@ static int kmos_extract_spec(
             cpl_propertylist_delete(sub_header_mask);
 
             /* Process & save noise, if existing */
-            if (desc1.ex_noise) {
+            if (desc1.ex_noise && sub_header_noise) {
                 kmclipm_vector *nnn = NULL;
                 if (spec_noise_out != NULL) {
                     nnn = kmclipm_vector_create(spec_noise_out);
@@ -502,7 +506,9 @@ static int kmos_extract_spec(
             }
         }
         cpl_propertylist_delete(sub_header_data); 
-        if (desc1.ex_noise) cpl_propertylist_delete(sub_header_noise);
+        if (desc1.ex_noise && sub_header_noise) {
+        	cpl_propertylist_delete(sub_header_noise);
+        }
     }
     kmo_free_fits_desc(&desc1);
     kmo_free_fits_desc(&desc2);
