@@ -383,9 +383,9 @@ static int kmos_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
     char                *   suffix ;
     char                *   fn_suffix ;
     unsigned int            save_mode ;
-    char                *   fn_flat = "flat_tmp.fits" ;
-    char                *   fn_noise = "flat_noise.fits" ;
-    char                *   fn_badpix = "badpix_tmp.fits" ;
+    const char          *   fn_flat   = "flat_tmp.fits" ;
+    const char          *   fn_noise  = "flat_noise.fits" ;
+    const char          *   fn_badpix = "badpix_tmp.fits" ;
     cpl_imagelist       *   det_lamp_on ;
     cpl_imagelist       *   det_lamp_off ;
     cpl_image           *   img_in ;
@@ -407,11 +407,9 @@ static int kmos_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
     double                  gain, exptime, mean_data, mean_noise ;
     int                     sx, nr_bad_pix, nr_sat, i, j, a ;
 
-    /* Check entries */
-    if (parlist == NULL || frameset == NULL) {
-        cpl_msg_error(__func__, "Null Inputs") ;
-        cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
-        return -1 ;
+    /* Check initial Entries */
+    if (kmos_check_and_set_groups(frameset) != CPL_ERROR_NONE) {
+        return cpl_error_get_code();
     }
 
     /* Get Parameters */
@@ -448,13 +446,6 @@ static int kmos_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
         return -1 ;
     }
 
-    /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset) != 1) {
-        cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
-        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
-        return -1 ;
-    }
-
     /* Check the inputs consistency */
     if (kmos_flat_check_inputs(frameset, &nx, &ny, &next, &exptime) != 1) {
         cpl_msg_error(__func__, "Input frameset is not consistent") ;
