@@ -30,6 +30,7 @@
 
 #include <cpl.h>
 
+#include "kmclipm_priv_splines.h"
 #include "kmclipm_functions.h"
 #include "kmclipm_constants.h"
 
@@ -41,6 +42,13 @@
  *                          Functions prototypes
  *----------------------------------------------------------------------------*/
 
+static cpl_vector * kmos_gen_telluric_resample(
+        cpl_vector          *   vec,
+        int                     b_samples,
+        double                  crval1,
+        double                  cdelt1,
+        double              *   new_crval1,
+        double              *   new_cdelt1) ;
 static int kmos_gen_telluric_get_avg_zpoint(
         const cpl_frame     *   zp_frame, 
         double              *   zp1_avg,
@@ -52,12 +60,16 @@ static int kmos_gen_telluric_create_file_multiply(
         const cpl_frame         *   zp_frame,
         const char              *   filename,
         cpl_frameset            *   allframes,
+		int							b_samples,
         const cpl_parameterlist *   parlist) ;
 static int kmos_gen_telluric_create_file_simple(
         const cpl_frame         *   data_frame,
         const cpl_frame         *   zp_frame,
+        const cpl_frame         *   resp_frame,
         const char              *   filename,
         cpl_frameset            *   allframes,
+        int                         b_samples,
+        int                         fill_empty_ifus,
         const cpl_parameterlist *   parlist) ;
 
 static int kmos_gen_telluric_check_inputs(cpl_frameset *, int);
@@ -91,14 +103,14 @@ static char kmos_gen_telluric_description[] =
 "   DO category         Explanation                    Required \n"
 "   -----------         -----------                    -------- \n"
 "   TELLURIC            Produced  by kmos_std_star          N\n"
-"   TELLURIC_CORR       Produced  bym molecfit              N\n"
+"   TELLURIC_CORR       Produced  by molecfit               N\n"
 "   RESPONSE            static calibration                  N\n"
 "\n"
 "Output files:\n"
 "\n"
 "   DO category         Explanation\n"
 "   -----------         -----------\n"
-"   TELLURIC            Used by kmos_sci_red\n"
+"   TELLURIC_GEN        Used by kmos_sci_red\n"
 "----------------------------------------------------------------------------\n"
 "\n";
 
@@ -177,6 +189,22 @@ static int kmos_gen_telluric_create(cpl_plugin *plugin)
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
+    /* --b_samples */
+    p = cpl_parameter_new_value("kmos.kmos_gen_telluric.b_samples",
+            CPL_TYPE_INT, "The number of samples in wavelength",
+            "kmos.kmos_gen_telluric", -1);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "b_samples");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
+    /* --fill_empty_ifus */
+    p = cpl_parameter_new_value("kmos.kmos_gen_telluric.fill_empty_ifus",
+            CPL_TYPE_BOOL, "Flag to fill empty TELLURIC IFUs (only method 0)",
+            "kmos.kmos_gen_telluric", FALSE);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "fill_empty_ifus");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
     return 0;
 }
 
@@ -230,19 +258,15 @@ static int kmos_gen_telluric_destroy(cpl_plugin *plugin)
 static int kmos_gen_telluric(cpl_parameterlist *parlist, cpl_frameset *frameset)
 {
     const cpl_parameter     *   par ;
-    int                         method ;
+    int                         method, fill_empty_ifus, b_samples ;
     cpl_frame               *   tell_frame ;
     cpl_frame               *   tell_corr_frame ;
     cpl_frame               *   resp_frame ;
     const char              *   fn ;
-
-    int                         i, j, ifu_nr, ext_nb ;
     
-    /* Check entries */
-    if (parlist == NULL || frameset == NULL) {
-        cpl_msg_error(__func__, "Null Inputs") ;
-        cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
-        return -1 ;
+    /* Check initial Entries */
+    if (kmos_check_and_set_groups(frameset) != CPL_ERROR_NONE) {
+        return cpl_error_get_code();
     }
 
     /* Initialise */
@@ -251,12 +275,18 @@ static int kmos_gen_telluric(cpl_parameterlist *parlist, cpl_frameset *frameset)
     /* Get Parameters */
     par = cpl_parameterlist_find_const(parlist,"kmos.kmos_gen_telluric.method");
     method = cpl_parameter_get_int(par);
+    par = cpl_parameterlist_find_const(parlist,
+            "kmos.kmos_gen_telluric.b_samples");
+    b_samples = cpl_parameter_get_int(par);
+    par = cpl_parameterlist_find_const(parlist,
+            "kmos.kmos_gen_telluric.fill_empty_ifus");
+    fill_empty_ifus = cpl_parameter_get_bool(par);
 
-    /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset) != 1) {
-        cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
-        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
-        return -1 ;
+    /* Check Parameters */
+    if (method != 0 && fill_empty_ifus != 0) {
+        fill_empty_ifus = 0 ;
+        cpl_msg_warning(__func__, 
+                "Filling empty IFUs is only possible in method 0 - disable it");
     }
 
     /* Check the inputs consistency */
@@ -276,31 +306,31 @@ static int kmos_gen_telluric(cpl_parameterlist *parlist, cpl_frameset *frameset)
         if (tell_frame != NULL) {
             cpl_msg_info(__func__, "Use %s for Data and Zpoint", 
                     cpl_frame_get_filename(tell_frame)) ;
-            kmos_gen_telluric_create_file_simple(tell_frame, NULL, fn,
-                    frameset, parlist) ;
+            kmos_gen_telluric_create_file_simple(tell_frame, NULL, resp_frame, 
+                    fn, frameset, b_samples, fill_empty_ifus, parlist) ;
         } else {
             cpl_msg_info(__func__, "Use %s for Data and Zpoint", 
                     cpl_frame_get_filename(resp_frame)) ;
-            kmos_gen_telluric_create_file_simple(resp_frame, NULL, fn,
-                    frameset, parlist) ;
+            kmos_gen_telluric_create_file_simple(resp_frame, NULL, NULL, 
+                    fn, frameset, b_samples, 0, parlist) ;
         }
     } else if (method == 1) {
         cpl_msg_info(__func__, "Use %s for Data and Zpoint", 
                 cpl_frame_get_filename(tell_corr_frame)) ;
-            kmos_gen_telluric_create_file_simple(tell_corr_frame, NULL, fn,
-                    frameset, parlist) ;
+            kmos_gen_telluric_create_file_simple(tell_corr_frame, NULL, NULL, 
+                    fn, frameset, b_samples, 0, parlist) ;
     } else if (method == 2) {
         if (tell_frame != NULL) {
             cpl_msg_info(__func__, "Use %s for Data and %s for Zpoint",
                     cpl_frame_get_filename(resp_frame),
                     cpl_frame_get_filename(tell_frame)) ;
-            kmos_gen_telluric_create_file_simple(resp_frame, tell_frame, fn,
-                    frameset, parlist) ;
+            kmos_gen_telluric_create_file_simple(resp_frame, tell_frame, NULL, 
+                    fn, frameset, b_samples, 0, parlist) ;
         } else {
             cpl_msg_info(__func__, "Use %s for Data and Zpoint", 
                     cpl_frame_get_filename(resp_frame)) ;
-            kmos_gen_telluric_create_file_simple(resp_frame, NULL, fn,
-                    frameset, parlist) ;
+            kmos_gen_telluric_create_file_simple(resp_frame, NULL, NULL, 
+                    fn, frameset, b_samples, 0, parlist) ;
         }
     } else if (method == 3) {
         cpl_msg_info(__func__, "Use %s X %s for Data and %s for Zpoint", 
@@ -308,7 +338,7 @@ static int kmos_gen_telluric(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 cpl_frame_get_filename(tell_corr_frame),
                 cpl_frame_get_filename(tell_corr_frame)) ;
         kmos_gen_telluric_create_file_multiply(resp_frame, tell_corr_frame, 
-                tell_corr_frame, fn, frameset, parlist) ;
+                tell_corr_frame, fn, frameset, b_samples, parlist) ;
     } else {
         cpl_msg_error(__func__, "Unsupported - Should never come here") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
@@ -325,6 +355,7 @@ static int kmos_gen_telluric_create_file_multiply(
         const cpl_frame         *   zp_frame,
         const char              *   filename,
         cpl_frameset            *   allframes,
+		int							b_samples,
         const cpl_parameterlist *   parlist)
 {
     cpl_propertylist        *   mh ;
@@ -333,7 +364,8 @@ static int kmos_gen_telluric_create_file_multiply(
     cpl_propertylist        *   zph ;
     cpl_vector              *   vec1 ;
     cpl_vector              *   vec2 ;
-    double                      zpoint ;
+    cpl_vector              *   vec_resampled ;
+    double                      zpoint, crval1, cdelt1, new_crval1, new_cdelt1 ;
     enum kmo_frame_type         ft ;
     char                        content[256] ;
     const char              *   extname ;
@@ -344,20 +376,25 @@ static int kmos_gen_telluric_create_file_multiply(
     id = -1 ;
     ft = illegal_frame ; 
 
-    /* Load main header */
-    mh=kmclipm_propertylist_load(cpl_frame_get_filename(data1_frame), 0);
-
     /* Get Extensions number */
     ext_nb = cpl_fits_count_extensions(cpl_frame_get_filename(data1_frame)) ;
 
+    if (cpl_fits_count_extensions(cpl_frame_get_filename(data2_frame))!=ext_nb){
+        cpl_msg_error(__func__, "Extensions numbers do not match - abort") ;
+        return -1 ;
+    }
+
+    /* Load main header */
+    mh = cpl_propertylist_load(cpl_frame_get_filename(data1_frame), 0);
+
     /* Create applist with PRO CATG  */
     applist = cpl_propertylist_new() ;
-    cpl_propertylist_update_string(applist, CPL_DFS_PRO_CATG, "TELLURIC") ;
+    cpl_propertylist_update_string(applist, CPL_DFS_PRO_CATG, TELLURIC_GEN) ;
 
     /* Create PRO_STD keywords */
     for (i = 0; i < ext_nb ; i++) {
         /* Load extension header */
-        eh = kmclipm_propertylist_load(cpl_frame_get_filename(data2_frame),i+1);
+        eh = cpl_propertylist_load(cpl_frame_get_filename(data2_frame),i+1);
         /* Read EXTNAME */
         extname = cpl_propertylist_get_string(eh, "EXTNAME") ;
         kmo_extname_extractor(extname, &ft, &ifu_nr, content) ;
@@ -367,7 +404,7 @@ static int kmos_gen_telluric_create_file_multiply(
         if (vec1 != NULL) {
             cpl_vector_delete(vec1) ;
 
-            /* The Telluric is presenet in this IFU - write the keyword */
+            /* The Telluric is present in this IFU - write the keyword */
             keyword = cpl_sprintf("%s%d", PRO_STD, ifu_nr);
             cpl_propertylist_update_int(applist, keyword, 1);
             cpl_free(keyword);
@@ -388,7 +425,7 @@ static int kmos_gen_telluric_create_file_multiply(
     for (i = 0; i < ext_nb ; i++) {
 
         /* Load extension header */
-        eh = kmclipm_propertylist_load(cpl_frame_get_filename(data1_frame),i+1);
+        eh = cpl_propertylist_load(cpl_frame_get_filename(data1_frame),i+1);
 
         /* Read EXTNAME */
         extname = cpl_propertylist_get_string(eh, "EXTNAME") ;
@@ -399,9 +436,47 @@ static int kmos_gen_telluric_create_file_multiply(
         vec2 = cpl_vector_load(cpl_frame_get_filename(data2_frame), i+1) ;
         if (vec1 == NULL || vec2 == NULL) cpl_error_reset() ;
 
+        /* Resample vec1 if needed */
+        if (vec1 != NULL &&
+                cpl_vector_get_size(vec1) != b_samples && b_samples > 0) {
+
+            /* Get crval1, cdelt1 */
+            cdelt1 = kmos_pfits_get_cdelt1(eh) ;
+            crval1 = kmos_pfits_get_crval1(eh) ;
+
+            /* Recreate vec */
+            vec_resampled = kmos_gen_telluric_resample(vec1, b_samples, crval1,
+                    cdelt1, &new_crval1, &new_cdelt1) ;
+            if (vec_resampled != NULL) {
+                cpl_vector_delete(vec1) ;
+                vec1 = vec_resampled ;
+
+                /* Update CRVAL1 / CDELT1 in eh */
+                cpl_propertylist_update_double(eh, "CRVAL1", new_crval1) ;
+                cpl_propertylist_update_double(eh, "CDELT1", new_cdelt1) ;
+            }
+        }
+
+		/* Resample vec2 if needed */
+        if (vec1 != NULL && vec2 != NULL && 
+                cpl_vector_get_size(vec1) != cpl_vector_get_size(vec2)) {
+
+            /* Get crval1, cdelt1 */
+            cdelt1 = kmos_pfits_get_cdelt1(eh) ;
+            crval1 = kmos_pfits_get_crval1(eh) ;
+
+            /* Recreate vec */
+            vec_resampled = kmos_gen_telluric_resample(vec2, b_samples, crval1,
+                    cdelt1, &new_crval1, &new_cdelt1) ;
+            if (vec_resampled != NULL) {
+                cpl_vector_delete(vec2) ;
+                vec2 = vec_resampled ;
+            }
+        }
+
         /* Need to update ZPOINT ? */
         if (vec1 != NULL && vec2 != NULL && zp_frame != NULL) {
-            zph=kmclipm_propertylist_load(cpl_frame_get_filename(zp_frame),i+1);
+            zph=cpl_propertylist_load(cpl_frame_get_filename(zp_frame),i+1);
             zpoint = cpl_propertylist_get_double(zph, "ESO QC ZPOINT");
             cpl_propertylist_delete(zph); 
             if (cpl_error_get_code() != CPL_ERROR_NONE) {
@@ -435,17 +510,30 @@ static int kmos_gen_telluric_create_file_multiply(
 static int kmos_gen_telluric_create_file_simple(
         const cpl_frame         *   data_frame,
         const cpl_frame         *   zp_frame,
+        const cpl_frame         *   resp_frame,
         const char              *   filename,
         cpl_frameset            *   allframes,
+        int                         b_samples,
+        int                         fill_empty_ifus,
         const cpl_parameterlist *   parlist)
 {
     cpl_propertylist        *   mh ;
     cpl_propertylist        *   applist ;
     cpl_propertylist        *   eh ;
+    cpl_propertylist        *   tmp_eh ;
     cpl_propertylist        *   zph ;
     cpl_vector              *   vec ;
-    double                      zpoint, zp1_avg, zp2_avg, zp3_avg ;
-    int                         i, ext_nb, id, det_nr, ifu_nr ;
+    cpl_vector              *   vec_ref ;
+    cpl_vector              *   resp_ref ;
+    cpl_vector              *   resp_cur ;
+    cpl_vector              *   vec_resampled ;
+    double                      zpoint, zpoint_vec_ref, zpoint_resp_ref,
+                                zpoint_resp_cur, zp1_avg, zp2_avg, zp3_avg,
+                                cdelt1, crval1, new_crval1, new_cdelt1;
+    int                         i, ext_nb, id, det_nr, ifu_nr, first_data_det1,
+                                first_data_det2, first_data_det3, 
+                                first_noise_det1, first_noise_det2, 
+                                first_noise_det3, ref_ifu ;
     enum kmo_frame_type         ft ;
     char                        content[256] ;
     char                	*   keyword ;
@@ -455,31 +543,61 @@ static int kmos_gen_telluric_create_file_simple(
     zp1_avg = zp2_avg = zp3_avg = -1.0 ;
     id = -1 ;
     ft = illegal_frame ; 
+    first_data_det1 = first_data_det2 = first_data_det3 = -1 ;
+    first_noise_det1 = first_noise_det2 = first_noise_det3 = -1 ;
 
     /* Get Extensions number */
     ext_nb = cpl_fits_count_extensions(cpl_frame_get_filename(data_frame)) ;
 
     /* Load main header */
-    mh=kmclipm_propertylist_load(cpl_frame_get_filename(data_frame), 0);
+    mh = cpl_propertylist_load(cpl_frame_get_filename(data_frame), 0);
 
     /* Create applist with PRO CATG  */
     applist = cpl_propertylist_new() ;
-    cpl_propertylist_update_string(applist, CPL_DFS_PRO_CATG, "TELLURIC") ;
+    cpl_propertylist_update_string(applist, CPL_DFS_PRO_CATG, TELLURIC_GEN) ;
 
     /* Create PRO_STD keywords */
     for (i = 0; i < ext_nb ; i++) {
         /* Load extension header */
-        eh = kmclipm_propertylist_load(cpl_frame_get_filename(data_frame), i+1);
+        eh = cpl_propertylist_load(cpl_frame_get_filename(data_frame), i+1);
         /* Read EXTNAME */
         extname = cpl_propertylist_get_string(eh, "EXTNAME") ;
+
         kmo_extname_extractor(extname, &ft, &ifu_nr, content) ;
         cpl_propertylist_delete(eh); 
-        /* Load the data */
-        vec = cpl_vector_load(cpl_frame_get_filename(data_frame), i+1) ;
-        if (vec != NULL) {
-            cpl_vector_delete(vec) ;
 
-            /* The Telluric is presenet in this IFU - write the keyword */
+        /* Get Detector */
+        if (ifu_nr >= 1 && ifu_nr <= 8)         det_nr = 1 ;
+        else if (ifu_nr >= 9 && ifu_nr <= 16)   det_nr = 2 ;
+        else if (ifu_nr >= 17 && ifu_nr <= 24)  det_nr = 3 ;
+        else {
+            cpl_msg_error(__func__, "Cannot Identify the detector") ;
+            cpl_propertylist_delete(mh);
+            cpl_propertylist_delete(applist);
+            return -1 ;
+        }
+
+        /* Try to load the data */
+        vec = cpl_vector_load(cpl_frame_get_filename(data_frame), i+1) ;
+        if (vec == NULL) cpl_error_reset() ;
+
+        /* Store the first non-null extensions per detector */
+        if (vec != NULL) {
+            if (!strcmp(content, "DATA")) {
+                if (det_nr == 1 && first_data_det1 < 0) first_data_det1 = i+1 ;
+                if (det_nr == 2 && first_data_det2 < 0) first_data_det2 = i+1 ;
+                if (det_nr == 3 && first_data_det3 < 0) first_data_det3 = i+1 ;
+            } else if (!strcmp(content, "NOISE")) {
+                if (det_nr == 1 && first_noise_det1 < 0) first_noise_det1 = i+1;
+                if (det_nr == 2 && first_noise_det2 < 0) first_noise_det2 = i+1;
+                if (det_nr == 3 && first_noise_det3 < 0) first_noise_det3 = i+1;
+            }
+        }
+
+        if (vec != NULL || fill_empty_ifus == 1) {
+            if (vec != NULL) cpl_vector_delete(vec) ;
+
+            /* The Telluric is present in this IFU - write the keyword */
             keyword = cpl_sprintf("%s%d", PRO_STD, ifu_nr);
             cpl_propertylist_update_int(applist, keyword, 1);
             cpl_free(keyword);
@@ -505,7 +623,7 @@ static int kmos_gen_telluric_create_file_simple(
     for (i = 0; i < ext_nb ; i++) {
 
         /* Load extension header */
-        eh = kmclipm_propertylist_load(cpl_frame_get_filename(data_frame), i+1);
+        eh = cpl_propertylist_load(cpl_frame_get_filename(data_frame), i+1);
 
         /* Read EXTNAME */
         extname = cpl_propertylist_get_string(eh, "EXTNAME") ;
@@ -524,9 +642,127 @@ static int kmos_gen_telluric_create_file_simple(
         vec = cpl_vector_load(cpl_frame_get_filename(data_frame), i+1) ;
         if (vec == NULL) cpl_error_reset() ;
 
+        /* Recover vec if requested */
+        if (vec == NULL && fill_empty_ifus == 1) {
+
+            /* Initialise */
+            vec_ref = NULL ;
+            ref_ifu = -1 ;
+            if (!strcmp(content, "NOISE")) {
+                /* Get ref_ifu */
+                if (det_nr==1)  ref_ifu = first_noise_det1 ;
+                if (det_nr==2)  ref_ifu = first_noise_det2 ;
+                if (det_nr==3)  ref_ifu = first_noise_det3 ;
+ 
+                /* Load noise reference */
+                vec_ref=cpl_vector_load(cpl_frame_get_filename(data_frame),
+                        ref_ifu);
+
+            } else if (!strcmp(content, "DATA")) {
+
+                /* Get ref_ifu */
+                if (det_nr==1)  ref_ifu = first_data_det1 ;
+                if (det_nr==2)  ref_ifu = first_data_det2 ;
+                if (det_nr==3)  ref_ifu = first_data_det3 ;
+
+                /* Load data reference */
+                vec_ref=cpl_vector_load(cpl_frame_get_filename(data_frame),
+                        ref_ifu);
+
+                resp_ref = cpl_vector_load(cpl_frame_get_filename(resp_frame), 
+                        ref_ifu) ;
+                resp_cur = cpl_vector_load(cpl_frame_get_filename(resp_frame), 
+                        i+1) ;
+                if (resp_ref != NULL && resp_cur != NULL) {
+                    /* Resample resp_ref if needed */
+                    if (cpl_vector_get_size(vec_ref) !=
+                            cpl_vector_get_size(resp_ref)) {
+
+                        /* Get crval1, cdelt1 from the resp_ref_ifu */
+                        tmp_eh = cpl_propertylist_load(
+                                cpl_frame_get_filename(resp_frame), ref_ifu);
+                        cdelt1 = kmos_pfits_get_cdelt1(tmp_eh) ;
+                        crval1 = kmos_pfits_get_crval1(tmp_eh) ;
+                        cpl_propertylist_delete(tmp_eh) ;
+
+                        /* Resample */
+                        vec_resampled = kmos_gen_telluric_resample(resp_ref, 
+                                cpl_vector_get_size(vec_ref), crval1, cdelt1, 
+                                &new_crval1, &new_cdelt1) ;
+                        if (vec_resampled != NULL) {
+                            cpl_vector_delete(resp_ref) ;
+                            resp_ref = vec_resampled ;
+                        }
+                    }
+
+                    /* Resample resp_cur if needed */
+                    if (cpl_vector_get_size(vec_ref) !=
+                            cpl_vector_get_size(resp_cur)) {
+
+                        /* Get crval1, cdelt1 from the resp_cur_ifu */
+                        tmp_eh = cpl_propertylist_load(
+                                cpl_frame_get_filename(resp_frame), i+1);
+                        cdelt1 = kmos_pfits_get_cdelt1(tmp_eh) ;
+                        crval1 = kmos_pfits_get_crval1(tmp_eh) ;
+                        cpl_propertylist_delete(tmp_eh) ;
+
+                        /* Resample */
+                        vec_resampled = kmos_gen_telluric_resample(resp_cur, 
+                                cpl_vector_get_size(vec_ref), crval1, cdelt1, 
+                                &new_crval1, &new_cdelt1) ;
+                        if (vec_resampled != NULL) {
+                            cpl_vector_delete(resp_ref) ;
+                            resp_ref = vec_resampled ;
+                        }
+                    }
+                    cpl_vector_divide(vec_ref, resp_ref);
+                    cpl_vector_multiply(vec_ref, resp_cur);
+                }
+                if (resp_ref != NULL) cpl_vector_delete(resp_ref) ;
+                if (resp_cur != NULL) cpl_vector_delete(resp_cur) ;
+            }
+            vec = vec_ref ;
+
+            /* Get crval1, cdelt1 from the ref_ifu */
+            tmp_eh = cpl_propertylist_load(
+                    cpl_frame_get_filename(data_frame), ref_ifu);
+
+            cpl_propertylist_copy_property(eh, tmp_eh, "CTYPE1") ;
+            cpl_propertylist_copy_property(eh, tmp_eh, "CRPIX1") ;
+            cpl_propertylist_copy_property(eh, tmp_eh, "CRVAL1") ;
+            cpl_propertylist_copy_property(eh, tmp_eh, "CDELT1") ;
+            cpl_propertylist_delete(tmp_eh) ;
+            cpl_propertylist_erase(eh, "CRPIX2") ;
+            cpl_propertylist_erase(eh, "CTYPE2") ;
+            cpl_propertylist_erase(eh, "CD1_1") ;
+            cpl_propertylist_erase(eh, "CD1_2") ;
+            cpl_propertylist_erase(eh, "CD2_1") ;
+            cpl_propertylist_erase(eh, "CD2_2") ;
+
+            /* Compute ZPOINT */
+            tmp_eh = cpl_propertylist_load(
+                    cpl_frame_get_filename(data_frame), ref_ifu);
+            zpoint_vec_ref = cpl_propertylist_get_double(tmp_eh,
+                    "ESO QC ZPOINT");
+            cpl_propertylist_delete(tmp_eh) ;
+            tmp_eh = cpl_propertylist_load(
+                    cpl_frame_get_filename(resp_frame), ref_ifu);
+            zpoint_resp_ref = cpl_propertylist_get_double(tmp_eh,
+                    "ESO QC ZPOINT");
+            cpl_propertylist_delete(tmp_eh) ;
+            tmp_eh = cpl_propertylist_load(
+                    cpl_frame_get_filename(resp_frame), i+1);
+            zpoint_resp_cur = cpl_propertylist_get_double(tmp_eh,
+                    "ESO QC ZPOINT");
+            cpl_propertylist_delete(tmp_eh) ;
+            /* Compute new ZPOINT */
+            zpoint = zpoint_vec_ref - zpoint_resp_ref + zpoint_resp_cur ;
+            cpl_propertylist_update_double(eh, "ESO QC ZPOINT", zpoint) ;
+        }
+
         /* Need to update ZPOINT ? */
         if (vec != NULL && zp_frame != NULL) {
-            zph=kmclipm_propertylist_load(cpl_frame_get_filename(zp_frame),i+1);
+            zph = cpl_propertylist_load(cpl_frame_get_filename(zp_frame),i+1);
             zpoint = cpl_propertylist_get_double(zph, "ESO QC ZPOINT");
             cpl_propertylist_delete(zph); 
             if (cpl_error_get_code() != CPL_ERROR_NONE) {
@@ -541,6 +777,27 @@ static int kmos_gen_telluric_create_file_simple(
             cpl_propertylist_update_double(eh, "ESO QC ZPOINT", zpoint) ;
         }
 
+        /* Resample vec if needed */
+        if (vec != NULL && 
+                cpl_vector_get_size(vec) != b_samples && b_samples > 0) {
+
+            /* Get crval1, cdelt1 */
+            cdelt1 = kmos_pfits_get_cdelt1(eh) ;
+            crval1 = kmos_pfits_get_crval1(eh) ;
+
+            /* Recreate vec */
+            vec_resampled = kmos_gen_telluric_resample(vec, b_samples, crval1,
+                    cdelt1, &new_crval1, &new_cdelt1) ;
+            if (vec_resampled != NULL) {
+                cpl_vector_delete(vec) ;
+                vec = vec_resampled ;
+
+                /* Update CRVAL1 / CDELT1 in eh */
+                cpl_propertylist_update_double(eh, "CRVAL1", new_crval1) ;
+                cpl_propertylist_update_double(eh, "CDELT1", new_cdelt1) ;
+            }
+        }
+
         /* Save the Extension */
         if (vec != NULL) {
             /* Save the data */
@@ -554,6 +811,101 @@ static int kmos_gen_telluric_create_file_simple(
     }
     return 0 ;
 }
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Resample 1d vector
+  @param    vec         Vector to resample
+  @param    b_samples   Number of samples wished
+  @param    crval1      
+  @param    cdelt1
+  @param    new_crval1  [out]
+  @param    new_cdelt1  [out]
+  @return   resampled vector or NULL in error case
+ */
+/*----------------------------------------------------------------------------*/
+static cpl_vector * kmos_gen_telluric_resample(
+        cpl_vector          *   vec,
+        int                     b_samples,
+        double                  crval1,
+        double                  cdelt1,
+        double              *   new_crval1,
+        double              *   new_cdelt1)
+{
+    cpl_bivector        *   fold ;
+    cpl_bivector        *   fnew ;
+    cpl_vector          *   old_x ;
+    cpl_vector          *   new_x ;
+    cpl_vector          *   new_y ;
+	int                     vec_size ;
+    cpl_error_code          err;
+    double                  current_lambda ;
+    int                     i, j ;
+
+    /* Check entries */
+    if (vec == NULL || new_crval1 == NULL || new_cdelt1 == NULL) return NULL;
+
+    /* Initialise */
+    vec_size = cpl_vector_get_size(vec) ;
+
+    /* No resample needed */
+    if (b_samples == vec_size) {
+        *new_crval1 = crval1 ;
+        *new_cdelt1 = cdelt1 ;
+        return cpl_vector_duplicate(vec) ;
+    }
+
+    /* Prepare data */
+    *new_crval1 = crval1 ;
+    *new_cdelt1 = cdelt1 * vec_size / b_samples ;
+
+    /* Fill the old lambda */
+    old_x = cpl_vector_new(vec_size) ;
+    for (i=0 ; i<vec_size ; i++) {
+        cpl_vector_set(old_x, i, crval1 + i*cdelt1) ;
+    }
+
+    /* Fill the new lambda */
+    new_x = cpl_vector_new(b_samples) ;
+    new_y = cpl_vector_new(b_samples) ;
+    for (i=0 ; i<b_samples ; i++) {
+        cpl_vector_set(new_x, i, *new_crval1 + i*(*new_cdelt1)) ;
+    }
+
+    if (b_samples < vec_size) {
+        /* Undersampling */
+        fold = cpl_bivector_wrap_vectors(old_x, (cpl_vector *)vec) ;
+        fnew = cpl_bivector_wrap_vectors(new_x, new_y) ;
+
+        /* Resample */
+        err = cpl_bivector_interpolate_linear(fnew, fold) ;
+
+        /* Unwrap */
+        cpl_bivector_unwrap_vectors(fold) ;
+        cpl_bivector_unwrap_vectors(fnew) ;
+
+        if (err != CPL_ERROR_NONE) {
+            cpl_msg_error(__func__, "Cannot Resample") ;
+            cpl_vector_delete(old_x) ;
+            cpl_vector_delete(new_x) ;
+            cpl_vector_delete(new_y) ;
+            return NULL ;
+        }
+    } else {
+        /* Oversampling */
+        for (i=0 ; i<b_samples ; i++) {
+            /* Current wavelength */
+            current_lambda = cpl_vector_get(new_x, i) ;
+            /* Find j : index of this wl in the old vector */
+            for (j=0 ; j<vec_size-1 ; j++) {
+                if (cpl_vector_get(old_x, j) > current_lambda) break ;
+            }
+            cpl_vector_set(new_y, i, cpl_vector_get(vec, j)) ;
+        }
+    }
+    cpl_vector_delete(old_x) ;
+    cpl_vector_delete(new_x) ;
+    return new_y ;
+}
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -595,7 +947,7 @@ static int kmos_gen_telluric_get_avg_zpoint(
     /* Loop on the extensions */
     for (i = 0; i < ext_nb ; i++) {
         /* Load extension header */
-        eh = kmclipm_propertylist_load(cpl_frame_get_filename(zp_frame), i+1);
+        eh = cpl_propertylist_load(cpl_frame_get_filename(zp_frame), i+1);
 
         /* Read EXTNAME */
         extname = cpl_propertylist_get_string(eh, "EXTNAME") ;
