@@ -292,7 +292,6 @@ static int kmos_illumination_create(cpl_plugin *plugin)
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
-
     return 0 ;
 }
 
@@ -363,7 +362,7 @@ static int kmos_illumination(
                             suppress_extension, reduce_det, 
                             has_flat_edge ;
     double                  neighborhoodRange, pix_scale, cpos_rej, cneg_rej, 
-                            rotangle, reduce_angle ;
+                            reduce_angle ;
     int                     nb_raw_sky, nb_raw_lamp ;
     const char          *   do_catg_used ;
     int                 *   angles_array ;
@@ -374,11 +373,9 @@ static int kmos_illumination(
     cpl_frame           *   frame ;
     cpl_propertylist    *   main_header ;
 
-    /* Check entries */
-    if (parlist == NULL || frameset == NULL) {
-        cpl_msg_error(__func__, "Null Inputs") ;
-        cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
-        return -1 ;
+    /* Check initial Entries */
+    if (kmos_check_and_set_groups(frameset) != CPL_ERROR_NONE) {
+        return cpl_error_get_code();
     }
     
     /* Get parameters */
@@ -446,13 +443,6 @@ static int kmos_illumination(
  
     has_flat_edge = cpl_frameset_count_tags(frameset, FLAT_EDGE);
 
-    /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset) != 1) {
-        cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
-        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
-        return -1 ;
-    }
-   
     /* Determine the used rawfiles */
     nb_raw_sky = cpl_frameset_count_tags(frameset, FLAT_SKY);
     nb_raw_lamp = cpl_frameset_count_tags(frameset, FLAT_ON);
@@ -514,8 +504,6 @@ static int kmos_illumination(
                 a, angles_array[a]);
         cpl_msg_indent_more() ;
 
-        if (cpl_error_get_code()) 
-            printf("angle nb %d - %s\n", a, cpl_error_get_where()) ;
         /* Get the frameset with this angle */
         angle_frameset = kmos_purge_wrong_angles_frameset(frameset, 
                 angles_array[a], do_catg_used);
@@ -591,7 +579,6 @@ static int kmos_illumination_one_angle(
     cpl_propertylist    *   main_header ;
     char                *   filter ;
     char                *   keyword ;
-    const char          *   ranges_txt_loc ;
     gridDefinition          gd;
     char                *   fn_lut ;
     cpl_propertylist    *   tmp_header ;
@@ -603,7 +590,7 @@ static int kmos_illumination_one_angle(
     cpl_image           **  stored_noise_images ;
     cpl_propertylist    **  stored_sub_data_headers ;
     cpl_propertylist    **  stored_sub_noise_headers ;
-    cpl_table           *** edge_table_sky ;
+    cpl_table           *** edge_table_sky = NULL;
     cpl_vector          *   calAngles ;
     cpl_imagelist       *   detector_in ;
     cpl_image           *   img_in ;
@@ -621,10 +608,10 @@ static int kmos_illumination_one_angle(
     cpl_table           *   band_table ;
     cpl_propertylist    *   sub_header ;
     char                *   extname ;
-    cpl_vector          *   identified_slices ;
+    cpl_vector          *   identified_slices = NULL;
     cpl_image           *   tmp_img ;
     float               *   pdata ;
-    float               *   pnoise ;
+    float               *   pnoise = NULL;
     cpl_vector          *   ranges ;
     cpl_imagelist       *   cube_data ;
     cpl_imagelist       *   cube_noise ;
@@ -700,8 +687,6 @@ static int kmos_illumination_one_angle(
             return -1 ;
         }
         cpl_free(filter) ;
-    } else {
-        ranges_txt_loc = ranges_txt ;
     }
     cpl_msg_info(__func__, "Spectral range to collapse: %s um", ranges_txt);
 
@@ -803,7 +788,7 @@ static int kmos_illumination_one_angle(
             cpl_free(stored_noise_images);
             cpl_free(stored_sub_data_headers);
             cpl_free(stored_sub_noise_headers); 
-            if (has_flat_edge) cpl_free(edge_table_sky) ;
+            if (edge_table_sky) cpl_free(edge_table_sky) ;
             cpl_vector_delete(calAngles) ;
             cpl_msg_error(__func__, "Combination failed") ;
             cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
@@ -1054,18 +1039,25 @@ static int kmos_illumination_one_angle(
                 /* Apply median smoothing - Taking care of edges  */
                 /* (IFUs 1-16 top/bottom, IFUs 17-24 left/right) */
                 if (!strcmp(do_catg_used, FLAT_ON)) {
+                    nx = cpl_image_get_size_x(stored_data_images[ifu_nr-1]) ;
+                    ny = cpl_image_get_size_x(stored_data_images[ifu_nr-1]) ;
                     int  firstx = 0, lastx = 0, firsty = 0, lasty = 0 ;
-                    if (ifu_nr <= 2*KMOS_IFUS_PER_DETECTOR) 
-                        { firstx = 0; lastx = 13; firsty = 1; lasty = 12; }
-                    else 
-                        { firstx = 1; lastx= 12; firsty = 0; lasty = 13; }
+                    if (ifu_nr <= 2*KMOS_IFUS_PER_DETECTOR) { 
+                        firstx = 0; 
+                        lastx = nx-1; 
+                        firsty = 1; 
+                        lasty = ny-2; 
+                    } else { 
+                        firstx = 1; 
+                        lastx= nx-2; 
+                        firsty = 0; 
+                        lasty = ny-1; 
+                    }
 
                     tmp_img = cpl_image_duplicate(stored_data_images[ifu_nr-1]);
                     pdata = cpl_image_get_data_float(tmp_img);
                     pnoise =
                         cpl_image_get_data_float(stored_noise_images[ifu_nr-1]);
-                    nx = cpl_image_get_size_x(tmp_img);
-                    ny = cpl_image_get_size_y(tmp_img);
 
                     /* Median filtering */
                     int mhalf = 3 ;
@@ -1079,7 +1071,6 @@ static int kmos_illumination_one_angle(
                             else                    ymin = firsty; 
                             if (iy+mhalf < lasty)   ymax = iy+mhalf; 
                             else                    ymax = lasty; 
-
                             pdata[ix+nx*iy] = cpl_image_get_median_window(
                                     stored_data_images[ifu_nr-1],xmin+1,ymin+1, 
                                     xmax+1, ymax+1);
@@ -1093,12 +1084,13 @@ static int kmos_illumination_one_angle(
                     cpl_image_delete(stored_data_images[ifu_nr-1]);
                     stored_data_images[ifu_nr-1] = tmp_img;
                 }
-                cpl_vector_delete(identified_slices);
+                if(identified_slices) cpl_vector_delete(identified_slices);
             } else {
                 /* IFU is invalid */
             }
         }
         cpl_msg_indent_less() ;
+
     }
     cpl_vector_delete(ranges);
     for (i = 0; i < next * KMOS_IFUS_PER_DETECTOR; i++) {
@@ -1134,6 +1126,25 @@ static int kmos_illumination_one_angle(
                         "RAW frames are exactly the same as the "
                         "frames used for MASTER_DARK calculation.");
                     cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
+
+                    if (stored_sub_data_headers) {
+                      for (int k = 0; k < next * KMOS_IFUS_PER_DETECTOR; k++) {
+                        if (stored_sub_data_headers[k]) {
+                            cpl_propertylist_delete(stored_sub_data_headers[k]);
+                        }
+                      }
+                      cpl_free(stored_sub_data_headers);
+                    }
+
+                    if (stored_sub_noise_headers) {
+                      for (int k = 0; k < next * KMOS_IFUS_PER_DETECTOR; k++) {
+                        if (stored_sub_noise_headers[k]) {
+                            cpl_propertylist_delete(stored_sub_noise_headers[k]);
+                        }
+                      }
+                      cpl_free(stored_sub_noise_headers);
+                    }
+
                     return -1 ;
                 }
                 mean_data += cpl_image_get_mean(stored_data_images[ifu_nr]);
@@ -1189,8 +1200,10 @@ static int kmos_illumination_one_angle(
                             pdata[ix+nx*iy] = 1. / pdata[ix+nx*iy];
                             if (stored_noise_images[ifu_nr] != NULL) {
                                 new_val = pdata[ix+nx*iy];
-                                pnoise[ix+nx*iy] = sqrt(pow(new_val, 2) *
+                                if (pnoise) {
+                                	pnoise[ix+nx*iy] = sqrt(pow(new_val, 2) *
                                         pow(pnoise[ix+nx*iy],2)/pow(old_val,2));
+                                }
                             }
                         }
                     }
@@ -1305,9 +1318,9 @@ static int kmos_illumination_one_angle(
     }
     cpl_free(stored_sub_data_headers);
     cpl_free(stored_sub_noise_headers); 
-    if (has_flat_edge) {
+    if (edge_table_sky) {
         for (i = 0; i < KMOS_NR_DETECTORS; i++) {
-            if (edge_table_sky[i] != NULL) {
+            if (edge_table_sky[i]) {
                 for (j = 0; j < KMOS_IFUS_PER_DETECTOR; j++) 
                     cpl_table_delete(edge_table_sky[i][j]);
                 cpl_free(edge_table_sky[i]); 
