@@ -186,10 +186,10 @@ static int kmos_molecfit_calctrans(
   if (!(conf->mf.fit_continuum.fit) ) cpl_msg_info(cpl_func, "Not fit continuum!" );
 
   /* Loading data spectrums */
-  if(kmos_molecfit_load_spectrums(frameset, &(conf->mf), RECIPE_NAME) != CPL_ERROR_NONE) {
+  cpl_error_code err = kmos_molecfit_load_spectrums(frameset, &(conf->mf), RECIPE_NAME);
+  if(err != CPL_ERROR_NONE) {
       kmos_molecfit_calctrans_clean(conf);
-      return (int)cpl_error_set_message(cpl_func, CPL_ERROR_FILE_IO,
-                                        "Loading spectrums data in the input frameset failed!");
+      return err;
   }
 
   /* Loading kernels */
@@ -214,8 +214,8 @@ static int kmos_molecfit_calctrans(
 
   /* Saving generic multi-extension output *.fits file */
   cpl_msg_info(cpl_func, "Saving generic multi-extension output fits file ('%s','%s') ...", TELLURIC_DATA, TELLURIC);
-  cpl_error_code sTel_data = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, TELLURIC_DATA, conf->mf.grating.name, NULL);
-  cpl_error_code sTel_img  = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, TELLURIC_CORR, conf->mf.grating.name, NULL);
+  cpl_error_code sTel_data = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, TELLURIC_DATA, conf->mf.grating.name, conf->mf.suppress_extension, NULL);
+  cpl_error_code sTel_img  = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, TELLURIC_CORR, conf->mf.grating.name, conf->mf.suppress_extension, NULL);
   if (sTel_data != CPL_ERROR_NONE || sTel_img != CPL_ERROR_NONE) {
       kmos_molecfit_calctrans_clean(conf);
       return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
@@ -450,7 +450,7 @@ static int kmos_molecfit_calctrans(
 
       /* Save cpl_table with the data of the mf_convolution execution */
       sTel_data = kmos_molecfit_save_mf_results(header_data, header_noise,
-                                                TELLURIC_DATA, conf->mf.grating.name, NULL, telluric_data, NULL);
+                                                TELLURIC_DATA, conf->mf.grating.name, conf->mf.suppress_extension, NULL, telluric_data, NULL);
       if (sTel_data != CPL_ERROR_NONE) {
           if (telluric_vec) cpl_vector_delete(telluric_vec);
           cpl_propertylist_delete(header_data);
@@ -463,7 +463,7 @@ static int kmos_molecfit_calctrans(
 
       /* Save data image with the data obtained in the mf_convolution execution */
       sTel_img = kmos_molecfit_save_mf_results(header_data, header_noise,
-                                               TELLURIC_CORR, conf->mf.grating.name, NULL, NULL, telluric_vec);
+                                               TELLURIC_CORR, conf->mf.grating.name, conf->mf.suppress_extension, NULL, NULL, telluric_vec);
       if (sTel_img != CPL_ERROR_NONE) {
           if (telluric_vec) cpl_vector_delete(telluric_vec);
           cpl_propertylist_delete(header_data);
@@ -676,6 +676,12 @@ static cpl_error_code kmos_molecfit_calctrans_fill_parameterlist(
                                    "IFU number in ATMOS_PARM and BEST_FIT_PARM to be used to compute the telluric correction for IFU 24.", CPL_FALSE);
   if (e != CPL_ERROR_NONE) return (int)e;
 
+  /* --suppress_extension */
+  cpl_boolean suppress_extension = CPL_FALSE;
+  e = kmos_molecfit_fill_parameter(RECIPE_NAME, self, "suppress_extension",
+                                   !range, dummyMin, dummyMax, CPL_TYPE_BOOL, &suppress_extension,
+                                   "Suppress arbitrary filename extension.(TRUE (apply) or FALSE (don't apply).", CPL_FALSE);
+  if (e != CPL_ERROR_NONE) return (int)e;
 
   /* Check possible errors */
   if (!cpl_errorstate_is_equal(prestate)) {
@@ -722,6 +728,9 @@ static kmos_molecfit_calctrans_parameter * kmos_molecfit_calctrans_conf(
   /* Initialize input parameters propertylist */
   conf->mf.parms = cpl_propertylist_new();
 
+  /* User input kernel ? */
+  p = cpl_parameterlist_find_const(list, "use_input_kernel");
+  conf->mf.use_input_kernel = cpl_parameter_get_bool(p);
 
   /* Mapping IFUS in kmos_molecfit_calctrans recipe */
   int ifu = -1;
@@ -798,13 +807,14 @@ static kmos_molecfit_calctrans_parameter * kmos_molecfit_calctrans_conf(
   p = cpl_parameterlist_find_const(list, "IFU_24");
   conf->mf.ifus[++ifu].map = cpl_parameter_get_int(p);
 
-
-  /* User input kernel ? */
-  p = cpl_parameterlist_find_const(list, "use_input_kernel");
-  conf->mf.use_input_kernel = cpl_parameter_get_bool(p);
+  /* suppress_extension */
+  p = cpl_parameterlist_find_const(list, "suppress_extension");
+  conf->mf.suppress_extension = cpl_parameter_get_bool(p);
 
 
   /* Save parameter in the output propertylist */
+  cpl_propertylist_update_bool(conf->mf.parms, KMOS_MF_PARAM_RECIPE"USE_INPUT_KERNEL", conf->mf.use_input_kernel);
+
   ifu = -1;
   cpl_propertylist_update_int( conf->mf.parms, KMOS_MF_PARAM_RECIPE"IFU_1",            conf->mf.ifus[++ifu].map );
   cpl_propertylist_update_int( conf->mf.parms, KMOS_MF_PARAM_RECIPE"IFU_2",            conf->mf.ifus[++ifu].map );
@@ -831,7 +841,7 @@ static kmos_molecfit_calctrans_parameter * kmos_molecfit_calctrans_conf(
   cpl_propertylist_update_int( conf->mf.parms, KMOS_MF_PARAM_RECIPE"IFU_23",           conf->mf.ifus[++ifu].map );
   cpl_propertylist_update_int( conf->mf.parms, KMOS_MF_PARAM_RECIPE"IFU_24",           conf->mf.ifus[++ifu].map );
 
-  cpl_propertylist_update_bool(conf->mf.parms, KMOS_MF_PARAM_RECIPE"USE_INPUT_KERNEL", conf->mf.use_input_kernel);
+  cpl_propertylist_update_bool(conf->mf.parms, KMOS_MF_PARAM_RECIPE"SUPPRESS_EXTENSION", conf->mf.use_input_kernel);
 
 
   /* Check status */
@@ -919,8 +929,9 @@ static cpl_error_code kmos_molecfit_calctrans_frames_conf(
   /*** Check and assign mapping of IFUS ***/
   cpl_msg_info(cpl_func, "Mapping IFU's ... (Using BEST_FIT_PARM data in automatic assignment)");
   for (cpl_size n_ifu = 0; n_ifu < N_IFUS; n_ifu++) {
-      kmos_spectrum *ifu = &(conf->mf.ifus[n_ifu]);
-      cpl_size ifu_num = n_ifu + 1;
+
+      kmos_spectrum *ifu    = &(conf->mf.ifus[n_ifu]);
+      cpl_size      ifu_num = n_ifu + 1;
 
       /* Check if it's necessary to re-mapping automatically */
       if (ifu->map != -1) {
@@ -932,30 +943,46 @@ static cpl_error_code kmos_molecfit_calctrans_frames_conf(
           }
 
           cpl_msg_info(cpl_func, "IFU_X.%02lld mapping to IFU_Y.%02d --> "
-                       "Defined by the user", ifu_num, ifu->map);
+                       "Defined by the user with the input parameter (IFU_%02lld=%02d)",
+                       ifu_num, ifu->map, ifu_num, ifu->map);
       } else {
 
-          /* First rule: ifuX_(1-8)-->ifu_Y(1-8), ifuX_(9-16)-->ifu_Y(9-16), ifuX_(17-24)-->ifu_Y(17-24) */
-          cpl_size indx = (n_ifu / 8) * 8;
-          for (cpl_size ifu_Y = indx; ifu_Y < indx + 8 && ifu->map == -1; ifu_Y++) {
-
-              /* If exist data --> Map */
-              if (conf->res_table[ifu_Y]) {
-                  ifu->map = ifu_Y + 1;
-                  cpl_msg_info(cpl_func, "IFU_X.%02lld mapping to IFU_Y.%02d --> "
-                               "Defined automatically (Inside the normal range)", ifu_num, ifu->map);
-              }
+          /* First rule: ifuX_i (science) have ifuY_i (calibration) */
+          if (conf->res_table[n_ifu]) {
+              ifu->map = ifu_num;
+              cpl_msg_info(cpl_func, "IFU_X.%02lld mapping to IFU_Y.%02d --> "
+                           "Defined automatically (Same  IFU_Y [with calibration data] for                  IFU_X [science data] - 1st rule)",
+                           ifu_num, ifu->map);
           }
 
-          /* Second rule: If not found it in the normal range, looking for in all the range */
+          /* Second rule: ifuX_(1-8)-->ifu_Y(1-8), ifuX_(9-16)-->ifu_Y(9-16), ifuX_(17-24)-->ifu_Y(17-24) */
           if (ifu->map == -1) {
-              for (cpl_size ifu_Y = 0; ifu_Y < N_IFUS && ifu->map == -1; ifu_Y++) {
+              cpl_size ifuY_detector      = (n_ifu / 8) + 1;           /* Get detector of Science (IFU_X) */
+              cpl_size ifuY_detector_init = (ifuY_detector - 1) * 8;   /* Starting IFU_Y (calibration) in the detector of IFU_X number (science) [valid = 0, 8, 16] */
+              for (cpl_size ifu_Y = ifuY_detector_init; ifu_Y < ifuY_detector_init + 8 && ifu->map == -1; ifu_Y++) {
 
                   /* If exist data --> Map */
                   if (conf->res_table[ifu_Y]) {
                       ifu->map = ifu_Y + 1;
                       cpl_msg_info(cpl_func, "IFU_X.%02lld mapping to IFU_Y.%02d --> "
-                                   "Defined automatically (Outside the normal range)", ifu_num, ifu->map);
+                                   "Defined automatically (First IFU_Y [with calibration data] inside detector:%lld of IFU_X [science data] - 2nd rule)",
+                                   ifu_num, ifu->map, ifuY_detector);
+                  }
+              }
+          }
+
+          /* Third rule: If not found it in the normal range, looking for in all the range */
+          if (ifu->map == -1) {
+              cpl_size ifuX_detector = (n_ifu / 8) + 1;                /* Get detector of Science (IFU_X) */
+              for (cpl_size ifu_Y = 0; ifu_Y < N_IFUS && ifu->map == -1; ifu_Y++) {
+
+                  /* If exist data --> Map */
+                  if (conf->res_table[ifu_Y]) {
+                      cpl_size ifuY_detector = (ifu_Y / 8) + 1;        /* Get detector of calibration (IFU_Y) */
+                      ifu->map = ifu_Y + 1;
+                      cpl_msg_info(cpl_func, "IFU_X.%02lld mapping to IFU_Y.%02d --> "
+                                   "Defined automatically (First IFU_Y [with calibration date] in the instrument (detector=%lld) outside the IFU_X detector=%lld [science data] - 3rd rule)", ifu_num, ifu->map,
+                                   ifuY_detector, ifuX_detector);
                   }
               }
           }
@@ -991,7 +1018,7 @@ static cpl_error_code kmos_molecfit_calctrans_frames_conf(
   cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"WAVE_RANGE", conf->mf.grating.wave_range      );
   cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"LIST_MOLEC", conf->mf.grating.list_molec      );
   cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_MOLEC",  conf->mf.grating.fit_molec       );
-  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RECOL",     conf->mf.grating.relcol          );
+  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RECOL",      conf->mf.grating.relcol          );
 
   cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"KERNMODE",   conf->mf.kernmode                );
   cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"KERNFAC",    conf->mf.kernfac                 );
