@@ -30,6 +30,7 @@
 #include "kmclipm_vector.h"
 #include "kmo_priv_arithmetic.h"
 #include "kmos_molecfit.h"
+#include "kmo_dfs.h"
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -57,11 +58,11 @@ typedef struct {
 } kmos_molecfit_correct_data;
 
 typedef struct {
-  kmos_molecfit_correct_data ifus[N_IFUS]; /* Input data                                  */
-  cpl_propertylist *parms;                 /* Input parameters propertylist               */
-  cpl_propertylist *pl_data;               /* Header    of input data       fits file     */
-  cpl_propertylist *pl_correction;         /* Header    of input correction fits file     */
-  const char       *tag_output;            /* Tag of the output files                     */
+  kmos_molecfit_correct_data ifus[N_IFUS]; /* Input data                                          */
+  cpl_propertylist *parms;                 /* Input parameters propertylist                       */
+  cpl_propertylist *pl_data;               /* Header    of input data       fits file             */
+  cpl_propertylist *pl_correction;         /* Header    of input correction fits file             */
+  const char       *tag_output;            /* Tag of the output files                             */
 } kmos_molecfit_correct_parameter;
 
 
@@ -71,14 +72,16 @@ typedef struct {
  */
 /*----------------------------------------------------------------------------*/
 
+/* Use the data input and kmos_molecfit_calctrans output to configure kmos_molecfit_correct */
+static cpl_error_code kmos_molecfit_correct_frame_conf(
+    kmos_molecfit_correct_parameter *conf,
+    cpl_frame                       *frmCorrection,
+    cpl_frame                       *frmData);
+
 /* Fill the internal KMOS configuration file */
 static kmos_molecfit_correct_parameter * kmos_molecfit_correct_conf(
     const cpl_parameterlist *list);
 
-/* Use the data input and kmos_molecfit_calctrans output to configure kmos_molecfit_correct */
-static cpl_error_code kmos_molecfit_correct_frames_conf(
-    kmos_molecfit_correct_parameter *conf, cpl_frameset *frameset);
-
 /* Clean variables allocated in the recipe */
 static void kmos_molecfit_correct_clean(
     kmos_molecfit_correct_parameter *conf);
@@ -104,7 +107,7 @@ static char kmos_molecfit_correct_description[] =
     "It is independent from molecfit/calctrans and uses one utility that is available in the KMOS pipeline (kmo_arithmetic).\n"
     "The result obtained by the proposed molecfit/calctrans recipes must be the same as at the current molecfit and calctrans stand-alone tools.\n"
     "\n"
-    "Input files: (It's mandatory to provide 1 file only of type A and B) \n"
+    "Input files: (It's mandatory to provide 1 to N files type A, but only 1 type B that it will apply in all of A's) \n"
     "\n"
     "   DO                 KMOS                                               \n"
     "   category           Type   required   Explanation                      \n"
@@ -171,141 +174,209 @@ static int kmos_molecfit_correct(
   /* Get initial errorstate */
   cpl_errorstate initial_errorstate = cpl_errorstate_get();
 
-  /* Extract and verify data in the parameters of the recipe */
-  cpl_msg_info(cpl_func, "Configuring initial parameters in the recipe ...");
-  kmos_molecfit_correct_parameter *conf = kmos_molecfit_correct_conf(parlist);
-  cpl_error_ensure(conf, CPL_ERROR_ILLEGAL_INPUT,
-                   return (int)CPL_ERROR_ILLEGAL_INPUT, "Problems with the configuration parameters");
+  /* Get --suppress_extension parameter : Flag to activate/suppress the output grating prefix */
+  const cpl_parameter *p = cpl_parameterlist_find_const(parlist, "suppress_extension");
+  cpl_boolean suppress_extension = cpl_parameter_get_bool(p);
 
-  /* Complete configuration using the data input and kmos_molecfit_calctrans output to configure kmos_molecfit_correct */
-
-  if (kmos_molecfit_correct_frames_conf(conf, frameset) != CPL_ERROR_NONE) {
-      kmos_molecfit_correct_clean(conf);
-      return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
-                                        "Configuration with kmos_molecfit_model output failed!");
+  /*** Get frame, header and check: correction TELLURIC_CORR/RESPONSE ***/
+  cpl_errorstate preStateLoadCorrection = cpl_errorstate_get();
+  cpl_msg_info(cpl_func, "Loading header, input spectrum correction ...");
+  cpl_frame *frmCorrection = cpl_frameset_find(frameset, TELLURIC_CORR);
+  if (!frmCorrection) {
+      cpl_errorstate_set(preStateLoadCorrection);
+      frmCorrection = cpl_frameset_find(frameset, RESPONSE);
+      if (!frmCorrection) {
+          return cpl_error_set_message(cpl_func, CPL_ERROR_DATA_NOT_FOUND,
+                                       "Frame with input correction data spectrum not found in frameset ('%s','%s') !",
+                                       TELLURIC_CORR, RESPONSE);
+      }
   }
 
-  cpl_msg_info(cpl_func, " +++ All input data loaded successfully! +++");
+  /*** Create the raw frameset ***/
+  cpl_size     nframes  = cpl_frameset_get_size(frameset);
+  cpl_frameset *fs_raws = cpl_frameset_new();
+  for (cpl_size i = 0; i < nframes; i++) {
 
+     cpl_frame  *frame    = cpl_frameset_get_position(frameset, i);
 
-  /* Saving generic multi-extension output *.fits file */
-  char *filename = cpl_sprintf("%s_%s", conf->tag_output, cpl_propertylist_get_string(conf->pl_data, "ARCFILE"));
-  cpl_msg_info(cpl_func, "Saving generic multi-extension output fits file ('%s') ...", filename);
-  if (kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->parms, conf->tag_output, NULL, filename) != CPL_ERROR_NONE) {
-      cpl_free(filename);
-      kmos_molecfit_correct_clean(conf);
-      return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
-                                        "Saving generic multi-extension output fits files failed!");
+     if (   !strcmp(cpl_frame_get_tag(frame), STAR_SPEC         )
+         || !strcmp(cpl_frame_get_tag(frame), EXTRACT_SPEC      )
+         || !strcmp(cpl_frame_get_tag(frame), SCIENCE           )
+         || !strcmp(cpl_frame_get_tag(frame), RECONSTRUCTED_CUBE) ){
+
+         cpl_frameset_insert(fs_raws, cpl_frame_duplicate(frame));
+     }
   }
 
+  /* Check size of raw frameset*/
+  cpl_size n_raws = cpl_frameset_get_size(fs_raws);
+  if (n_raws < 1) {
+      cpl_frameset_delete(fs_raws);
+      return cpl_error_set_message(cpl_func, CPL_ERROR_DATA_NOT_FOUND,
+                                   "Not raw Frames in the input frameset!");
+  }
 
-  /* Execute correction */
-  for (cpl_size n_ifu = 0; n_ifu < N_IFUS; n_ifu++) {
-      kmos_molecfit_correct_data *ifu = &(conf->ifus[n_ifu]);
+  /* Loop to compute all the inputs raws files */
+  for (cpl_size i = 0; i < n_raws; i++) {
 
-      /* Get state */
-      cpl_errorstate preState = cpl_errorstate_get();
+      /* Get one input data file */
+      cpl_frame *frmData = cpl_frameset_get_position(fs_raws, i);
 
-      /* Apply the correction and save */
-      cpl_error_code e_sData;
-      cpl_error_code e_sNoise = CPL_ERROR_NONE;
+      /* Extract and verify data in the parameters of the recipe */
+      cpl_msg_info(cpl_func, "Configuring initial parameters in the recipe ...");
+      kmos_molecfit_correct_parameter *conf = kmos_molecfit_correct_conf(parlist);
+      if (!conf) {
+          cpl_frameset_delete(fs_raws);
+          return (int)cpl_error_set_message(cpl_func, CPL_ERROR_ILLEGAL_INPUT,
+                                            "Problems with the configuration parameters");
 
-      /*** Get input data ***/
-      if (ifu->vec_data) {
+      }
 
-          cpl_msg_info(cpl_func,     "Correcting                   1D data  spectrum    , IFU.%02lld ...", n_ifu + 1);
-          cpl_vector_divide(ifu->vec_data, ifu->correction);
+      /* Complete configuration using the data input and kmos_molecfit_calctrans output to configure kmos_molecfit_correct */
+      if (kmos_molecfit_correct_frame_conf(conf, frmCorrection, frmData) != CPL_ERROR_NONE) {
+          kmos_molecfit_correct_clean(conf);
+          cpl_frameset_delete(fs_raws);
+          return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                            "Configuration with kmos_molecfit_model output failed!");
+      }
 
-          cpl_msg_info(cpl_func,     "Saving in '%s' 1D data              , IFU.%02lld ...", filename, n_ifu + 1);
-          e_sData  = cpl_vector_save(ifu->vec_data, filename, CPL_TYPE_FLOAT, ifu->header_ext_data, CPL_IO_EXTEND);
+      const char *fileData = cpl_frame_get_filename(frmData);
+      cpl_msg_info(cpl_func, " +++ All input data loaded successfully from the input file: %s +++", fileData);
 
-          if (ifu->vec_noise) {
+      /* Saving generic multi-extension output *.fits file */
+      char *filename;
+      if (suppress_extension) {
+          filename = cpl_sprintf("%s_%lld.fits", conf->tag_output, i);
+      } else {
+          filename = cpl_sprintf("%s_%s", conf->tag_output, cpl_propertylist_get_string(conf->pl_data, "ARCFILE"));
+      }
 
-              cpl_msg_info(cpl_func, "Correcting                   1D noise spectrum, IFU.%02lld ...", n_ifu + 1);
-              cpl_vector_divide(ifu->vec_noise, ifu->correction);
+      cpl_msg_info(cpl_func, "Saving generic multi-extension output fits file ('%s') ...", filename);
+      if (kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->parms, conf->tag_output, NULL, CPL_FALSE, filename) != CPL_ERROR_NONE) {
+          cpl_free(filename);
+          kmos_molecfit_correct_clean(conf);
+          cpl_frameset_delete(fs_raws);
+          return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                            "Saving generic multi-extension output fits files failed!");
+      }
 
-              cpl_msg_info(cpl_func, "Saving in '%s' 1D noise             , IFU.%02lld ...", filename, n_ifu + 1);
-              e_sNoise = cpl_vector_save(ifu->vec_noise, filename, CPL_TYPE_FLOAT, ifu->header_ext_noise, CPL_IO_EXTEND);
 
-          } else if (ifu->header_ext_noise){
+      /* Execute correction */
+      for (cpl_size n_ifu = 0; n_ifu < N_IFUS; n_ifu++) {
+          kmos_molecfit_correct_data *ifu = &(conf->ifus[n_ifu]);
 
-              cpl_msg_info(cpl_func, "Saving in '%s'    header noise      , IFU.%02lld ...", filename, n_ifu + 1);
-              e_sNoise = cpl_propertylist_save(ifu->header_ext_noise, filename, CPL_IO_EXTEND);
-          }
+          /* Get state */
+          cpl_errorstate preState = cpl_errorstate_get();
 
-      } else if (ifu->cube_data) {
+          /* Apply the correction and save */
+          cpl_error_code e_sData;
+          cpl_error_code e_sNoise = CPL_ERROR_NONE;
 
-          /* Conver ifu->correction for operate with kmo_priv_arithmetic */
-          kmclipm_vector *correction = kmclipm_vector_create(cpl_vector_duplicate(ifu->correction));
+          /*** Get input data ***/
+          if (ifu->vec_data) {
 
-          cpl_msg_info(cpl_func,     "Correcting                    3D data   cube       , IFU.%02lld ...", n_ifu + 1);
-          if (kmo_arithmetic_3D_1D(ifu->cube_data, correction, NULL, NULL, "/") != CPL_ERROR_NONE) {
-              cpl_free(filename);
-              kmclipm_vector_delete(correction);
-              kmos_molecfit_correct_clean(conf);
-              return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
-                                                "Correction 3D failed in IFU.%02lld!", n_ifu + 1);
-          }
+              cpl_msg_info(cpl_func,     "Correcting                   1D data  spectrum    , IFU.%02lld ...", n_ifu + 1);
+              cpl_vector_divide(ifu->vec_data, ifu->correction);
 
-          cpl_msg_info(cpl_func,     "Saving in '%s' 3D data              , IFU.%02lld ...", filename, n_ifu + 1);
-          e_sData  = cpl_imagelist_save(ifu->cube_data, filename, CPL_TYPE_FLOAT, ifu->header_ext_data, CPL_IO_EXTEND);
+              cpl_msg_info(cpl_func,     "Saving in '%s' 1D data              , IFU.%02lld ...", filename, n_ifu + 1);
+              e_sData  = cpl_vector_save(ifu->vec_data, filename, CPL_TYPE_FLOAT, ifu->header_ext_data, CPL_IO_EXTEND);
 
-          if (ifu->cube_noise) {
+              if (ifu->vec_noise) {
 
-              cpl_msg_info(cpl_func, "Correcting                    3D noise  cube, IFU.%02lld ...", n_ifu + 1);
-              if (kmo_arithmetic_3D_1D(ifu->cube_noise, correction, NULL, NULL, "/") != CPL_ERROR_NONE) {
+                  cpl_msg_info(cpl_func, "Correcting                   1D noise spectrum, IFU.%02lld ...", n_ifu + 1);
+                  cpl_vector_divide(ifu->vec_noise, ifu->correction);
+
+                  cpl_msg_info(cpl_func, "Saving in '%s' 1D noise             , IFU.%02lld ...", filename, n_ifu + 1);
+                  e_sNoise = cpl_vector_save(ifu->vec_noise, filename, CPL_TYPE_FLOAT, ifu->header_ext_noise, CPL_IO_EXTEND);
+
+              } else if (ifu->header_ext_noise){
+
+                  cpl_msg_info(cpl_func, "Saving in '%s'    header noise      , IFU.%02lld ...", filename, n_ifu + 1);
+                  e_sNoise = cpl_propertylist_save(ifu->header_ext_noise, filename, CPL_IO_EXTEND);
+              }
+
+          } else if (ifu->cube_data) {
+
+              /* Conver ifu->correction for operate with kmo_priv_arithmetic */
+              kmclipm_vector *correction = kmclipm_vector_create(cpl_vector_duplicate(ifu->correction));
+
+              cpl_msg_info(cpl_func,     "Correcting                    3D data   cube       , IFU.%02lld ...", n_ifu + 1);
+              if (kmo_arithmetic_3D_1D(ifu->cube_data, correction, NULL, NULL, "/") != CPL_ERROR_NONE) {
                   cpl_free(filename);
                   kmclipm_vector_delete(correction);
                   kmos_molecfit_correct_clean(conf);
+                  cpl_frameset_delete(fs_raws);
                   return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
                                                     "Correction 3D failed in IFU.%02lld!", n_ifu + 1);
               }
 
-              cpl_msg_info(cpl_func, "Saving in '%s' 3D noise correction cube, IFU.%02lld ...", filename, n_ifu + 1);
-              e_sNoise = cpl_imagelist_save(ifu->cube_noise, filename, CPL_TYPE_FLOAT, ifu->header_ext_noise, CPL_IO_EXTEND);
+              cpl_msg_info(cpl_func,     "Saving in '%s' 3D data              , IFU.%02lld ...", filename, n_ifu + 1);
+              e_sData  = cpl_imagelist_save(ifu->cube_data, filename, CPL_TYPE_FLOAT, ifu->header_ext_data, CPL_IO_EXTEND);
 
-          } else if (ifu->header_ext_noise) {
+              if (ifu->cube_noise) {
 
-              cpl_msg_info(cpl_func, "Saving in '%s'    header noise      , IFU.%02lld ...", filename, n_ifu + 1);
-              e_sNoise = cpl_propertylist_save(ifu->header_ext_noise, filename, CPL_IO_EXTEND);
+                  cpl_msg_info(cpl_func, "Correcting                    3D noise  cube, IFU.%02lld ...", n_ifu + 1);
+                  if (kmo_arithmetic_3D_1D(ifu->cube_noise, correction, NULL, NULL, "/") != CPL_ERROR_NONE) {
+                      cpl_free(filename);
+                      kmclipm_vector_delete(correction);
+                      kmos_molecfit_correct_clean(conf);
+                      cpl_frameset_delete(fs_raws);
+                      return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                                        "Correction 3D failed in IFU.%02lld!", n_ifu + 1);
+                  }
+
+                  cpl_msg_info(cpl_func, "Saving in '%s' 3D noise correction cube, IFU.%02lld ...", filename, n_ifu + 1);
+                  e_sNoise = cpl_imagelist_save(ifu->cube_noise, filename, CPL_TYPE_FLOAT, ifu->header_ext_noise, CPL_IO_EXTEND);
+
+              } else if (ifu->header_ext_noise) {
+
+                  cpl_msg_info(cpl_func, "Saving in '%s'    header noise      , IFU.%02lld ...", filename, n_ifu + 1);
+                  e_sNoise = cpl_propertylist_save(ifu->header_ext_noise, filename, CPL_IO_EXTEND);
+              }
+
+              /* Cleanup correction */
+              kmclipm_vector_delete(correction);
+
+          } else {
+
+              cpl_msg_info(cpl_func, "Saving in '%s'    header data       , IFU.%02lld ...", filename, n_ifu + 1);
+              e_sData      = cpl_propertylist_save(ifu->header_ext_data,  filename, CPL_IO_EXTEND);
+              if (ifu->header_ext_noise) {
+                  cpl_msg_info(cpl_func, "Saving in '%s'    header noise      , IFU.%02lld ...", filename, n_ifu + 1);
+                  e_sNoise = cpl_propertylist_save(ifu->header_ext_noise, filename, CPL_IO_EXTEND);
+              }
           }
 
-          /* Cleanup correction */
-          kmclipm_vector_delete(correction);
+          /* Check save  */
+          if (e_sData != CPL_ERROR_NONE || e_sNoise != CPL_ERROR_NONE) {
+              cpl_free(filename);
+              kmos_molecfit_correct_clean(conf);
+              cpl_frameset_delete(fs_raws);
+              return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                                "Saving correction output failed!, ext=%lld", n_ifu + 1);
+          }
 
-      } else {
+          /* Check execution */
+          if (!cpl_errorstate_is_equal(preState)) {
+              cpl_msg_info(cpl_func, "Correction failed! in IFU.%02lld -> error: %s", n_ifu + 1, cpl_error_get_message());
+              cpl_free(filename);
+              kmos_molecfit_correct_clean(conf);
+              cpl_frameset_delete(fs_raws);
+              return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                                "Correction failed! in IFU.%02lld ...", n_ifu + 1);
 
-          cpl_msg_info(cpl_func, "Saving in '%s'    header data       , IFU.%02lld ...", filename, n_ifu + 1);
-          e_sData      = cpl_propertylist_save(ifu->header_ext_data,  filename, CPL_IO_EXTEND);
-          if (ifu->header_ext_noise) {
-              cpl_msg_info(cpl_func, "Saving in '%s'    header noise      , IFU.%02lld ...", filename, n_ifu + 1);
-              e_sNoise = cpl_propertylist_save(ifu->header_ext_noise, filename, CPL_IO_EXTEND);
           }
       }
 
-      /* Check save  */
-      if (e_sData != CPL_ERROR_NONE || e_sNoise != CPL_ERROR_NONE) {
-          cpl_free(filename);
-          kmos_molecfit_correct_clean(conf);
-          return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
-                                            "Saving correction output failed!, ext=%lld", n_ifu + 1);
-      }
-
-      /* Check execution */
-      if (!cpl_errorstate_is_equal(preState)) {
-          cpl_msg_info(cpl_func, "Correction failed! in IFU.%02lld -> error: %s", n_ifu + 1, cpl_error_get_message());
-          cpl_free(filename);
-          kmos_molecfit_correct_clean(conf);
-          return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
-                                            "Correction failed! in IFU.%02lld ...", n_ifu + 1);
-
-      }
+      /* Cleanup configuration */
+      cpl_msg_info(cpl_func,"Cleaning variables from the input file : %s", fileData);
+      cpl_free(filename);
+      kmos_molecfit_correct_clean(conf);
   }
 
-  /* Cleanup configuration */
-  cpl_msg_info(cpl_func,"Cleaning variables ...");
-  cpl_free(filename);
-  kmos_molecfit_correct_clean(conf);
+  /* Cleanup */
+  cpl_frameset_delete(fs_raws);
+
 
   /* Check Recipe status and end */
   if (cpl_errorstate_is_equal(initial_errorstate) && cpl_error_get_code() == CPL_ERROR_NONE ) {
@@ -340,6 +411,21 @@ static cpl_error_code kmos_molecfit_correct_fill_parameterlist(
   /* Add the different default parameters to the recipe */
   cpl_errorstate prestate = cpl_errorstate_get();
 
+  /* Fill the parameters list */
+  cpl_error_code e;
+  cpl_boolean    range     = CPL_TRUE;
+  const void     *dummyMin = NULL;
+  const void     *dummyMax = NULL;
+
+
+  /* --suppress_extension */
+  cpl_boolean suppress_extension = CPL_FALSE;
+  e = kmos_molecfit_fill_parameter(RECIPE_NAME, self, "suppress_extension",
+                                   !range, dummyMin, dummyMax, CPL_TYPE_BOOL, &suppress_extension,
+                                   "Suppress arbitrary filename extension.(TRUE (apply) or FALSE (don't apply).", CPL_FALSE);
+  if (e != CPL_ERROR_NONE) return (int)e;
+
+
   /* Check possible errors */
   if (!cpl_errorstate_is_equal(prestate)) {
       return cpl_error_set_message(cpl_func, cpl_error_get_code(),
@@ -411,11 +497,13 @@ static kmos_molecfit_correct_parameter * kmos_molecfit_correct_conf(
  *
  */
 /*----------------------------------------------------------------------------*/
-static cpl_error_code kmos_molecfit_correct_frames_conf(
-    kmos_molecfit_correct_parameter *conf, cpl_frameset *frameset)
+static cpl_error_code kmos_molecfit_correct_frame_conf(
+    kmos_molecfit_correct_parameter *conf,
+    cpl_frame                       *frmCorrection,
+    cpl_frame                       *frmData)
 {
   /* Check input */
-  cpl_error_ensure(conf && frameset, CPL_ERROR_NULL_INPUT,
+  cpl_error_ensure(conf && frmCorrection && frmData, CPL_ERROR_NULL_INPUT,
                    return CPL_ERROR_NULL_INPUT, "kmos_molecfit_correct_inputs_conf inputs NULL!");
 
   /* Get preState */
@@ -424,7 +512,6 @@ static cpl_error_code kmos_molecfit_correct_frames_conf(
 
   /*** Get frame, header and check input data ***/
   cpl_msg_info(cpl_func, "Loading header, input data frame ...");
-  cpl_frame  *frmData  = kmos_molecfit_get_frame_spectrums(frameset);
   const char *fileData = cpl_frame_get_filename(frmData);
   conf->pl_data = cpl_propertylist_load(fileData, 0);
   cpl_error_ensure(conf->pl_data, cpl_error_get_code(),
@@ -435,13 +522,25 @@ static cpl_error_code kmos_molecfit_correct_frames_conf(
       cpl_propertylist_update_string(conf->parms, KMOS_MOLECFIT_CORRECT_REFLEX_SUFFIX, cpl_propertylist_get_string(conf->pl_data, KMOS_MOLECFIT_CORRECT_REFLEX_SUFFIX));
   }
 
+  /* Propagate the keyword : ESO PRO MJD-OBS */
+  if (cpl_propertylist_has(conf->pl_data, PRO_MJD_OBS)) {
+      cpl_propertylist_update_double(conf->parms, PRO_MJD_OBS,
+              cpl_propertylist_get_double(conf->pl_data, PRO_MJD_OBS));
+  }
+
+  /* Propagate the keyword : ESO PRO DATE-OBS */
+  if (cpl_propertylist_has(conf->pl_data, PRO_DATE_OBS)) {
+      cpl_propertylist_update_string(conf->parms, PRO_DATE_OBS,
+              cpl_propertylist_get_string(conf->pl_data, PRO_DATE_OBS));
+  }
+
   /* Get input data tag and select ouput tag */
   const char *tag = cpl_frame_get_tag(frmData);
-  if (       strcmp(tag, STAR_SPEC         ) == 0 ||
-      strcmp(tag, EXTRACT_SPEC      ) == 0 ){
+  if (          strcmp(tag, STAR_SPEC         ) == 0
+             || strcmp(tag, EXTRACT_SPEC      ) == 0 ){
       conf->tag_output = SINGLE_SPECTRA;
-  } else if (strcmp(tag, SCIENCE           ) == 0 ||
-      strcmp(tag, RECONSTRUCTED_CUBE) == 0 ){
+  } else if (   strcmp(tag, SCIENCE           ) == 0
+             || strcmp(tag, RECONSTRUCTED_CUBE) == 0 ){
       conf->tag_output = SINGLE_CUBES;
   } else {
       return cpl_error_set_message(cpl_func, CPL_ERROR_TYPE_MISMATCH,
@@ -452,20 +551,6 @@ static cpl_error_code kmos_molecfit_correct_frames_conf(
   cpl_size n_extensions_raw = cpl_fits_count_extensions(fileData);
   cpl_size ext24_raw = (N_IFUS == n_extensions_raw) ? 1 : 2;
 
-
-  /*** Get frame, header and check: correction TELLURIC_CORR/RESPONSE ***/
-  cpl_errorstate preStateLoadCorrection = cpl_errorstate_get();
-  cpl_msg_info(cpl_func, "Loading header, input spectrum correction ...");
-  cpl_frame *frmCorrection = cpl_frameset_find(frameset, TELLURIC_CORR);
-  if (!frmCorrection) {
-      cpl_errorstate_set(preStateLoadCorrection);
-      frmCorrection = cpl_frameset_find(frameset, RESPONSE);
-      if (!frmCorrection) {
-          return cpl_error_set_message(cpl_func, CPL_ERROR_DATA_NOT_FOUND,
-                                       "Frame with input correction data spectrum not found in frameset ('%s','%s') !",
-                                       TELLURIC_CORR, RESPONSE);
-      }
-  }
   const char *fileCorrection = cpl_frame_get_filename(frmCorrection);
   conf->pl_correction = cpl_propertylist_load(fileCorrection, 0);
   cpl_error_ensure(conf->pl_correction, cpl_error_get_code(),
