@@ -35,6 +35,28 @@
  */
 /*----------------------------------------------------------------------------*/
 
+#define KMOS_MOLECFIT_RESULTS_COLUMN_PARAMETER    "parameter"
+#define KMOS_MOLECFIT_RESULTS_COLUMN_VALUE        "value"
+#define KMOS_MOLECFIT_MODEL_COLUMN_FLUX           "flux"
+#define KMOS_MOLECFIT_MODEL_COLUMN_MSCAL          "mscal"
+#define KMOS_MOLECFIT_MODEL_COLUMN_MTRANS         "mtrans"
+#define KMOS_MOLECFIT_CALCULE_COLUMN_NF           "NF"
+#define KMOS_MOLECFIT_CALCULE_COLUMN_NTF          "NTF"
+
+#define KMOS_MOLECFIT_RESULTS_ROW_RMS_REL_TO_MEAN "rms_rel_to_mean"
+#define KMOS_MOLECFIT_RESULTS_ROW_RMS_STATUS      "status"
+#define KMOS_MOLECFIT_RESULTS_ROW_RMS_H2O_COL_MM  "h2o_col_mm"
+
+#define KMOS_MOLECFIT_QC_PARAM_RMS                "ESO QC RMS"
+#define KMOS_MOLECFIT_QC_PARAM_STATUS             "ESO QC STATUS"
+#define KMOS_MOLECFIT_QC_PARAM_H2O                "ESO QC H2O"
+#define KMOS_MOLECFIT_QC_PARAM_IMPROV             "ESO QC IMPROV"
+
+#define KMOS_MOLECFIT_QC_PARAM_RMS_TXT            "Molecfit best_fit parameter rms_rel_to_mean"
+#define KMOS_MOLECFIT_QC_PARAM_STATUS_TXT         "Molecfit best_fit parameter status"
+#define KMOS_MOLECFIT_QC_PARAM_H2O_TXT            "Molecfit best_fit parameter h2o_col_mm"
+#define KMOS_MOLECFIT_QC_PARAM_IMPROV_TXT         "Computed from the Molecfit model columns flux, mscal, mtrans"
+
 /*----------------------------------------------------------------------------*/
 /**
  *                 Typedefs: Structs and enum types
@@ -79,6 +101,13 @@ static cpl_parameterlist * kmos_molecfit_model_mf_conf(
 static void kmos_molecfit_model_clean(
     kmos_molecfit_model_parameter *conf);
 
+/* Insert QC parameters in the headers of the IFUs with valid data */
+static cpl_error_code kmos_molecfit_model_headers_fill_qc_parameters(
+    const cpl_table  *res_table,
+    const cpl_table  *spec_out,
+    cpl_propertylist *pl_BParms,
+    cpl_propertylist *pl_BModel);
+
 /*----------------------------------------------------------------------------*/
 /**
  *                          Static variables
@@ -208,9 +237,9 @@ static int kmos_molecfit_model(
 
   /* Saving generic multi-extension output *.fits files */
   cpl_msg_info(cpl_func, "Saving generic multi-extension output fits file ('%s','%s','%s') ...", ATMOS_PARM, BEST_FIT_PARM, BEST_FIT_MODEL);
-  cpl_error_code sAtm_e    = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, ATMOS_PARM,     conf->mf.grating.name, NULL);
-  cpl_error_code sBParms_e = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, BEST_FIT_PARM,  conf->mf.grating.name, NULL);
-  cpl_error_code sBModel_e = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, BEST_FIT_MODEL, conf->mf.grating.name, NULL);
+  cpl_error_code sAtm_e    = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, ATMOS_PARM,     conf->mf.grating.name, conf->mf.suppress_extension, NULL);
+  cpl_error_code sBParms_e = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, BEST_FIT_PARM,  conf->mf.grating.name, conf->mf.suppress_extension, NULL);
+  cpl_error_code sBModel_e = kmos_molecfit_save(frameset, parlist, RECIPE_NAME, conf->mf.parms, BEST_FIT_MODEL, conf->mf.grating.name, conf->mf.suppress_extension, NULL);
   if (sAtm_e != CPL_ERROR_NONE || sBParms_e != CPL_ERROR_NONE || sBModel_e != CPL_ERROR_NONE) {
       kmos_molecfit_model_clean(conf);
       return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
@@ -240,6 +269,10 @@ static int kmos_molecfit_model(
       cpl_table *res_table = NULL;
       cpl_table *spec_out  = NULL;
 
+      /* Create local headers to fill QC parameters, if they are need */
+      cpl_propertylist *pl_BParms = cpl_propertylist_duplicate(ifu->header_ext_data);
+      cpl_propertylist *pl_BModel = cpl_propertylist_duplicate(ifu->header_ext_data);
+
       /* Check if the IFU contains data */
       if (ifu->process && ifu->data) {
 
@@ -247,6 +280,8 @@ static int kmos_molecfit_model(
           cpl_msg_info(cpl_func, "Building molecfict configuration variable in %s ... ", ifu->name);
           cpl_parameterlist *mf_config = kmos_molecfit_model_mf_conf(conf, ifu, grating->type);
           if (!mf_config) {
+              cpl_propertylist_delete(pl_BParms);
+              cpl_propertylist_delete(pl_BModel);
               kmos_molecfit_model_clean(conf);
               kmos_molecfit_tmpdir_set(tmpdir, NULL);
               cpl_free(tmpdir);
@@ -282,6 +317,8 @@ static int kmos_molecfit_model(
               cpl_msg_info(cpl_func, "Call mf_run_molecfit(...) run successfully! in %s ...", ifu->name);
           } else {
               cpl_msg_info(cpl_func, "Call mf_run_molecfit(...) failed! in %s -> error: %s", ifu->name, cpl_error_get_message());
+              cpl_propertylist_delete(pl_BParms);
+              cpl_propertylist_delete(pl_BModel);
               kmos_molecfit_model_clean(conf);
               cpl_parameterlist_delete(mf_config);
               mf_cleanup(mf_state);
@@ -291,6 +328,22 @@ static int kmos_molecfit_model(
               return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
                                                 "Molecfit call (mf_run_molecfit) failed! ...");
           }
+
+          /* Add QC parameters to assess the quality of the telluric correction */
+          if (kmos_molecfit_model_headers_fill_qc_parameters(res_table, spec_out, pl_BParms, pl_BModel) != CPL_ERROR_NONE) {
+              cpl_msg_info(cpl_func, "Fill QC parameters in headers failed! in %s -> error: %s", ifu->name, cpl_error_get_message());
+              cpl_propertylist_delete(pl_BParms);
+              cpl_propertylist_delete(pl_BModel);
+              kmos_molecfit_model_clean(conf);
+              cpl_parameterlist_delete(mf_config);
+              mf_cleanup(mf_state);
+              cpl_table_delete(data);
+              kmos_molecfit_tmpdir_set(tmpdir, NULL);
+              cpl_free(tmpdir);
+              return (int)cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                                "Fill QC parameters in headers failed! ...");
+          }
+
           n_procesed_ifus++;
 
           /* Cleanup molecfic output variables */
@@ -307,12 +360,19 @@ static int kmos_molecfit_model(
       } else {
           cpl_msg_info(cpl_func, "Saving data IFU=%d ... (data spectrum -> Molecfit executed)", ifu->num);
       }
-      sAtm_e    = kmos_molecfit_save_mf_results(ifu->header_ext_data, ifu->header_ext_noise, ATMOS_PARM,     conf->mf.grating.name, NULL, atmprof,   NULL);
-      sBParms_e = kmos_molecfit_save_mf_results(ifu->header_ext_data, ifu->header_ext_noise, BEST_FIT_PARM,  conf->mf.grating.name, NULL, res_table, NULL);
-      sBModel_e = kmos_molecfit_save_mf_results(ifu->header_ext_data, ifu->header_ext_noise, BEST_FIT_MODEL, conf->mf.grating.name, NULL, spec_out,  NULL);
+
+      sAtm_e    = kmos_molecfit_save_mf_results(ifu->header_ext_data, ifu->header_ext_noise, ATMOS_PARM,     conf->mf.grating.name, conf->mf.suppress_extension, NULL, atmprof,   NULL);
+      sBParms_e = kmos_molecfit_save_mf_results(pl_BParms,            ifu->header_ext_noise, BEST_FIT_PARM,  conf->mf.grating.name, conf->mf.suppress_extension, NULL, res_table, NULL);
+      sBModel_e = kmos_molecfit_save_mf_results(pl_BModel,            ifu->header_ext_noise, BEST_FIT_MODEL, conf->mf.grating.name, conf->mf.suppress_extension, NULL, spec_out,  NULL);
+
+      /* Cleanup */
+      cpl_propertylist_delete(pl_BParms);
+      cpl_propertylist_delete(pl_BModel);
+
       if (atmprof)   cpl_table_delete(atmprof);
       if (res_table) cpl_table_delete(res_table);
       if (spec_out)  cpl_table_delete(spec_out);
+
       if (sAtm_e != CPL_ERROR_NONE || sBParms_e != CPL_ERROR_NONE || sBModel_e != CPL_ERROR_NONE) {
           kmos_molecfit_model_clean(conf);
           kmos_molecfit_tmpdir_set(tmpdir, NULL);
@@ -375,6 +435,13 @@ static cpl_error_code kmos_molecfit_model_fill_parameterlist(
                                    "A list of IFUs to process. If set to -1, all the IFUs that have data will be process.", CPL_FALSE);
   if (e != CPL_ERROR_NONE) return (int)e;
 
+  /* --suppress_extension */
+  cpl_boolean suppress_extension = CPL_FALSE;
+  e = kmos_molecfit_fill_parameter(RECIPE_NAME, self, "suppress_extension",
+                                   !range, dummyMin, dummyMax, CPL_TYPE_BOOL, &suppress_extension,
+                                   "Suppress arbitrary filename extension.(TRUE (apply) or FALSE (don't apply).", CPL_FALSE);
+  if (e != CPL_ERROR_NONE) return (int)e;
+
   /* --wave_range */
   const char *wave_range = "-1";
   e = kmos_molecfit_fill_parameter(RECIPE_NAME, self, "wave_range",
@@ -770,6 +837,9 @@ static kmos_molecfit_model_parameter * kmos_molecfit_model_conf(
       kmo_strfreev(tokens);
   }
 
+  /*** Suppress prefix ***/
+  p = cpl_parameterlist_find_const(list, "suppress_extension");
+  conf->mf.suppress_extension = cpl_parameter_get_bool(p);
 
   /*** Wavelenght ranges & molecules: Defined by the user ****/
 
@@ -795,7 +865,6 @@ static kmos_molecfit_model_parameter * kmos_molecfit_model_conf(
       return NULL;
   }
 
-
   /*** Convergence criterion ***/
 
   p = cpl_parameterlist_find_const(list, "ftol");
@@ -967,37 +1036,38 @@ static kmos_molecfit_model_parameter * kmos_molecfit_model_conf(
 
   /* Save parameter in the output propertylist */
 
-  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"PROCESS_IFUS",     conf->process_ifus);
+  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"PROCESS_IFUS",       conf->process_ifus);
 
-  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"WAVE_RANGE",       conf->mf.grating.wave_range);
-  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"LIST_MOLEC",       conf->mf.grating.list_molec);
-  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_MOLEC",        conf->mf.grating.fit_molec);
-  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RECOL",           conf->mf.grating.relcol);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"SUPPRESS_EXTENSION", conf->mf.suppress_extension);
 
-  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"FTOL",             conf->ftol);
-  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"XTOL",             conf->xtol);
+  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"WAVE_RANGE",         conf->mf.grating.wave_range);
+  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"LIST_MOLEC",         conf->mf.grating.list_molec);
+  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_MOLEC",          conf->mf.grating.fit_molec);
+  cpl_propertylist_update_string(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RECOL",              conf->mf.grating.relcol);
 
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_CONT",         conf->mf.fit_continuum.fit);
-  cpl_propertylist_update_int(   conf->mf.parms, KMOS_MF_PARAM_RECIPE"CONT_N",           conf->mf.fit_continuum.n);
+  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"FTOL",               conf->ftol);
+  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"XTOL",               conf->xtol);
 
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_WLC",          conf->mf.fit_wavelenght.fit);
-  cpl_propertylist_update_int(   conf->mf.parms, KMOS_MF_PARAM_RECIPE"WLC_N",            conf->mf.fit_wavelenght.n);
-  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"WLC_CONST",        conf->mf.fit_wavelenght.const_val);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_CONT",           conf->mf.fit_continuum.fit);
+  cpl_propertylist_update_int(   conf->mf.parms, KMOS_MF_PARAM_RECIPE"CONT_N",             conf->mf.fit_continuum.n);
 
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"USE_INPUT_KERNEL", conf->mf.use_input_kernel);
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"KERNMODE",         conf->mf.kernmode);
-  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"KERNFAC",          conf->mf.kernfac);
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"VARKERN",          conf->mf.varkern);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_WLC",            conf->mf.fit_wavelenght.fit);
+  cpl_propertylist_update_int(   conf->mf.parms, KMOS_MF_PARAM_RECIPE"WLC_N",              conf->mf.fit_wavelenght.n);
+  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"WLC_CONST",          conf->mf.fit_wavelenght.const_val);
 
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_RES_BOX",      conf->boxcar.fit);
-  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RELRES_BOX",       conf->boxcar.res);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"USE_INPUT_KERNEL",   conf->mf.use_input_kernel);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"KERNMODE",           conf->mf.kernmode);
+  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"KERNFAC",            conf->mf.kernfac);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"VARKERN",            conf->mf.varkern);
 
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_RES_GAUSS",    conf->gauss.fit);
-  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RES_GAUSS",        conf->gauss.res);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_RES_BOX",        conf->boxcar.fit);
+  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RELRES_BOX",         conf->boxcar.res);
 
-  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_RES_LORENTZ",  conf->lorentz.fit);
-  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RES_LORENTZ",      conf->lorentz.res);
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_RES_GAUSS",      conf->gauss.fit);
+  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RES_GAUSS",          conf->gauss.res);
 
+  cpl_propertylist_update_bool(  conf->mf.parms, KMOS_MF_PARAM_RECIPE"FIT_RES_LORENTZ",    conf->lorentz.fit);
+  cpl_propertylist_update_double(conf->mf.parms, KMOS_MF_PARAM_RECIPE"RES_LORENTZ",        conf->lorentz.res);
 
   /* Check status */
   if (!cpl_errorstate_is_equal(preState)) {
@@ -1234,3 +1304,136 @@ static void kmos_molecfit_model_clean(
       cpl_free(conf);
   }
 }
+
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief Insert QC parameters in the headers of the IFUs with valid data
+ *
+ * @param  res_table   Molecfit result table with the parameters of best-fitting.
+ * @param  spec_out    Molecfit best fitting table data
+ * @param  pl_BParams  input/output Header to BEST_FIT_PARM  FITS file output
+ * @param  pl_BModel   input/output Header to BEST_FIT_MODEL FITS file output
+ *
+ * @return CPL_ERROR_NONE without error or CPL_ERROR_DATA_NOT_FOUND if it doesn't exist the correct columns
+ *
+ */
+/*----------------------------------------------------------------------------*/
+static cpl_error_code kmos_molecfit_model_headers_fill_qc_parameters(
+    const cpl_table  *res_table,
+    const cpl_table  *spec_out,
+    cpl_propertylist *pl_BParms,
+    cpl_propertylist *pl_BModel)
+{
+
+  /* Check column inputs */
+  if (   !cpl_table_has_column(res_table, KMOS_MOLECFIT_RESULTS_COLUMN_PARAMETER)
+      || !cpl_table_has_column(res_table, KMOS_MOLECFIT_RESULTS_COLUMN_VALUE    )
+      || !cpl_table_has_column(spec_out,  KMOS_MOLECFIT_MODEL_COLUMN_FLUX       )
+      || !cpl_table_has_column(spec_out,  KMOS_MOLECFIT_MODEL_COLUMN_MSCAL      )
+      || !cpl_table_has_column(spec_out,  KMOS_MOLECFIT_MODEL_COLUMN_MTRANS     ) ){
+
+      return CPL_ERROR_DATA_NOT_FOUND;
+  }
+
+
+  /*** Fill the BEST_FIT_PARM FITS header file with the QC parameters ***/
+  cpl_table_dump(res_table, 0, cpl_table_get_nrow(res_table), NULL);
+
+  /* Get parameters and values of the best fit model results table */
+  const char   **parameter = cpl_table_get_data_string_const(res_table, KMOS_MOLECFIT_RESULTS_COLUMN_PARAMETER);
+  const double *value      = cpl_table_get_data_double_const(res_table, KMOS_MOLECFIT_RESULTS_COLUMN_VALUE    );
+
+  /* Write the QC BEST_FIT_PARM parameters */
+  cpl_size nrows_res_table = cpl_table_get_nrow(res_table);
+  for (cpl_size i = 0; i < nrows_res_table; i++) {
+      if (parameter[i]) {
+          cpl_msg_info(cpl_func, "Parameter: %s, Value = %g", parameter[i], value[i]);
+
+          if (!strcmp(parameter[i], KMOS_MOLECFIT_RESULTS_ROW_RMS_REL_TO_MEAN)) {
+              cpl_propertylist_update_double( pl_BParms, KMOS_MOLECFIT_QC_PARAM_RMS,    value[i]                          );
+              cpl_propertylist_set_comment(   pl_BParms, KMOS_MOLECFIT_QC_PARAM_RMS,    KMOS_MOLECFIT_QC_PARAM_RMS_TXT    );
+          }
+
+          if (!strcmp(parameter[i], KMOS_MOLECFIT_RESULTS_ROW_RMS_STATUS)) {
+              cpl_propertylist_update_double( pl_BParms, KMOS_MOLECFIT_QC_PARAM_STATUS, value[i]                          );
+              cpl_propertylist_set_comment(   pl_BParms, KMOS_MOLECFIT_QC_PARAM_STATUS, KMOS_MOLECFIT_QC_PARAM_STATUS_TXT );
+          }
+
+          if (!strcmp(parameter[i], KMOS_MOLECFIT_RESULTS_ROW_RMS_H2O_COL_MM)) {
+              cpl_propertylist_update_double( pl_BParms, KMOS_MOLECFIT_QC_PARAM_H2O,    value[i]                          );
+              cpl_propertylist_set_comment(   pl_BParms, KMOS_MOLECFIT_QC_PARAM_H2O,    KMOS_MOLECFIT_QC_PARAM_H2O_TXT    );
+          }
+      }
+  }
+
+  /* Check QC BEST_FIT_PARM parameters */
+  if (   !cpl_propertylist_has(pl_BParms, KMOS_MOLECFIT_QC_PARAM_RMS   )
+      || !cpl_propertylist_has(pl_BParms, KMOS_MOLECFIT_QC_PARAM_STATUS)
+      || !cpl_propertylist_has(pl_BParms, KMOS_MOLECFIT_QC_PARAM_H2O   ) ){
+
+      return CPL_ERROR_DATA_NOT_FOUND;
+  }
+
+
+  /*** Fill the BEST_FIT_MODEL FITS header file with the QC parameters ***/
+  cpl_size nrows_spec_out = cpl_table_get_nrow(spec_out);
+  double   RMS_NF         =  1.;
+  double   RMS_NTF        = -1.;
+
+  /* Create new columns to the calculate table and select to zero for convert in valid */
+  cpl_table *copy_spec_out = cpl_table_duplicate(spec_out);
+  cpl_table_new_column(copy_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NF,  CPL_TYPE_DOUBLE);
+  cpl_table_new_column(copy_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NTF, CPL_TYPE_DOUBLE);
+  for (cpl_size i = 0; i < nrows_spec_out; i++) {
+      cpl_table_set_double(copy_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NF,  i, 0.);
+      cpl_table_set_double(copy_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NTF, i, 0.);
+  }
+
+  /* Apply the selection: mtrans > 0 and extract columns*/
+  cpl_table_unselect_all(copy_spec_out);
+  cpl_table_or_selected_double(copy_spec_out, KMOS_MOLECFIT_MODEL_COLUMN_MTRANS, CPL_GREATER_THAN, 0.);
+  cpl_msg_info(cpl_func, "Number of select columns (%s > 0) = %lld ", KMOS_MOLECFIT_MODEL_COLUMN_MTRANS, cpl_table_count_selected(copy_spec_out));
+  cpl_table *calculate_spec_out = cpl_table_extract_selected(copy_spec_out);
+
+  /* cpl_table_dump(calculate_spec_out, 0, cpl_table_get_nrow(calculate_spec_out), NULL); */
+
+  /* Remove the temporary copy of spec_out table */
+  cpl_table_delete(copy_spec_out);
+
+  /* Calculate RMS_NF and RMS_NTF */
+  if (cpl_table_get_nrow(calculate_spec_out) > 0) {
+
+      /* Calculate NF column and RMS_NF */
+      const double *cflux = cpl_table_get_data_double_const(calculate_spec_out, KMOS_MOLECFIT_MODEL_COLUMN_FLUX);
+      cpl_table_copy_data_double(calculate_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NF,  cflux);
+      cpl_table_divide_columns(  calculate_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NF,  KMOS_MOLECFIT_MODEL_COLUMN_MSCAL);
+
+      /* Calculate NTF column and RMS_NTF */
+      const double *cNF = cpl_table_get_data_double_const(calculate_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NF);
+      cpl_table_copy_data_double(calculate_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NTF, cNF);
+      cpl_table_divide_columns(  calculate_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NTF, KMOS_MOLECFIT_MODEL_COLUMN_MTRANS);
+
+      /* Calculate the standard deviation */
+      RMS_NF  = cpl_table_get_column_stdev(calculate_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NF);
+      RMS_NTF = cpl_table_get_column_stdev(calculate_spec_out, KMOS_MOLECFIT_CALCULE_COLUMN_NTF);
+
+      cpl_msg_info(cpl_func, "RMS_NF  = %g", RMS_NF);
+      cpl_msg_info(cpl_func, "RMS_NTF = %g", RMS_NTF);
+
+  } else {
+
+      cpl_msg_warning(cpl_func, "Any values in the column MSCAL < 0");
+  }
+
+  /* Remove the temporary calculate of spec_out table */
+  cpl_table_delete(calculate_spec_out);
+
+  /* Write the QC BEST_FIT_MODEL parameters */
+  double improv = RMS_NTF / RMS_NF;
+  cpl_propertylist_update_double( pl_BModel, KMOS_MOLECFIT_QC_PARAM_IMPROV, improv);
+  cpl_propertylist_set_comment(   pl_BModel, KMOS_MOLECFIT_QC_PARAM_IMPROV, KMOS_MOLECFIT_QC_PARAM_IMPROV_TXT);
+  cpl_msg_info(cpl_func, "HIERACH ESO QC IMPROV = %g ", improv);
+
+
+  return CPL_ERROR_NONE;
+}
