@@ -76,7 +76,8 @@ static char kmos_reconstruct_description[] =
 "   ARC_ON  or      RAW/F2D                                                 \n"
 "   OBJECT  or      RAW                                                     \n"
 "   STD     or      RAW                                                     \n"
-"   SCIENCE         RAW                                                     \n"
+"   SCIENCE or      RAW                                                     \n"
+"   ACQUISITION     RAW                                                     \n"
 "   XCAL            F2D      x-direction calib. frame           Y       1   \n"
 "   YCAL            F2D      y-direction calib. frame           Y       1   \n"
 "   LCAL            F2D      Wavelength calib. frame            Y       1   \n"
@@ -415,12 +416,18 @@ static int kmos_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
     } else if (cpl_frameset_count_tags(frameset, OBJECT) == 1) {
         input_frame_name = OBJECT;
         output_frame_name = CUBE_OBJECT;
+    } else if (cpl_frameset_count_tags(frameset, ACQUISITION) == 1) {
+        input_frame_name = ACQUISITION;
+        output_frame_name = CUBE_ACQUISITION;
     } else if (cpl_frameset_count_tags(frameset, STD) == 1) {
         input_frame_name = STD;
         output_frame_name = CUBE_STD;
     } else if (cpl_frameset_count_tags(frameset, SCIENCE) == 1) {
         input_frame_name = SCIENCE;
         output_frame_name = CUBE_SCIENCE;
+    } else if (cpl_frameset_count_tags(frameset, ACQUISITION) == 1) {
+        input_frame_name = SCIENCE;
+        output_frame_name = CUBE_SCIENCE;
     } else {
         cpl_msg_error(__func__, "Missing Inputs") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
@@ -501,7 +508,7 @@ static int kmos_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_table_delete(band_table); 
 
         /* Create empty detector images */
-        if (detectorimage == TRUE) {
+        if (detectorimage) {
             det_img_data = cpl_image_new(
                     gd.x.dim*gd.y.dim*KMOS_IFUS_PER_DETECTOR, gd.l.dim, 
                     CPL_TYPE_FLOAT);
@@ -630,17 +637,22 @@ static int kmos_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
         } // IFUs loop
 
         if (detectorimage) {
+
             /* Save Product (detector image) Data Cube */
             index = kmo_identify_index(cpl_frame_get_filename(input_frame), i,
                     FALSE);
+
             tmp_header = kmclipm_propertylist_load(
                     cpl_frame_get_filename(input_frame), index);
-            kmo_save_det_img_ext(det_img_data, gd, i, DET_IMG_REC,
-                    obs_suffix, tmp_header, FALSE, FALSE);
-            cpl_propertylist_delete(tmp_header);
-            cpl_image_delete(det_img_data);
+            if (det_img_data) {
+				kmo_save_det_img_ext(det_img_data, gd, i, DET_IMG_REC,
+						obs_suffix, tmp_header, FALSE, FALSE);
+				cpl_image_delete(det_img_data);
+            }
+			cpl_propertylist_delete(tmp_header);
 
             if (detImgCube) {
+
                 /* Save Product (detector image) Noise Cube */
                 /* Index changes (*2) if Noise extensions are there */
                 if (desc1.ex_noise) {
@@ -649,11 +661,13 @@ static int kmos_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 }
                 tmp_header = kmclipm_propertylist_load(
                         cpl_frame_get_filename(input_frame), index);
-                kmo_save_det_img_ext(det_img_noise, gd, i, DET_IMG_REC,
-                        obs_suffix, tmp_header, FALSE, TRUE);
+                if (det_img_noise) {
+					kmo_save_det_img_ext(det_img_noise, gd, i, DET_IMG_REC,
+							obs_suffix, tmp_header, FALSE, TRUE);
+                }
                 cpl_propertylist_delete(tmp_header); 
             }
-            cpl_image_delete(det_img_noise);
+            if (det_img_noise) cpl_image_delete(det_img_noise);
         }
     } // Detectors loop
     cpl_propertylist_delete(main_header);
@@ -694,6 +708,7 @@ static int kmos_reconstruct_check_inputs(
             cpl_frameset_count_tags(frameset, FLAT_ON) != 1 &&
             cpl_frameset_count_tags(frameset, ARC_ON) != 1 &&
             cpl_frameset_count_tags(frameset, OBJECT) != 1 &&
+            cpl_frameset_count_tags(frameset, ACQUISITION) != 1 &&
             cpl_frameset_count_tags(frameset, STD) != 1 &&
             cpl_frameset_count_tags(frameset, SCIENCE) != 1) {
         cpl_msg_error(__func__, "1 data frame must be provided") ;
