@@ -406,7 +406,7 @@ static int kmos_sky_tweak(
 
                 /* Apply the sky tweaking */
                 result = kmos_priv_sky_tweak(obj_data, sky_data, 
-                        sub_header, .3, tbsub, ifu_nr, discard_subband,
+                        sub_header, .3, tbsub, discard_subband,
                         stretch, stretch_degree, stretch_resampling, plot, 
                         &new_sky);
                 cpl_imagelist_delete(new_sky);
