@@ -541,8 +541,8 @@ static int kmos_std_star(cpl_parameterlist *parlist, cpl_frameset *frameset)
     cpl_vector          *   centre ;
     const char          *   spec_type ;        
     const char          *   magnitude_txt ;        
-    double                  cpos_rej, cneg_rej, neighborhoodRange, cen_x, cen_y,
-                            radius ;
+    double                  cpos_rej, cneg_rej, neighborhoodRange;
+    double                  cen_x = 0., cen_y = 0., radius = 0.;
     int                     flux, save_cubes, no_noise, citer, cmin, cmax,
                             xcal_interpolation, suppress_extension ;
     /*********************/
@@ -605,19 +605,17 @@ static int kmos_std_star(cpl_parameterlist *parlist, cpl_frameset *frameset)
     char                    star_type ;
     kmclipm_vector      *   ddd  ;
     int                     i, j ;
+
+    /* Check initial Entries */
+    if (kmos_check_and_set_groups(frameset) != CPL_ERROR_NONE) {
+        return cpl_error_get_code();
+    }
     
     /* Initialise */
     nr_std_stars = 0 ;
     zeropoint = throughput_mean = throughput_sdv = -1.0 ;
     magnitude1 = magnitude2 = -1.0 ;
 
-    /* Check entries */
-    if (parlist == NULL || frameset == NULL) {
-        cpl_msg_error(__func__, "Null Inputs") ;
-        cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
-        return -1 ;
-    }
-
     /* Get parameters */
     par = cpl_parameterlist_find_const(parlist, "kmos.kmos_std_star.imethod");
     imethod = cpl_parameter_get_string(par) ;
@@ -700,13 +698,6 @@ static int kmos_std_star(cpl_parameterlist *parlist, cpl_frameset *frameset)
         return -1 ;
     }
 
-    /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset) != 1) {
-        cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
-        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
-        return -1 ;
-    }
-
     /* Check the inputs consistency */
     if (kmos_std_star_check_inputs(frameset, magnitude_txt, &is_stdstarscipatt,
                 &compute_qcs, &magnitude1, &magnitude2) != 1) {
@@ -1289,7 +1280,7 @@ static int kmos_std_star_compute_ifu(
     cpl_imagelist       *   tmp_cube ;
     cpl_vector          *   lambda_x ;
     cpl_vector          *   atmos_model ;
-    int                     i, j, k, nr_sky_pairs, npix, x, y, det_nr ;
+    int                     i, j, k, nr_sky_pairs, npix, x, y ;
  
     /* Check inputs */
     
@@ -1363,7 +1354,6 @@ static int kmos_std_star_compute_ifu(
     /* Illumination correction */
     /* Illumination noise small versus noise - skipped */
     if (illum_frame != NULL) {
-        det_nr = (ifu_nr - 1)/KMOS_IFUS_PER_DETECTOR + 1;
         plist = kmclipm_propertylist_load(cpl_frame_get_filename(obj_frame), 0);
         angle = kmo_dfs_get_property_double(plist, ROTANGLE);
         cpl_propertylist_delete(plist); 
