@@ -43,7 +43,6 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
 static int kmos_test_create(cpl_plugin *plugin)
 {
     cpl_recipe *recipe;
-    cpl_parameter *p;
 
     /* Check that the plugin is part of a valid recipe */
     if (cpl_plugin_get_type(plugin) == CPL_PLUGIN_TYPE_RECIPE) 
@@ -114,10 +113,12 @@ static int kmos_test(cpl_parameterlist * parlist, cpl_frameset * frameset)
     cpl_vector  *   vec_x_extract ;
     cpl_vector  *   vec_y_extract ;
 	cpl_vector	*	fit_par ;
+	cpl_vector	*	guess_vec ;
+    double      *   pguess_vec ;
 	cpl_vector	*	fit ;
     double      *   pfit ;
     cpl_matrix  *   x_mat ;
-    double          line_center, line_width, cdelt ;
+    double          line_center, line_width ;
     int             lowIndex, highIndex, i ;	
     double          red_chisq ;
     cpl_matrix  *   covariance ;
@@ -162,19 +163,40 @@ static int kmos_test(cpl_parameterlist * parlist, cpl_frameset * frameset)
 	fit_par = cpl_vector_new(5);
 
     /* Initial estimates */
-    cdelt = cpl_vector_get(vec_x_extract, 1) - cpl_vector_get(vec_x_extract, 0);
     cpl_vector_set(fit_par, 0, 0.0);
+    cpl_vector_set(fit_par, 0, 17000.0);
     cpl_vector_set(fit_par, 1, cpl_vector_get_min(vec_y_extract));
     cpl_vector_set(fit_par, 1, 17310.7);
+    cpl_vector_set(fit_par, 1, 6000);
     cpl_vector_set(fit_par, 2, line_center);
     cpl_vector_set(fit_par, 2, 0.88635);
     cpl_vector_set(fit_par, 3, 0.000151367);
     cpl_vector_set(fit_par, 4, 0.0);
     cpl_vector_dump(fit_par, stdout);
 
+    
+    /* cpl_vector_set(fit_par, 0, 23000.0); */
+    /* cpl_vector_set(fit_par, 1, 0.0); */
+    /* cpl_vector_set(fit_par, 2, 0.0); */
+    /* cpl_vector_set(fit_par, 3, 0.0); */
+    /* cpl_vector_set(fit_par, 4, 0.0); */
+ 
+    /* Compute the guess vector for plotting*/
+    guess_vec = cpl_vector_new(cpl_vector_get_size(vec_y_extract));
+    pguess_vec = cpl_vector_get_data(guess_vec);
+	for (i = 0; i < cpl_vector_get_size(guess_vec); i++) {
+		x_array[0] = cpl_vector_get(vec_x_extract, i);
+		kmo_priv_lorentz1d_fnc(x_array, cpl_vector_get_data(fit_par),
+				y_array);
+		pguess_vec[i] = y_array[0];
+	}
+	cpl_plot_vector("set grid;", "t 'Guess' w lines", "", guess_vec);
+    cpl_vector_delete(guess_vec) ;
+
+
     /* Prepare data for fitting */
     x_mat = cpl_matrix_wrap(cpl_vector_get_size(vec_x_extract), 1,
-            (double*)cpl_vector_get_data_const(vec_x_extract));
+            cpl_vector_get_data(vec_x_extract));
 
     sigma_y = cpl_vector_new(cpl_vector_get_size(vec_x_extract));
     cpl_vector_fill(sigma_y, 1.0);
