@@ -104,11 +104,6 @@ static char kmos_wave_cal_description[] =
 "The number of samples in spectral direction for the reconstructed cube.\n"
 "Ideally this number should be greater than 2048, the detector size.\n"
 "\n"
-"--b_start\n"
-"--b_end\n"
-"Used to define manually the start and end wavelength for the reconstructed\n"
-"cube. By default the internally defined values are used.\n"
-"\n"
 "--suppress_extension\n"
 "If set to TRUE, the arbitrary filename extensions are supressed. If\n"
 "multiple products with the same category are produced, they will be numered\n"
@@ -363,11 +358,9 @@ static int kmos_wave_cal(cpl_parameterlist *parlist, cpl_frameset *frameset)
     const char              *   tmp_str ;
     cpl_error_code              err ;
 
-    /* Check entries */
-    if (parlist == NULL || frameset == NULL) {
-        cpl_msg_error(__func__, "Null Inputs") ;
-        cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
-        return -1 ;
+    /* Check initial Entries */
+    if (kmos_check_and_set_groups(frameset) != CPL_ERROR_NONE) {
+        return cpl_error_get_code();
     }
     
     /* Get Parameters */
@@ -398,13 +391,6 @@ static int kmos_wave_cal(cpl_parameterlist *parlist, cpl_frameset *frameset)
         return -1 ;
     }
 
-    /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset) != 1) {
-        cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
-        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
-        return -1 ;
-    }
-
     /* Check the inputs consistency */
     if (kmos_wave_cal_check_inputs(frameset, &nx, &ny, &next, &exptime,
                 &non_dest_rom, &lamp_config) != 1) {
@@ -531,13 +517,14 @@ static int kmos_wave_cal(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
             /* Set default fit orders for the different bands */
             if (fit_order_par == 0) {
+
                 if ((strcmp(filter_ids[i-1], "H") == 0) ||
                     (strcmp(filter_ids[i-1], "K") == 0) ||
                     (strcmp(filter_ids[i-1], "YJ") == 0)) {
                     fit_order = 6;
                 } else if (strcmp(filter_ids[i-1], "IZ") == 0) {
                     fit_order = 4;
-                } else if (strcmp(filter_ids[i-1], "HK") == 0) {
+                } else { //if (strcmp(filter_ids[i-1], "HK") == 0) {
                     fit_order = 5;
                 }
                 cpl_msg_info(__func__, 
@@ -810,7 +797,9 @@ static int kmos_wave_cal_check_inputs(
     cpl_propertylist    *   mh_on ;
     cpl_propertylist    *   eh_off ;
     cpl_propertylist    *   eh_on ;
-    int                     ext, next_off, next_on, nx_on, ny_on, nx_off,ny_off;
+    int                     ext;
+    int                     next_off;
+    int                     next_on;
     double                  ndit_off, ndit_on, exptime_off, exptime_on ;
     const char          *   readmode_off ;
     const char          *   readmode_on ;
@@ -842,12 +831,14 @@ static int kmos_wave_cal_check_inputs(
 
     /* Check READ OUT MODE */
     readmode_on = kmos_pfits_get_readmode(mh_on);
+    cpl_propertylist_delete(mh_on);
+    if (!readmode_on) return -1;
+
     if (!strcmp(readmode_on, "Nondest")) {
         *non_dest_rom = 1 ;
     } else {
         *non_dest_rom = 0 ;
     }
-    cpl_propertylist_delete(mh_on);
 
     /* Get ARC_OFF */
     frame_off = kmo_dfs_get_frame(frameset, ARC_OFF);
@@ -895,6 +886,10 @@ static int kmos_wave_cal_check_inputs(
     cpl_propertylist_delete(mh_off);
 
     /* Check the extensions */
+    int nx_on  = -1;
+    int nx_off = -1;
+    int ny_on  = -1;
+    int ny_off = -1;
     for (ext = 1; ext <= next_off ; ext++) {
         eh_off = cpl_propertylist_load(cpl_frame_get_filename(frame_off), ext);
         nx_off = kmos_pfits_get_naxis1(eh_off) ;
