@@ -69,7 +69,7 @@ if __name__ == '__main__':
            response_ =  hdu_res[exten].data
            error_response_ = hdu_res[exten+1].data
       
-           if data != None:
+           if data is not None:
               
               wdata = getw(hdu_spc[exten].header)
               wresponse = getw(hdu_res[exten].header)
@@ -78,7 +78,7 @@ if __name__ == '__main__':
               response = np.interp(wdata,wresponse,response_)
               hdu_spc[exten].data = data / response
               
-           if noise != None:
+           if noise is not None:
               wnoise = getw(hdu_res[exten+1].header) 
               #I need to interpolate the response and error_response to the wavelength range and step of data and noise.
               error_response =  np.interp(wnoise,wresponse,error_response_)
