@@ -34,9 +34,11 @@ def paragraph(text, width=None):
 
 class DataPlotterManager(object):
     # static members
-    recipe_name = "kmos_combine"
-    combined_cat = "COMBINE_SCI_RECONSTRUCTED"
-    recons_cat = "SCI_RECONSTRUCTED"
+    recipe_name  = "kmos_combine"
+    recons_cat   = "SCI_RECONSTRUCTED"
+    recons_cat2  = "SINGLE_CUBES"
+    combined_cat = "COMBINED_CUBE"
+    
     oh_spec_cat = "OH_SPEC"
     cores = ['r', 'g', '0.50', 'c', 'm', 'y', 'b']
     labels_view=['Display input and output spectra', 'Display output spectra', 'Display input spectra']
@@ -184,7 +186,7 @@ class DataPlotterManager(object):
                 # Loop on all input fitsfiles
                 countr = 0  
                 for frec in fitsFiles:
-                    if frec.category == self.recons_cat :
+                    if frec.category == self.recons_cat or frec.category == self.recons_cat2 :
                         reconstructed_file = PipelineProduct(frec)
                         reconstructed_filename = os.path.basename(frec.name)
                         
@@ -490,7 +492,7 @@ class DataPlotterManager(object):
 
     def _process_label(self, in_label):
         # If known, 'pretty print' the label
-        if (in_label == "ERG/sec/cm2/A"):
+        if (in_label == "erg.s**(-1).cm**(-2).angstrom**(-1)"):
             return "erg sec" + r"$^{-1}$"+"cm" + r"$^{-2}$" + r"$\AA^{-1}$"
         else:
             return in_label
