@@ -49,15 +49,7 @@ class DataPlotterManager(object):
                     group="Recons.", description="Apply Overscan Correction"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="xcal_interpolation",
                     group="Recons.", description="Interpolate xcal between rotator angles"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="b_samples",
-                    group="Recons.", description="The number of samples in wavelength"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="b_start",
-                    group="Recons.", description="The lowest wavelength"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="b_end",
-                    group="Recons.", description="The highest wavelength"),
 
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="fmethod",
-                    group="Extr.", description="Fitting Method (gauss, moffat)"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="neighborhoodRange",
                     group="Extr.", description="Range for Neighbors"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="flux",
@@ -287,7 +279,7 @@ class DataPlotterManager(object):
 
     def _process_label(self, in_label):
         # If known, 'pretty print' the label
-        if (in_label == "ERG/sec/cm2/A"):
+        if (in_label == "erg.s**(-1).cm**(-2).angstrom**(-1)"):
             return "erg sec" + r"$^{-1}$"+"cm" + r"$^{-2}$" + r"$\AA^{-1}$"
         else:
             return in_label
