@@ -45,12 +45,6 @@ class DataPlotterManager(object):
                     group="Wavelength Calibration", description="The expected dispersion of the wavelength in microns/pixel"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="suppress_extension",
                     group="Wavelength Calibration", description="Suppress arbitrary filename extension"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="b_samples",
-                    group="Wavelength Calibration", description="The number of samples in wavelength for the reconstructed cube"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="b_start",
-                    group="Wavelength Calibration", description="The lowest wavelength to take into account when reconstructing"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="b_end",
-                    group="Wavelength Calibration", description="The highest wavelength to take into account when reconstructing"),
         ]
 
     def readFitsData(self, fitsFiles):
@@ -68,11 +62,11 @@ class DataPlotterManager(object):
             # Get the angle values
             self.angles_list = dict()
             for i in range(18):
-                angle = det_img_wave.readKeyword('ESO PRO ROT NAANGLE', i+1)
-
-                if not (angle in self.angles_list) :
-                    self.angles_list[angle] = []
-                self.angles_list[angle].append(i+1)
+                if (i+1 < len(det_img_wave.all_hdu)):
+                    angle = det_img_wave.readKeyword('ESO PRO ROT NAANGLE', i+1)
+                    if not (angle in self.angles_list) :
+                        self.angles_list[angle] = []
+                    self.angles_list[angle].append(i+1)
 
             # Sorted angles list
             self.sorted_angles = self.angles_list.keys()
@@ -84,31 +78,33 @@ class DataPlotterManager(object):
             self.neon_pos_data = []
             self.neon_fwhm_data = []
             for i in range(18):
-                key1 = det_img_wave.readKeyword('ESO QC ARC AR POS MEAN', i+1)
-                key2 = det_img_wave.readKeyword('ESO QC ARC AR FWHM MEAN', i+1)
-                ar_vscale = det_img_wave.readKeyword('ESO QC ARC AR VSCALE', i+1)
+                if (i+1 < len(det_img_wave.all_hdu)):
+                    key1 = det_img_wave.readKeyword('ESO QC ARC AR POS MEAN', i+1)
+                    key2 = det_img_wave.readKeyword('ESO QC ARC AR FWHM MEAN', i+1)
+                    ar_vscale = det_img_wave.readKeyword('ESO QC ARC AR VSCALE', i+1)
 
-                key3 = det_img_wave.readKeyword('ESO QC ARC NE POS MEAN', i+1)
-                key4 = det_img_wave.readKeyword('ESO QC ARC NE FWHM MEAN', i+1)
-                ne_vscale = det_img_wave.readKeyword('ESO QC ARC NE VSCALE', i+1)
-           
-                # Correct Key2 and Key4 units
-                key2 /= ar_vscale
-                key4 /= ne_vscale
+                    key3 = det_img_wave.readKeyword('ESO QC ARC NE POS MEAN', i+1)
+                    key4 = det_img_wave.readKeyword('ESO QC ARC NE FWHM MEAN', i+1)
+                    ne_vscale = det_img_wave.readKeyword('ESO QC ARC NE VSCALE', i+1)
+               
+                    # Correct Key2 and Key4 units
+                    key2 /= ar_vscale
+                    key4 /= ne_vscale
 
-                # Fill the Argon Data for the scatter plot
-                self.argon_pos_data.append(key1)
-                self.argon_fwhm_data.append(key2)
-                
-                # Fill the Neon Data for the scatter plot
-                self.neon_pos_data.append(key3)
-                self.neon_fwhm_data.append(key4)
+                    # Fill the Argon Data for the scatter plot
+                    self.argon_pos_data.append(key1)
+                    self.argon_fwhm_data.append(key2)
+                    
+                    # Fill the Neon Data for the scatter plot
+                    self.neon_pos_data.append(key3)
+                    self.neon_fwhm_data.append(key4)
 
             # Read the images
             self.images = []
             for i in range(18):
-                det_img_wave.readImage(i+1)
-                self.images.append(det_img_wave.image) 
+                if (i+1 < len(det_img_wave.all_hdu)):
+                    det_img_wave.readImage(i+1)
+                    self.images.append(det_img_wave.image) 
 
             # Set the plotting functions
             self._add_subplots = self._add_subplots
@@ -178,8 +174,9 @@ class DataPlotterManager(object):
             print "Wrong number of extensions for this angle"
 
         # Define x
-        x = numpy.linspace(1, 18, num=18)
-        
+        size = len(self.argon_pos_data)
+        x = numpy.linspace(1, size, num=size)
+
         # Plot Argon and Neon plots
         scadsp = pipeline_display.ScatterDisplay()
         scadsp.display(self.argon_plot, "Argon Lines", "Mean Argon line positional offset, with error bars equal to the FWH", x, self.argon_pos_data,
