@@ -4,9 +4,14 @@ import sys
 import os
 import time
 from optparse import OptionParser
-import pyfits
-from pyfits import getval
-from pyfits import getheader
+try:
+    import pyfits
+    from pyfits import getval
+    from pyfits import getheader
+except:
+    from astropy.io import fits as fits
+    from fits import getval
+    from fits import getheader
 import glob
 import logging
 import subprocess
@@ -181,15 +186,15 @@ def create_sof( filelist, mydir ):
 
     # Add Calibrations
     if filelist[0]['tpl_id'] == "KMOS_spec_cal_calunitflat" :
-        sof.write(os.getcwd()+"/badpixel_dark.fits BADPIXEL_DARK\n")
+        sof.write(os.getcwd()+"/BADPIXEL_DARK.fits BADPIXEL_DARK\n")
 
     if filelist[0]['tpl_id'] == "KMOS_spec_cal_wave" :
         sof.write(os.environ['KMOS_CALIB']+"/kmos_wave_ref_table.fits  REF_LINES\n")
         sof.write(os.environ['KMOS_CALIB']+"/kmos_wave_band.fits       WAVE_BAND\n")
         sof.write(os.environ['KMOS_CALIB']+"/kmos_ar_ne_list_"+band_lc+".fits    ARC_LIST\n")
-        sof.write(os.getcwd()+"/"+filelist[0]['band']+"/flat_edge_"+band_3uc+".fits   FLAT_EDGE\n")
-        sof.write(os.getcwd()+"/"+filelist[0]['band']+"/xcal_"+band_3uc+".fits        XCAL\n")
-        sof.write(os.getcwd()+"/"+filelist[0]['band']+"/ycal_"+band_3uc+".fits        YCAL\n")
+        sof.write(os.getcwd()+"/"+filelist[0]['band']+"/FLAT_EDGE_"+band_3uc+".fits   FLAT_EDGE\n")
+        sof.write(os.getcwd()+"/"+filelist[0]['band']+"/XCAL_"+band_3uc+".fits        XCAL\n")
+        sof.write(os.getcwd()+"/"+filelist[0]['band']+"/YCAL_"+band_3uc+".fits        YCAL\n")
 
     # Close sof file
     sof.close()
@@ -279,15 +284,15 @@ description = '''
 \033[1mPurpose:\033[0m
 Execute kmos_dark/_flat/_wave_cal on the data from the 3 relevant templates in the 5 bands in order to create the calibration files set needed for the image reconstruction on the instrument workstation.
 The wished 37 files are:
-- badpixel_dark.fits
-- master_dark.fits
-- badpixel_flat_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
-- det_img_wave_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
-- flat_edge_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
-- master_flat_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
-- lcal_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
-- xcal_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
-- ycal_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
+- BADPIXEL_DARK.fits
+- MASTER_DARK.fits
+- BADPIXEL_FLAT_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
+- DET_IMG_WAVE_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
+- FLAT_EDGE_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
+- MASTER_FLAT_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
+- LCAL_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
+- XCAL_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
+- YCAL_[HHH|KKK|HKHKHK|IZIZIZ|YJYJYJ].fits
 
 \033[1mUsage:\033[0m
 - Create a new directory and cd to it (mkdir tmp ; cd tmp)
@@ -507,8 +512,8 @@ else:
     os.mkdir('results') 
 
 # Collect results
-os.rename(os.getcwd()+"/master_dark.fits", os.getcwd()+"/results/master_dark.fits")
-os.rename(os.getcwd()+"/badpixel_dark.fits", os.getcwd()+"/results/badpixel_dark.fits")
+os.rename(os.getcwd()+"/MASTER_DARK.fits", os.getcwd()+"/results/MASTER_DARK.fits")
+os.rename(os.getcwd()+"/BADPIXEL_DARK.fits", os.getcwd()+"/results/BADPIXEL_DARK.fits")
 for set_curr in selected_sets:
     # Skip the bands that are not wished
     if options.band != 'All' and options.band != set_curr['band']:
@@ -517,13 +522,13 @@ for set_curr in selected_sets:
     # Collect the band results
     my_dir = set_curr['band']
     band_3uc = set_curr['band']*3
-    filenames = [   "xcal_{0}.fits".format(band_3uc), 
-                    "ycal_{0}.fits".format(band_3uc), 
-                    "lcal_{0}.fits".format(band_3uc),
-                    "master_flat_{0}.fits".format(band_3uc),
-                    "badpixel_flat_{0}.fits".format(band_3uc),
-                    "det_img_wave_{0}.fits".format(band_3uc),
-                    "flat_edge_{0}.fits".format(band_3uc)]
+    filenames = [   "XCAL_{0}.fits".format(band_3uc), 
+                    "YCAL_{0}.fits".format(band_3uc), 
+                    "LCAL_{0}.fits".format(band_3uc),
+                    "MASTER_FLAT_{0}.fits".format(band_3uc),
+                    "BADPIXEL_FLAT_{0}.fits".format(band_3uc),
+                    "DET_IMG_WAVE_{0}.fits".format(band_3uc),
+                    "FLAT_EDGE_{0}.fits".format(band_3uc)]
     for filename in filenames :
         src_file = os.getcwd()+"/"+my_dir+"/"+filename
         dest_file = os.getcwd()+"/results/"+filename
